@@ -3,7 +3,7 @@
  * time, so that we only need one Ethereal binary and one Tethereal binary
  * for Windows, regardless of whether WinPcap is installed or not.
  *
- * $Id: capture-wpcap.c 14081 2005-04-14 20:37:13Z guy $
+ * $Id: capture-wpcap.c 14540 2005-06-03 09:55:28Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -78,6 +78,7 @@ static const char *(*p_pcap_datalink_val_to_name) (int);
 #endif
 static const char *(*p_pcap_lib_version) (void);
 static int     (*p_pcap_setbuff) (pcap_t *, int dim);
+static int     (*p_pcap_next_ex) (pcap_t *, struct pcap_pkthdr **pkt_header, const u_char **pkt_data);
 
 typedef struct {
 	const char	*name;
@@ -105,7 +106,7 @@ load_wpcap(void)
 		SYM(pcap_lookupnet, FALSE),
 		SYM(pcap_open_live, FALSE),
 		SYM(pcap_loop, FALSE),
-		SYM(pcap_freecode, FALSE),
+		SYM(pcap_freecode, TRUE),
 #ifdef HAVE_PCAP_FINDALLDEVS
 		SYM(pcap_findalldevs, TRUE),
 		SYM(pcap_freealldevs, TRUE),
@@ -118,6 +119,7 @@ load_wpcap(void)
 #endif
 		SYM(pcap_lib_version, TRUE),
 		SYM(pcap_setbuff, TRUE),
+		SYM(pcap_next_ex, TRUE),
 		{ NULL, NULL, FALSE }
 	};
 
@@ -250,7 +252,9 @@ void
 pcap_freecode(struct bpf_program *a)
 {
 	g_assert(has_wpcap);
-	p_pcap_freecode(a);
+    if(p_pcap_freecode) {
+	    p_pcap_freecode(a);
+    }
 }
 
 #ifdef HAVE_PCAP_FINDALLDEVS
@@ -418,6 +422,14 @@ int pcap_setbuff(pcap_t *a, int b)
 	return p_pcap_setbuff(a, b);
 }
 
+/* pcap_next_ex is available since libpcap 0.8 / WinPcap 3.0! */
+/* (if you get a declaration warning here, try to update to at least WinPcap 3.1b4 develpack) */
+int pcap_next_ex (pcap_t *a, struct pcap_pkthdr **b, const u_char **c)
+{
+	g_assert(has_wpcap);
+	return p_pcap_next_ex(a, b, c);
+}
+
 /*
  * This will use "pcap_findalldevs()" if we have it, otherwise it'll
  * fall back on "pcap_lookupdev()".
@@ -442,7 +454,7 @@ get_interface_list(int *err, char *err_str)
 	 * PacketGetAdapterNames.  According to the documentation
 	 * I could find:
 	 *
-	 *	http://winpcap.polito.it/docs/man/html/Packet32_8c.html#a43
+	 *	http://www.winpcap.org/docs/man/html/Packet32_8c.html#a43
 	 *
 	 * this means that:
 	 *
@@ -588,7 +600,7 @@ cant_get_if_list_error_message(const char *err_str)
 	    strstr(err_str, "The operation completed successfully") != NULL) {
 		return g_strdup_printf("Can't get list of interfaces: %s\n"
 "This might be a problem with WinPcap 3.0; you should try updating to\n"
-"a later version of WinPcap - see the WinPcap site at winpcap.polito.it",
+"a later version of WinPcap - see the WinPcap site at www.winpcap.org",
 		    err_str);
 	}
 	return g_strdup_printf("Can't get list of interfaces: %s", err_str);
@@ -648,7 +660,9 @@ get_runtime_pcap_version(GString *str)
 						blankp = strchr(packetVer, ' ');
 						if (blankp != NULL)
 							*blankp = '\0';
-					}
+                    } else {
+				        packetVer = "version unknown";
+                    }
 					g_module_close(handle);
 				}
 			}
