@@ -1,7 +1,7 @@
 /* capture.c
  * Routines for packet capture
  *
- * $Id: capture.c 14246 2005-04-30 17:23:33Z ulfl $
+ * $Id: capture.c 14446 2005-05-26 21:45:58Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -69,6 +69,7 @@
 #include "capture-wpcap.h"
 #endif
 #include "ui_util.h"
+#include "log.h"
 
 
 
@@ -89,6 +90,8 @@ capture_start(capture_options *capture_opts)
   g_assert(capture_opts->state == CAPTURE_STOPPED);
   capture_opts->state = CAPTURE_PREPARING;
 
+  g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "Capture Start ...");
+
   /* try to start the capture child process */
   ret = sync_pipe_start(capture_opts);
   if(!ret) {
@@ -98,6 +101,13 @@ capture_start(capture_options *capture_opts)
       }
 
       capture_opts->state = CAPTURE_STOPPED;
+  } else {
+      /* the capture child might not respond shortly after bringing it up */
+      /* (especially it will block, if no input coming from an input capture pipe (e.g. mkfifo) is coming in) */
+
+      /* to prevent problems, bring the main GUI into "capture mode" right after successfully */
+      /* spawn/exec the capture child, without waiting for any response from it */
+      cf_callback_invoke(cf_cb_live_capture_prepared, capture_opts);
   }
 
   return ret;
@@ -107,6 +117,8 @@ capture_start(capture_options *capture_opts)
 void
 capture_stop(capture_options *capture_opts)
 {
+  g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "Capture Stop ...");
+
   /* stop the capture child gracefully */
   sync_pipe_stop(capture_opts);
 }
@@ -115,6 +127,8 @@ capture_stop(capture_options *capture_opts)
 void
 capture_restart(capture_options *capture_opts)
 {
+    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "Capture Restart");
+
     capture_opts->restart = TRUE;
     capture_stop(capture_opts);
 }
@@ -123,6 +137,8 @@ capture_restart(capture_options *capture_opts)
 void
 capture_kill_child(capture_options *capture_opts)
 {
+  g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_INFO, "Capture Kill");
+
   /* kill the capture child */
   sync_pipe_kill(capture_opts);
 }
@@ -218,8 +234,12 @@ capture_input_new_file(capture_options *capture_opts, gchar *new_file)
   int  err;
 
 
+  if(capture_opts->state == CAPTURE_PREPARING) {
+    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "Capture started!");
+  }
+  g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "File: \"%s\"", new_file);
+
   g_assert(capture_opts->state == CAPTURE_PREPARING || capture_opts->state == CAPTURE_RUNNING);
-  /*g_warning("New capture file: %s", new_file);*/
 
   /* free the old filename */
   if(capture_opts->save_file != NULL) {
@@ -310,6 +330,7 @@ capture_input_closed(capture_options *capture_opts)
     int  err;
 
 
+    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "Capture stopped!");
     g_assert(capture_opts->state == CAPTURE_PREPARING || capture_opts->state == CAPTURE_RUNNING);
 
     /* if we didn't started the capture (happens if an error occured), do a fake start */
