@@ -1,7 +1,7 @@
 /* capture_sync.c
  * Synchronisation between Ethereal capture parent and child instances
  *
- * $Id: capture_sync.c 14241 2005-04-30 15:39:40Z ulfl $
+ * $Id: capture_sync.c 14484 2005-05-30 04:46:25Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -87,6 +87,7 @@
 #include "capture-wpcap.h"
 #endif
 #include "ui_util.h"
+#include "log.h"
 
 #ifdef HAVE_IO_H
 # include <io.h>
@@ -108,7 +109,7 @@ static char *sync_pipe_signame(int);
 
 
 static gboolean sync_pipe_input_cb(gint source, gpointer user_data);
-static void sync_pipe_wait_for_child(capture_options *capture_opts, gboolean always_report);
+static void sync_pipe_wait_for_child(capture_options *capture_opts);
 
 /* Size of buffer to hold decimal representation of
    signed/unsigned 64-bit int */
@@ -228,21 +229,26 @@ sync_pipe_packet_count_to_parent(int packet_count)
 {
     char tmp[SP_DECISIZE+1+1];
 
-
     g_snprintf(tmp, sizeof(tmp), "%d", packet_count);
 
+    g_log(LOG_DOMAIN_CAPTURE_CHILD, G_LOG_LEVEL_DEBUG, "sync_pipe_packet_count_to_parent: %s", tmp);
+
     pipe_write_block(1, SP_PACKET_COUNT, strlen(tmp)+1, tmp);
 }
 
 void
 sync_pipe_filename_to_parent(const char *filename)
 {
+    g_log(LOG_DOMAIN_CAPTURE_CHILD, G_LOG_LEVEL_DEBUG, "sync_pipe_filename_to_parent: %s", filename);
+
     pipe_write_block(1, SP_FILE, strlen(filename)+1, filename);
 }
 
 void
 sync_pipe_errmsg_to_parent(const char *errmsg)
 {
+    g_log(LOG_DOMAIN_CAPTURE_CHILD, G_LOG_LEVEL_DEBUG, "sync_pipe_errmsg_to_parent: %s", errmsg);
+
     pipe_write_block(1, SP_ERROR_MSG, strlen(errmsg)+1, errmsg);
 }
 
@@ -254,6 +260,8 @@ sync_pipe_drops_to_parent(int drops)
 
     g_snprintf(tmp, sizeof(tmp), "%d", drops);
 
+    g_log(LOG_DOMAIN_CAPTURE_CHILD, G_LOG_LEVEL_DEBUG, "sync_pipe_drops_to_parent: %s", tmp);
+
     pipe_write_block(1, SP_DROPS, strlen(tmp)+1, tmp);
 }
 
@@ -264,6 +272,7 @@ static void
 signal_pipe_capquit_to_child(capture_options *capture_opts)
 {
 
+    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "signal_pipe_capquit_to_child");
 
     pipe_write_block(capture_opts->signal_pipe_fd, SP_QUIT, 0, NULL);
 }
@@ -324,10 +333,12 @@ sync_pipe_start(capture_options *capture_opts) {
     char sautostop_filesize[ARGV_NUMBER_LEN];
     char sautostop_duration[ARGV_NUMBER_LEN];
 #ifdef _WIN32
+    char buffer_size[ARGV_NUMBER_LEN];
     char sync_pipe_fd[ARGV_NUMBER_LEN];
     char signal_pipe_fd[ARGV_NUMBER_LEN];
     char *fontstring;
     char *filterstring;
+    char *savefilestring;
     int signal_pipe[2];                     /* pipe used to send messages from parent to child (currently only stop) */
 #else
     char errmsg[1024+1];
@@ -338,8 +349,10 @@ sync_pipe_start(capture_options *capture_opts) {
     int sync_pipe[2];                       /* pipe used to send messages from child to parent */
 
 
-    /*g_warning("sync_pipe_start");
-    capture_opts_info(capture_opts);*/
+    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "sync_pipe_start");
+#ifdef LOG_CAPTURE_VERBOSE
+    capture_opts_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, capture_opts);
+#endif
 
     capture_opts->fork_child = -1;
 
@@ -355,11 +368,6 @@ sync_pipe_start(capture_options *capture_opts) {
     argv = sync_pipe_add_arg(argv, &argc, "-i");
     argv = sync_pipe_add_arg(argv, &argc, capture_opts->iface);
 
-    if(capture_opts->save_file) {
-      argv = sync_pipe_add_arg(argv, &argc, "-w");
-      argv = sync_pipe_add_arg(argv, &argc, capture_opts->save_file);
-    }
-
     if (capture_opts->has_snaplen) {
       argv = sync_pipe_add_arg(argv, &argc, "-s");
       sprintf(ssnap,"%d",capture_opts->snaplen);
@@ -452,6 +460,10 @@ sync_pipe_start(capture_options *capture_opts) {
 
     capture_opts->signal_pipe_fd = signal_pipe[PIPE_WRITE];
 
+    argv = sync_pipe_add_arg(argv, &argc, "-B");
+    sprintf(buffer_size,"%d",capture_opts->buffer_size);
+    argv = sync_pipe_add_arg(argv, &argc, buffer_size);
+
     /* Convert font name to a quote-encapsulated string and pass to child */
     argv = sync_pipe_add_arg(argv, &argc, "-m");
     fontstring = sync_pipe_quote_encapsulate(prefs.PREFS_GUI_FONT_NAME);
@@ -475,12 +487,23 @@ sync_pipe_start(capture_options *capture_opts) {
       argv = sync_pipe_add_arg(argv, &argc, filterstring);
     }
 
+    /* Convert save file name to a quote delimited string and pass to child */
+    savefilestring = NULL;
+    if(capture_opts->save_file) {
+      argv = sync_pipe_add_arg(argv, &argc, "-w");
+      savefilestring = sync_pipe_quote_encapsulate(capture_opts->save_file);
+      argv = sync_pipe_add_arg(argv, &argc, savefilestring);
+    }
+
     /* Spawn process */
     capture_opts->fork_child = spawnvp(_P_NOWAIT, ethereal_path, argv);
     g_free(fontstring);
     if (filterstring) {
       g_free(filterstring);
     }
+    if(savefilestring) {
+      g_free(savefilestring);
+    }
 
     /* child own's the read side now, close our handle */
     close(signal_pipe[PIPE_READ]);
@@ -501,6 +524,11 @@ sync_pipe_start(capture_options *capture_opts) {
       argv = sync_pipe_add_arg(argv, &argc, capture_opts->cfilter);
     }
 
+    if(capture_opts->save_file) {
+      argv = sync_pipe_add_arg(argv, &argc, "-w");
+      argv = sync_pipe_add_arg(argv, &argc, capture_opts->save_file);
+    }
+
     if ((capture_opts->fork_child = fork()) == 0) {
       /*
        * Child process - run Ethereal with the right arguments to make
@@ -567,7 +595,6 @@ sync_pipe_start(capture_options *capture_opts) {
     return TRUE;
 }
 
-
 /* There's stuff to read from the sync pipe, meaning the child has sent
    us a message, or the sync pipe has closed, meaning the child has
    closed it (perhaps because it exited). */
@@ -583,10 +610,13 @@ sync_pipe_input_cb(gint source, gpointer user_data)
 
   nread = pipe_read_block(source, &indicator, BUFSIZE, buffer);
   if(nread <= 0) {
+    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "sync_pipe_input_cb: child has closed sync_pipe");
+
     /* The child has closed the sync pipe, meaning it's not going to be
        capturing any more packets.  Pick up its exit status, and
        complain if it did anything other than exit with status 0. */
-    sync_pipe_wait_for_child(capture_opts, FALSE);
+    sync_pipe_wait_for_child(capture_opts);
+
 #ifdef _WIN32
     close(capture_opts->signal_pipe_fd);
 #endif
@@ -597,6 +627,8 @@ sync_pipe_input_cb(gint source, gpointer user_data)
   switch(indicator) {
   case SP_FILE:
       if(!capture_input_new_file(capture_opts, buffer)) {
+        g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "sync_pipe_input_cb: file failed, closing capture");
+
         /* We weren't able to open the new capture file; user has been
            alerted. Close the sync pipe. */
         /* XXX - is it safe to close the pipe inside this callback? */
@@ -612,12 +644,16 @@ sync_pipe_input_cb(gint source, gpointer user_data)
       break;
   case SP_PACKET_COUNT:
     nread = atoi(buffer);
+    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "sync_pipe_input_cb: new packets %u", nread);
     capture_input_new_packets(capture_opts, nread);
     break;
   case SP_ERROR_MSG:
+    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_MESSAGE, "Error message from child: \"%s\"", buffer);
     simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, buffer);
+    /* the capture child will close the sync_pipe, nothing to do for now */
     break;
   case SP_DROPS:
+    g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_INFO, "%d packet%s dropped", atoi(buffer), plurality(atoi(buffer), "", "s"));
     cf_set_drops_known(capture_opts->cf, TRUE);
     cf_set_drops(capture_opts->cf, atoi(buffer));
     break;
@@ -632,11 +668,12 @@ sync_pipe_input_cb(gint source, gpointer user_data)
 
 /* the child process is going down, wait until it's completely terminated */
 static void
-sync_pipe_wait_for_child(capture_options *capture_opts, gboolean always_report)
+sync_pipe_wait_for_child(capture_options *capture_opts)
 {
   int  wstatus;
 
 
+  g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "sync_pipe_wait_for_child: wait till child closed");
   g_assert(capture_opts->fork_child != -1);
 
 #ifdef _WIN32
@@ -650,9 +687,13 @@ sync_pipe_wait_for_child(capture_options *capture_opts, gboolean always_report)
 #else
   if (wait(&wstatus) != -1) {
     if (WIFEXITED(wstatus)) {
-      /* The child exited; display its exit status, if it's not zero,
-         and even if it's zero if "always_report" is true. */
-      if (always_report || WEXITSTATUS(wstatus) != 0) {
+      /* The child exited; display its exit status, if it seems uncommon (0=ok, 1=error) */
+      /* the child will inform us about errors through the sync_pipe, which will popup */
+      /* an error message, so don't popup another one */
+
+      /* XXX - if there are situations where the child won't send us such an error message, */
+      /* this should be fixed in the child and not here! */
+      if (WEXITSTATUS(wstatus) != 0 && WEXITSTATUS(wstatus) != 1) {
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
 		      "Child capture process exited: exit status %d",
 		      WEXITSTATUS(wstatus));
@@ -679,6 +720,8 @@ sync_pipe_wait_for_child(capture_options *capture_opts, gboolean always_report)
   /* No more child process. */
   capture_opts->fork_child = -1;
 #endif
+
+  g_log(LOG_DOMAIN_CAPTURE, G_LOG_LEVEL_DEBUG, "sync_pipe_wait_for_child: capture child closed");
 }
 
 
