@@ -1,7 +1,7 @@
 /* column.c
  * Routines for handling column preferences
  *
- * $Id: column.c 13999 2005-04-01 10:17:05Z sahlberg $
+ * $Id: column.c 15015 2005-07-23 11:41:25Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -46,16 +46,18 @@
 
 /* Given a format number (as defined in packet.h), returns its equivalent
    string */
-gchar *
+const gchar *
 col_format_to_string(gint fmt) {
-  gchar *slist[] = { "%m", "%t", "%Rt", "%At", "%Yt", "%Tt", "%s", "%rs",
-                     "%us","%hs", "%rhs", "%uhs", "%ns", "%rns", "%uns", "%d",
-                     "%rd", "%ud", "%hd", "%rhd", "%uhd", "%nd", "%rnd",
-                     "%und", "%S", "%rS", "%uS", "%D", "%rD", "%uD", "%p",
-                     "%i", "%L", "%B", "%XO", "%XR", "%I", "%c", "%Xs", 
-                     "%Xd", "%V", "%x", "%e", "%H", "%P" };
+  const gchar *slist[] = {
+	"%m", "%t", "%Rt", "%At", "%Yt", "%Tt", "%s", "%rs",
+	"%us","%hs", "%rhs", "%uhs", "%ns", "%rns", "%uns", "%d",
+	"%rd", "%ud", "%hd", "%rhd", "%uhd", "%nd", "%rnd",
+	"%und", "%S", "%rS", "%uS", "%D", "%rD", "%uD", "%p",
+	"%i", "%L", "%B", "%XO", "%XR", "%I", "%c", "%Xs", 
+	"%Xd", "%V", "%x", "%e", "%H", "%P", "%y"
+};
                      
-  if (fmt < 0 || fmt > NUM_COL_FMTS)
+  if (fmt < 0 || fmt >= NUM_COL_FMTS)
     return NULL;
 
   return(slist[fmt]);
@@ -63,9 +65,9 @@ col_format_to_string(gint fmt) {
 
 /* Given a format number (as defined in packet.h), returns its
   description */
-static gchar *dlist[NUM_COL_FMTS] = {
+static const gchar *dlist[NUM_COL_FMTS] = {
 	"Number",
-	"Time (command line specified)",
+	"Time (format as specified)",
 	"Relative time",
 	"Absolute time",
 	"Absolute date and time",
@@ -98,20 +100,21 @@ static gchar *dlist[NUM_COL_FMTS] = {
 	"Information",
 	"Packet length (bytes)" ,
 	"Cumulative Bytes" ,
-	"OXID",
-	"RXID",
+	"Fibre Channel OXID",
+	"Fibre Channel RXID",
 	"FW-1 monitor if/direction",
 	"Circuit ID",
-	"Src PortIdx",
-	"Dst PortIdx",
-	"VSAN",
+	"Cisco Src PortIdx",
+	"Cisco Dst PortIdx",
+	"Cisco VSAN",
 	"IEEE 802.11 TX rate",
 	"IEEE 802.11 RSSI",
 	"HP-UX Subsystem",
 	"HP-UX Device ID",
+	"DCE/RPC call (cn_call_id / dg_seqnum)",
 };
 
-gchar *
+const gchar *
 col_format_desc(gint fmt) {
   g_assert((fmt >= 0) && (fmt < NUM_COL_FMTS));
   return(dlist[fmt]);
@@ -203,6 +206,9 @@ get_column_format_matches(gboolean *fmt_list, gint format) {
     case COL_HPUX_DEVID:
       fmt_list[COL_HPUX_DEVID] = TRUE;
       break;
+    case COL_DCE_CALL:
+      fmt_list[COL_DCE_CALL] = TRUE;
+      break;
     default:
       break;
   }
@@ -220,7 +226,7 @@ get_column_format_matches(gboolean *fmt_list, gint format) {
    is done, and given that the width for COL...SRC and COL...DST columns
    is somewhat arbitrary in any case.  We should probably clean
    that up eventually, though. */
-char *
+const char *
 get_column_longest_string(gint format)
 {
   switch (format) {
@@ -277,7 +283,7 @@ get_column_longest_string(gint format)
       return "Protocol";	/* not the longest, but the longest is too long */
       break;
     case COL_PACKET_LENGTH:
-      return "000000";
+      return "00000";
       break;
     case COL_CUMULATIVE_BYTES:
       return "00000000";
@@ -311,6 +317,9 @@ get_column_longest_string(gint format)
     case COL_HPUX_DEVID:
       return "0000";
       break;
+    case COL_DCE_CALL:
+      return "0000";
+      break;
     default: /* COL_INFO */
       return "Source port: kerberos-master  Destination port: kerberos-master";
       break;
@@ -454,6 +463,9 @@ get_column_format_from_str(gchar *str) {
       case 'P':
 	return COL_HPUX_DEVID;
 	break;
+      case 'y':
+	return COL_DCE_CALL;
+	break;
     }
     cptr++;
   }
