@@ -1,5 +1,5 @@
 /*
- * $Id: dfilter.c,v 1.18 2004/06/16 07:33:46 guy Exp $
+ * $Id: dfilter.c 15013 2005-07-23 06:53:59Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -53,7 +53,7 @@ int     df_lex(void);
 static void*	ParserObj = NULL;
 
 void
-dfilter_fail(char *format, ...)
+dfilter_fail(const char *format, ...)
 {
 	va_list	args;
 
