@@ -1,5 +1,5 @@
 /*
- * $Id: semcheck.c,v 1.28 2004/06/15 10:16:10 guy Exp $
+ * $Id: semcheck.c 15012 2005-07-23 06:51:57Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -27,6 +27,7 @@
 #include <string.h>
 
 #include "dfilter-int.h"
+#include "semcheck.h"
 #include "syntax-tree.h"
 #include "sttype-range.h"
 #include "sttype-test.h"
@@ -73,7 +74,8 @@ compatible_ftypes(ftenum_t a, ftenum_t b)
 		case FT_ETHER:
 		case FT_BYTES:
 		case FT_UINT_BYTES:
-			return (b == FT_ETHER || b == FT_BYTES || b == FT_UINT_BYTES);
+		case FT_GUID:
+			return (b == FT_ETHER || b == FT_BYTES || b == FT_UINT_BYTES || b == FT_GUID);
 
 		case FT_BOOLEAN:
 		case FT_FRAMENUM:
@@ -164,6 +166,7 @@ mk_fvalue_from_val_string(header_field_info *hfinfo, char *s)
 		case FT_UINT64:
 		case FT_INT64:
 		case FT_PCRE:
+		case FT_GUID:
 			return FALSE;
 
 		case FT_BOOLEAN:
@@ -233,6 +236,7 @@ is_bytes_type(enum ftenum type)
 		case FT_BYTES:
 		case FT_UINT_BYTES:
 		case FT_IPv6:
+		case FT_GUID:
 			return TRUE;
 
 		case FT_NONE:
