@@ -1,5 +1,5 @@
 /*
- * $Id: syntax-tree.c 11400 2004-07-18 00:24:25Z guy $
+ * $Id: syntax-tree.c 15011 2005-07-23 06:49:07Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -29,13 +29,6 @@
 /* Keep track of sttype_t's via their sttype_id_t number */
 static sttype_t* type_list[STTYPE_NUM_TYPES];
 
-/* These are the sttype_t registration function prototypes. */
-void sttype_register_integer(void);
-void sttype_register_pointer(void);
-void sttype_register_range(void);
-void sttype_register_string(void);
-void sttype_register_test(void);
-
 
 #define STNODE_MAGIC	0xe9b00b9e
 
