@@ -4,7 +4,7 @@
  * Copyright 2004, Jelmer Vernooij <jelmer@samba.org>
  * Copyright 2004, Devin Heitmueller <dheitmueller@netilla.com>
  *
- * $Id: packet-aim.c 13955 2005-03-28 15:55:47Z gerald $
+ * $Id: packet-aim.c 15027 2005-07-24 02:43:41Z sahlberg $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -666,7 +666,8 @@ static void dissect_aim_newconn(tvbuff_t *tvb, packet_info *pinfo,
 int dissect_aim_snac_error(tvbuff_t *tvb, packet_info *pinfo, 
 			     proto_tree *aim_tree)
 {
-  char *name;
+  const char *name;
+
   if ((name = match_strval(tvb_get_ntohs(tvb, 0), aim_snac_errors)) != NULL) {
      if (check_col(pinfo->cinfo, COL_INFO))
 		col_add_fstr(pinfo->cinfo, COL_INFO, name);
@@ -681,12 +682,12 @@ int dissect_aim_snac_error(tvbuff_t *tvb, packet_info *pinfo,
 int dissect_aim_userinfo(tvbuff_t *tvb, packet_info *pinfo, 
 				 int offset, proto_tree *tree) 
 {
-	offset = dissect_aim_buddyname(tvb, pinfo, offset, tree);
+    offset = dissect_aim_buddyname(tvb, pinfo, offset, tree);
 
     proto_tree_add_item(tree, hf_aim_userinfo_warninglevel, tvb, offset, 2, FALSE);
     offset += 2;
 
-	return dissect_aim_tlv_list(tvb, pinfo, offset, tree, onlinebuddy_tlvs);
+    return dissect_aim_tlv_list(tvb, pinfo, offset, tree, onlinebuddy_tlvs);
 }
 
 int dissect_aim_fnac_flags(tvbuff_t *tvb, int offset, int len, proto_item *ti, guint16 flags)
@@ -1008,11 +1009,6 @@ const aim_client_capability *aim_find_capability ( e_uuid_t clsid)
 	return NULL;
 }
 
-int dissect_aim_tlv_value_capability_data ( proto_item *ti _U_, guint16 valueid _U_, tvbuff_t *tvb _U_, packet_info *pinfo _U_)
-{
-	return 0;
-}
-
 int dissect_aim_capability(proto_tree *entry, tvbuff_t *tvb, int offset)
 {
 	const aim_client_capability *caps = NULL;
@@ -1118,9 +1114,8 @@ int dissect_aim_tlv_value_string (proto_item *ti, guint16 valueid _U_, tvbuff_t
    gint string_len;
 
    string_len = tvb_length(tvb);
-   buf = tvb_get_string(tvb, 0, string_len);
+   buf = ep_tvb_get_string(tvb, 0, string_len);
    proto_item_set_text(ti, "Value: %s", format_text(buf, string_len));
-   g_free(buf);
    return string_len;
 }
 
@@ -1209,14 +1204,13 @@ int dissect_aim_tlv_value_messageblock (proto_item *ti, guint16 valueid _U_, tvb
     offset += 2;
 
     /* The actual message */
-    buf = tvb_get_string(tvb, offset, blocklen - 4 );
+    buf = ep_tvb_get_string(tvb, offset, blocklen - 4 );
     proto_item_set_text(ti, "Message: %s",
                         format_text(buf, blocklen - 4));
     proto_tree_add_item(entry, hf_aim_messageblock_message, tvb, offset, 
 			blocklen-4,
 			FALSE);
     offset += tvb_length_remaining(tvb, offset);
-    g_free(buf);
   }
 
   return offset;
