@@ -6,7 +6,7 @@
  * Copyright 2003, Michael Lum <mlum [AT] telostech.com>
  * In association with Telos Technology Inc.
  *
- * $Id: packet-alcap.c 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-alcap.c 15030 2005-07-24 02:59:17Z lego $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -46,6 +46,7 @@
 #include <string.h>
 
 #include "epan/packet.h"
+#include <epan/emem.h>
 
 
 #define	ALCAP_MSG_HEADER_LEN	6
@@ -115,8 +116,8 @@ static int hf_alcap_organizational_unique_id = -1;
 static int hf_alcap_served_user_gen_ref = -1;
 static int hf_alcap_nsap_address = -1;
 
-static char bigbuf[1024];
-static char bigbuf2[1024];
+static char* bigbuf;
+static char* bigbuf2;
 static dissector_handle_t data_handle;
 static packet_info *g_pinfo;
 static proto_tree *g_tree;
@@ -183,25 +184,6 @@ static const value_string msg_type_strings[] = {
 
 /* FUNCTIONS */
 
-static gchar *
-my_match_strval(guint32 val, const value_string *vs, gint *idx)
-{
-    gint i = 0;
-
-    while (vs[i].strptr) {
-	if (vs[i].value == val)
-	{
-	    *idx = i;
-	    return(vs[i].strptr);
-	}
-
-	i++;
-    }
-
-    *idx = -1;
-    return(NULL);
-}
-
 /*
  * Ref. ITU-T Q.2630.1 (12/1999)
  * Section 7.4.1
@@ -340,11 +322,14 @@ dis_field_signalling_assoc_id(tvbuff_t *tvb, proto_tree *tree, guint *len, guint
 
     value = tvb_get_ntohl(tvb, curr_offset);
 
-    if (destination)
+	if (value && check_col(g_pinfo->cinfo, COL_INFO))
+		col_append_fstr(g_pinfo->cinfo, COL_INFO, " SA: %u", value);
+
+	if (destination)
     {
 	proto_tree_add_uint_format(tree, hf_alcap_dsaid, tvb,
 	    curr_offset, FIELD_SIGNALLING_ASSOC_ID_LEN, value,
-	    "Destination signalling association identifier: %d%s",
+	    "Destination signalling association identifier: %u%s",
 	    value,
 	    value ? "" : " (unknown)");
     }
@@ -378,6 +363,9 @@ dis_field_aal2_path_id(tvbuff_t *tvb, proto_tree *tree, guint *len, guint32 *off
 
     value = tvb_get_ntohl(tvb, curr_offset);
 
+	if (value && check_col(g_pinfo->cinfo, COL_INFO))
+		col_append_fstr(g_pinfo->cinfo, COL_INFO, " PathId: %u", value);
+
     proto_tree_add_uint_format(tree, hf_alcap_aal2_path_id, tvb,
 	curr_offset, FIELD_AAL2_PATH_ID_LEN, value,
 	"AAL2 path identifier: %d%s",
@@ -406,6 +394,9 @@ dis_field_channel_id(tvbuff_t *tvb, proto_tree *tree, guint *len, guint32 *offse
 
     oct = tvb_get_guint8(tvb, curr_offset);
 
+	if (oct && check_col(g_pinfo->cinfo, COL_INFO))
+		col_append_fstr(g_pinfo->cinfo, COL_INFO, " CID: %u", oct);
+
     proto_tree_add_uint_format(tree, hf_alcap_channel_id, tvb,
 	curr_offset, 1, oct,
 	"Channel identifier (CID): %d%s",
@@ -803,6 +794,9 @@ dis_field_served_user_gen_ref(tvbuff_t *tvb, proto_tree *tree, guint *len, guint
 
     value = tvb_get_ntohl(tvb, curr_offset);
 
+	if (value && check_col(g_pinfo->cinfo, COL_INFO))
+		col_append_fstr(g_pinfo->cinfo, COL_INFO, " SUGR: %u", value);
+
     proto_tree_add_uint(tree, hf_alcap_served_user_gen_ref, tvb,
 	curr_offset, FIELD_SERVED_USER_GEN_REF_LEN, value);
 
@@ -1029,6 +1023,9 @@ dis_field_e164_address(tvbuff_t *tvb, proto_tree *tree, guint *len, guint32 *off
 
 	bigbuf2[i] = '\0';
 
+	if (check_col(g_pinfo->cinfo, COL_INFO))
+		col_append_fstr(g_pinfo->cinfo, COL_INFO, " E164: %s", bigbuf2);
+
 	proto_item_append_text(item, " (%s)", bigbuf2);
     }
 
@@ -1044,7 +1041,7 @@ static void
 dis_field_nsap_address(tvbuff_t *tvb, proto_tree *tree, guint *len, guint32 *offset)
 {
     guint32	curr_offset;
-
+	
     curr_offset = *offset;
 
 #define	FIELD_NSAP_ADDRESS_LEN	20
@@ -1052,7 +1049,7 @@ dis_field_nsap_address(tvbuff_t *tvb, proto_tree *tree, guint *len, guint32 *off
     SHORT_DATA_CHECK(*len, FIELD_NSAP_ADDRESS_LEN);
 
     proto_tree_add_item(tree, hf_alcap_nsap_address, tvb,
-	curr_offset, FIELD_NSAP_ADDRESS_LEN, FALSE);
+						curr_offset, FIELD_NSAP_ADDRESS_LEN,FALSE);
 
     curr_offset += FIELD_NSAP_ADDRESS_LEN;
 
@@ -1167,7 +1164,7 @@ dis_field_diagnostics(tvbuff_t *tvb, proto_tree *tree, guint *len, guint32 *offs
     proto_item	*item;
     proto_tree	*subtree;
     guint8	parm_len;
-    gchar	*str = NULL;
+    const gchar	*str = NULL;
     gint	idx;
     guint8	i;
 
@@ -1198,7 +1195,7 @@ dis_field_diagnostics(tvbuff_t *tvb, proto_tree *tree, guint *len, guint32 *offs
 	     */
 	    oct = tvb_get_guint8(tvb, curr_offset);
 
-	    str = my_match_strval(oct, msg_type_strings, &idx);
+	    str = match_strval_idx(oct, msg_type_strings, &idx);
 
 	    proto_tree_add_none_format(subtree, hf_alcap_none, tvb,
 		curr_offset, 1, (str == NULL) ? "Unknown message identifier" : str);
@@ -1210,7 +1207,7 @@ dis_field_diagnostics(tvbuff_t *tvb, proto_tree *tree, guint *len, guint32 *offs
 	    {
 		oct = tvb_get_guint8(tvb, curr_offset);
 
-		str = my_match_strval(oct, msg_parm_strings, &idx);
+		str = match_strval_idx(oct, msg_parm_strings, &idx);
 
 		proto_tree_add_none_format(subtree, hf_alcap_none, tvb,
 		    curr_offset, 1, (str == NULL) ? "Unknown parameter" : str);
@@ -1496,7 +1493,7 @@ dissect_alcap_parms(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint32 len
     guint8	parm_len;
     guint32	curr_offset, saved_offset;
     gint	idx;
-    gchar	*str = NULL;
+    const gchar	*str = NULL;
     proto_item	*item;
     proto_tree	*subtree;
     gint	ett_parm_idx;
@@ -1506,59 +1503,59 @@ dissect_alcap_parms(tvbuff_t *tvb, proto_tree *tree, guint32 offset, guint32 len
 
     while (len >= ALCAP_PARM_HEADER_LEN)
     {
-	saved_offset = curr_offset;
-
-	parm = tvb_get_guint8(tvb, curr_offset);
-
-	str = my_match_strval(parm, msg_parm_strings, &idx);
-
-	if (str == NULL)
-	{
-	    ett_parm_idx = ett_parm;
-	    parm_fcn = NULL;
-	}
-	else
-	{
-	    ett_parm_idx = ett_parms[idx];
-	    parm_fcn = alcap_parm_fcn[idx];
-	}
-
-	item =
-	    proto_tree_add_none_format(tree, hf_alcap_none, tvb,
-		curr_offset, -1, (str == NULL) ? "Unknown parameter" : str);
-
-	subtree = proto_item_add_subtree(item, ett_parm_idx);
-
-	proto_tree_add_uint(subtree, hf_alcap_parm_id, tvb,
-	    curr_offset, 1, parm);
-
-	curr_offset++;
-
-	dis_field_compatibility(tvb, subtree, &curr_offset, FALSE);
-
-	parm_len = tvb_get_guint8(tvb, curr_offset);
-
-	proto_tree_add_uint(subtree, hf_alcap_length, tvb, curr_offset, 1, parm_len);
-
-	curr_offset++;
-
-	proto_item_set_len(item, (curr_offset - saved_offset) + parm_len);
-
-	if (parm_len > 0)
-	{
-	    if (parm_fcn == NULL)
-	    {
-		proto_tree_add_none_format(subtree, hf_alcap_none,
-		    tvb, curr_offset, parm_len, "Parameter data");
-	    }
-	    else
-	    {
-		(*parm_fcn)(tvb, subtree, parm_len, curr_offset);
-	    }
-	}
-
-	len -= (ALCAP_PARM_HEADER_LEN + parm_len);
-	curr_offset += parm_len;
+		saved_offset = curr_offset;
+		
+		parm = tvb_get_guint8(tvb, curr_offset);
+		
+		str = match_strval_idx(parm, msg_parm_strings, &idx);
+		
+		if (str == NULL)
+		{
+			ett_parm_idx = ett_parm;
+			parm_fcn = NULL;
+		}
+		else
+		{
+			ett_parm_idx = ett_parms[idx];
+			parm_fcn = alcap_parm_fcn[idx];
+		}
+		
+		item = proto_tree_add_none_format(tree, hf_alcap_none, tvb,
+										  curr_offset, -1,
+										  (str == NULL) ? "Unknown parameter" : str);
+		
+		subtree = proto_item_add_subtree(item, ett_parm_idx);
+		
+		proto_tree_add_uint(subtree, hf_alcap_parm_id, tvb,
+							curr_offset, 1, parm);
+		
+		curr_offset++;
+		
+		dis_field_compatibility(tvb, subtree, &curr_offset, FALSE);
+		
+		parm_len = tvb_get_guint8(tvb, curr_offset);
+		
+		proto_tree_add_uint(subtree, hf_alcap_length, tvb, curr_offset, 1, parm_len);
+		
+		curr_offset++;
+		
+		proto_item_set_len(item, (curr_offset - saved_offset) + parm_len);
+		
+		if (parm_len > 0)
+		{
+			if (parm_fcn == NULL)
+			{
+				proto_tree_add_none_format(subtree, hf_alcap_none,
+										   tvb, curr_offset, parm_len, "Parameter data");
+			}
+			else
+			{
+				(*parm_fcn)(tvb, subtree, parm_len, curr_offset);
+			}
+		}
+		
+		len -= (ALCAP_PARM_HEADER_LEN + parm_len);
+		curr_offset += parm_len;
     }
 
     EXTRANEOUS_DATA_CHECK(len, 0);
@@ -1572,7 +1569,7 @@ dissect_alcap_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *alcap_tree)
     guint32	offset;
     guint8	msg_type;
     gint	idx;
-    gchar	*str = NULL;
+    const gchar	*str = NULL;
 
     offset = 0;
 
@@ -1591,7 +1588,7 @@ dissect_alcap_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *alcap_tree)
 
     msg_type = tvb_get_guint8(tvb, offset);
 
-    str = my_match_strval(msg_type, msg_type_strings, &idx);
+    str = match_strval_idx(msg_type, msg_type_strings, &idx);
 
     if (str == NULL)
     {
@@ -1625,6 +1622,9 @@ dissect_alcap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_item	*alcap_item;
     proto_tree	*alcap_tree = NULL;
 
+	bigbuf = ep_alloc(1024);
+	bigbuf2 = ep_alloc(1024);
+	
     g_pinfo = pinfo;
 
     /*
@@ -1652,8 +1652,10 @@ dissect_alcap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	alcap_tree =
 	    proto_item_add_subtree(alcap_item, ett_alcap);
 
-	dissect_alcap_message(tvb, pinfo, alcap_tree);
     }
+	
+	dissect_alcap_message(tvb, pinfo, alcap_tree);
+
 }
 
 
@@ -1685,31 +1687,31 @@ proto_register_alcap(void)
 	},
 	{ &hf_alcap_aal2_path_id,
 	  { "AAL2 path identifier",
-	    "alcap.aal2_path_id",
+	    "alcap.path_id",
 	    FT_UINT32, BASE_DEC, NULL, 0,
 	    "", HFILL }
 	},
 	{ &hf_alcap_channel_id,
 	  { "Channel identifier (CID)",
-	    "alcap.channel_id",
+	    "alcap.cid",
 	    FT_UINT32, BASE_DEC, NULL, 0,
 	    "", HFILL }
 	},
 	{ &hf_alcap_organizational_unique_id,
 	  { "Organizational unique identifier (OUI)",
-	    "alcap.organizational_unique_id",
+	    "alcap.oui",
 	    FT_UINT24, BASE_DEC, NULL, 0,
 	    "", HFILL }
 	},
 	{ &hf_alcap_served_user_gen_ref,
 	  { "Served user generated reference",
-	    "alcap.served_user_gen_ref",
+	    "alcap.sugr",
 	    FT_UINT32, BASE_DEC, NULL, 0,
 	    "", HFILL }
 	},
 	{ &hf_alcap_nsap_address,
 	  { "NSAP address",
-	    "alcap.nsap_address",
+	    "alcap.nsap",
 	    FT_BYTES, BASE_NONE, NULL, 0,
 	    "", HFILL }
 	},
@@ -1755,6 +1757,8 @@ proto_register_alcap(void)
     proto_alcap =
 	proto_register_protocol(alcap_proto_name, alcap_proto_name_short, "alcap");
 
+	register_dissector("alcap", dissect_alcap, proto_alcap);
+	
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_alcap, hf, array_length(hf));
     proto_register_subtree_array(ett, array_length(ett));
