@@ -1,7 +1,7 @@
 /* packet-arp.c
  * Routines for ARP packet disassembly (RFC 826)
  *
- * $Id: packet-arp.c 12839 2004-12-26 22:26:02Z guy $
+ * $Id: packet-arp.c 14786 2005-06-26 19:56:52Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -257,7 +257,7 @@ static const value_string hrd_vals[] = {
   {ARPHRD_EUI_64,   "EUI-64"               },
   {0,                NULL                  } };
 
-gchar *
+const gchar *
 arphrdtype_to_str(guint16 hwtype, const char *fmt) {
     return val_to_str(hwtype, hrd_vals, fmt);
 }
@@ -389,7 +389,7 @@ dissect_atmarp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   int         tot_len;
   proto_tree  *arp_tree;
   proto_item  *ti;
-  gchar       *op_str;
+  const gchar *op_str;
   int         sha_offset, ssa_offset, spa_offset;
   int         tha_offset, tsa_offset, tpa_offset;
   const guint8      *sha_val, *ssa_val, *spa_val;
@@ -637,7 +637,7 @@ dissect_arp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   int         tot_len;
   proto_tree  *arp_tree;
   proto_item  *ti;
-  gchar       *op_str;
+  const gchar *op_str;
   int         sha_offset, spa_offset, tha_offset, tpa_offset;
   const guint8      *sha_val, *spa_val, *tha_val, *tpa_val;
   gboolean    is_gratuitous;
@@ -726,9 +726,14 @@ dissect_arp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     /* Add target address if target MAC address is neither a broadcast/
        multicast address nor an all-zero address and if target IP address
        isn't all zeroes. */
+       
+    /* Do not add target address if the packet is a Request. According to the RFC,
+       target addresses in requests have no meaning */
+       
     tvb_memcpy(tvb, (guint8 *)&ip, tpa_offset, sizeof(ip));
     mac = tvb_get_ptr(tvb, tha_offset, 6);
-    if ((mac[0] & 0x01) == 0 && memcmp(mac, mac_allzero, 6) != 0 && ip != 0)
+    if ((mac[0] & 0x01) == 0 && memcmp(mac, mac_allzero, 6) != 0 && ip != 0 
+      && ar_op != ARPOP_REQUEST)
       add_ether_byip(ip, mac);
   }
 
