@@ -2,7 +2,7 @@
  * Routines for AppleTalk packet disassembly: LLAP, DDP, NBP, ATP, ASP,
  * RTMP.
  *
- * $Id: packet-atalk.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-atalk.c 15027 2005-07-24 02:43:41Z sahlberg $
  *
  * Simon Wilkinson <sxw@dcs.ed.ac.uk>
  *
@@ -41,7 +41,7 @@
 #include <epan/conversation.h>
 
 #include <epan/prefs.h>
-#include "reassemble.h"
+#include <epan/reassemble.h>
 
 #include "packet-afp.h"
 
@@ -518,14 +518,13 @@ static int dissect_pascal_string(tvbuff_t *tvb, int offset, proto_tree *tree,
 		 * code, we could perhaps avoid allocating and freeing
 		 * this string buffer.
 		 */
-		tmp = tvb_get_string(tvb, offset, len);
+		tmp = ep_tvb_get_string(tvb, offset, len);
 		item = proto_tree_add_string(tree, hf_index, tvb, offset-1, len+1, tmp);
 
 		subtree = proto_item_add_subtree(item, ett_pstring);
 		proto_tree_add_text(subtree, tvb, offset-1, 1, "Length: %d", len);
 		proto_tree_add_text(subtree, tvb, offset, len, "Data: %s", tmp);
 
-		g_free(tmp);
 	}
 	offset += len;
 
@@ -759,12 +758,12 @@ dissect_atp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
   aspinfo.code = 0;
   query = (!aspinfo.reply && !aspinfo.release);
 
-  conversation = find_conversation(&pinfo->src, &pinfo->dst, pinfo->ptype,
+  conversation = find_conversation(pinfo->fd->num, &pinfo->src, &pinfo->dst, pinfo->ptype,
 		pinfo->srcport, pinfo->destport, 0);
 
   if (conversation == NULL)
   {
-	conversation = conversation_new(&pinfo->src, &pinfo->dst,
+	conversation = conversation_new(pinfo->fd->num, &pinfo->src, &pinfo->dst,
 			pinfo->ptype, pinfo->srcport, pinfo->destport, 0);
   }
 
@@ -1053,9 +1052,8 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 				break;
 			case 4: /* DNS */
 				if (len > 2) {
-					tmp = tvb_get_string(tvb, ofs +2, len -2);
+					tmp = ep_tvb_get_string(tvb, ofs +2, len -2);
 					ti = proto_tree_add_text(adr_tree, tvb, ofs, len, "dns %s", tmp);
-					g_free(tmp);
 					break;
 				}
 				/* else fall to default malformed record */
@@ -1092,14 +1090,13 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 
 		ofs = utf_ofs;
 		ulen = tvb_get_ntohs(tvb, ofs);
-		tmp = tvb_get_string(tvb, ofs + 2, ulen);
+		tmp = ep_tvb_get_string(tvb, ofs + 2, ulen);
 		ti = proto_tree_add_text(tree, tvb, ofs, ulen +2, "UTF8 server name: %s", tmp);
 		sub_tree = proto_item_add_subtree(ti, ett_asp_utf8_name);
 		proto_tree_add_uint(sub_tree, hf_asp_server_utf8_name_len, tvb, ofs, 2, ulen);
 		ofs += 2;		
 		proto_tree_add_string(sub_tree, hf_asp_server_utf8_name, tvb, ofs, ulen, tmp);
 		ofs += ulen;
-		g_free(tmp);
 	}
 	/* FIXME: offset is not updated */
 	return offset;
@@ -1117,12 +1114,12 @@ get_transaction(tvbuff_t *tvb, packet_info *pinfo)
   asp_request_val *request_val;
   guint8 fn;
 
-  conversation = find_conversation(&pinfo->src, &pinfo->dst, pinfo->ptype,
+  conversation = find_conversation(pinfo->fd->num, &pinfo->src, &pinfo->dst, pinfo->ptype,
 		pinfo->srcport, pinfo->destport, 0);
 
   if (conversation == NULL)
   {
-	conversation = conversation_new(&pinfo->src, &pinfo->dst,
+	conversation = conversation_new(pinfo->fd->num, &pinfo->src, &pinfo->dst,
 			pinfo->ptype, pinfo->srcport, pinfo->destport, 0);
   }
 
