@@ -1286,11 +1286,10 @@ fVTCloseError(tvbuff_t *tvb, proto_tree *tree, guint offset);
  * @param tree 
  * @param offset 
  * @param label 
- * @param src
  * @return modified offset
  */
 static guint
-fApplicationTypes   (tvbuff_t *tvb, proto_tree *tree, guint offset, guint8 *label, const value_string *src);
+fApplicationTypes   (tvbuff_t *tvb, proto_tree *tree, guint offset, guint8 *label);
 
 /**
  * BACnetActionCommand ::= SEQUENCE {
@@ -1376,31 +1375,6 @@ fCalendaryEntry (tvbuff_t *tvb, proto_tree *tree, guint offset);
 static guint
 fClientCOV (tvbuff_t *tvb, proto_tree *tree, guint offset);
 
-/**
- * BACnetCOVSubscription ::= SEQUENCE {
- *  Recipient                   [0] BACnetRecipientProcess,
- *  MOnitoredPropertyReference  [1] BACnetObjectPropertyReference,
- *  IssueConfirmedNotifications [2] BOOLEAN,
- *  TimeRemaining               [3] Unsigned,
- * 	COVIncrement                [4] REAL,
- * }
- * @param tvb 
- * @param tree 
- * @param offset 
- * @return modified offset
- */
-static guint
-fCOVSubscription (tvbuff_t *tvb, proto_tree *tree, guint offset);
-
-/**
- * BACnetDailySchedule ::= SEQUENCE {
- *  day-schedule    [0] SENQUENCE OF BACnetTimeValue
- * }
- * @param tvb 
- * @param tree 
- * @param offset 
- * @return modified offset
- */
 static guint
 fDailySchedule (tvbuff_t *tvb, proto_tree *tree, guint offset);
 
@@ -1933,7 +1907,7 @@ fTimeSpan (tvbuff_t *tvb, proto_tree *tree, guint offset, guint8 *label);
  * @return modified offset
  */
 static guint
-fPropertyIdentifier (tvbuff_t *tvb, proto_tree *tree, guint offset, proto_item **tt);
+fPropertyIdentifier (tvbuff_t *tvb, proto_tree *tree, guint offset);
 
 /**
  * listOfEventSummaries ::= SEQUENCE OF SEQUENCE {
@@ -2042,7 +2016,7 @@ proto_reg_handoff_bacapp(void);
  * @return count of modified characters of returned string, -1 for errors
  */
 guint32
-fConvertXXXtoUTF8(guint8 *in, guint32 *inbytesleft,guint8 *out, guint32 *outbytesleft, guint8 *fromcoding);
+fConvertXXXtoUTF8(const guint8 *in, size_t *inbytesleft,guint8 *out, size_t *outbytesleft, guint8 *fromcoding);
 
 #endif /* __BACAPP_H__ */
 
