@@ -1,7 +1,7 @@
 /* packet-beep.c
  * Routines for BEEP packet disassembly
  *
- * $Id: packet-beep.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-beep.c 14884 2005-07-09 00:53:17Z guy $
  *
  * Copyright (c) 2000 by Richard Sharpe <rsharpe@ns.aus.com>
  * Modified 2001 Darren New <dnew@invisible.net> for BEEP.
@@ -47,7 +47,7 @@
 void proto_reg_handoff_beep(void);
 
 
-static int global_beep_tcp_port = TCP_PORT_BEEP;
+static guint global_beep_tcp_port = TCP_PORT_BEEP;
 static int global_beep_strict_term = TRUE;
 
 static int proto_beep = -1;
@@ -96,7 +96,7 @@ static int ett_mime_header = -1;
 static int ett_header = -1;
 static int ett_trailer = -1;
 
-static unsigned int tcp_port = 0;
+static guint tcp_port = 0;
 
 /* Get the state of the more flag ... */
 
@@ -870,10 +870,10 @@ dissect_beep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   if (!frame_data) {
 
-    conversation = find_conversation(&pinfo->src, &pinfo->dst, pinfo->ptype,
+    conversation = find_conversation(pinfo->fd->num, &pinfo->src, &pinfo->dst, pinfo->ptype,
 				       pinfo->srcport, pinfo->destport, 0);
     if (conversation == NULL) { /* No conversation, create one */
-	conversation = conversation_new(&pinfo->src, &pinfo->dst, pinfo->ptype,
+	conversation = conversation_new(pinfo->fd->num, &pinfo->src, &pinfo->dst, pinfo->ptype,
 					pinfo->srcport, pinfo->destport, 0);
 
       }
