@@ -1,12 +1,25 @@
-/* #define DEBUG_BER 1 */
+/*#define DEBUG_BER 1 */
 /* TODO: change #.REGISTER signature to new_dissector_t and
  * update call_ber_oid_callback() accordingly.
+ *
+ * Since we dont pass the TAG/LENGTH from the CHOICE/SEQUENCE/SEQUENCE OF/
+ * SET OF helpers through the callbacks to the next pabket-ber helper
+ * when the tags are IMPLICIT, this causes a problem when we also have
+ * indefinite length at the same time as the tags are implicit.
+ * While the proper fix is to change the signatures for packet-ber.c helpers
+ * as well as the signatures for the callbacks to include the indefinite length
+ * indication that would be a major job.
+ * For the time being, kludge, set a global variable in the 
+ * CHOICE/SEQUENCE [OF]/SET [OF] helpers to indicate to the next helper
+ * whether the length is indefinite or not.
+ * This has currently only been implemented for {SEQUENCE|SET} [OF] but not yet
+ * CHOICE.
  */
 /* packet-ber.c
  * Helpers for ASN.1/BER dissection
  * Ronnie Sahlberg (C) 2004
  *
- * $Id: packet-ber.c 14217 2005-04-28 09:54:03Z kukosa $
+ * $Id: packet-ber.c 15085 2005-07-26 09:52:06Z etxrab $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -61,6 +74,7 @@ static gint hf_ber_length = -1;
 static gint hf_ber_bitstring_padding = -1;
 static gint hf_ber_unknown_OID = -1;
 static gint hf_ber_unknown_OCTETSTRING = -1;
+static gint hf_ber_unknown_GraphicString = -1;
 static gint hf_ber_unknown_NumericString = -1;
 static gint hf_ber_unknown_PrintableString = -1;
 static gint hf_ber_unknown_IA5String = -1;
@@ -74,6 +88,10 @@ static gint ett_ber_SEQUENCE = -1;
 static gboolean show_internal_ber_fields = FALSE;
 
 proto_item *ber_last_created_item=NULL;
+/* kludge to pass indefinite length indications from structure helpers
+   to the next helper.  Or else implicite tag + indefinite length wont work.
+*/
+static gboolean length_is_indefinite=FALSE;
 
 static dissector_table_t ber_oid_dissector_table=NULL;
 
@@ -136,6 +154,14 @@ dissect_ber_oid_NULL_callback(tvbuff_t *tvb _U_, packet_info *pinfo _U_, proto_t
 	return;
 }
 
+
+void
+register_ber_oid_dissector_handle(char *oid, dissector_handle_t dissector, int proto _U_, char *name)
+{
+	dissector_add_string("ber.oid", oid, dissector);
+	g_hash_table_insert(oid_table, oid, name);
+}
+
 void
 register_ber_oid_dissector(char *oid, dissector_t dissector, int proto, char *name)
 {
@@ -145,6 +171,7 @@ register_ber_oid_dissector(char *oid, dissector_t dissector, int proto, char *na
 	dissector_add_string("ber.oid", oid, dissector_handle);
 	g_hash_table_insert(oid_table, oid, name);
 }
+
 /* Register the oid name to get translation in proto dissection */
 void
 register_ber_oid_name(char *oid, char *name)
@@ -160,6 +187,76 @@ get_ber_oid_name(char *oid)
 }
 
 
+/* This function is only used by dissect_unknown_ber()
+ * It is essentially the get_ber_length() function but we dont
+ * deliberately generate a [malformed packet] if the length field looks
+ * like garbage.
+ * For unknown ber encodings we can just do as much as we can but sometimes it
+ * is impossible to do it right.
+ * For example:
+ * If there are implicit tags, then the length will not be valid when we 
+ * try to read the tag/len  but we DONT want to generate a malformed packet
+ * here, the packet is not malformed   we just can not parse the ber encoding.
+ */
+static int
+get_ber_length_dont_check_len(proto_tree *tree, tvbuff_t *tvb, int offset, guint32 *length, gboolean *ind) {
+	guint8 oct, len;
+	guint32 tmp_length;
+	gboolean tmp_ind;
+	int old_offset=offset;
+
+	tmp_length = 0;
+	tmp_ind = FALSE;
+
+	/* dont read beyond the end of the tvb */
+	if(tvb_length(tvb)<=(unsigned)offset){
+		*length=tvb_length(tvb)+99;
+		return offset;
+	}
+
+	oct = tvb_get_guint8(tvb, offset);
+	offset += 1;
+	
+	if (!(oct&0x80)) {
+		/* 8.1.3.4 */
+		tmp_length = oct;
+	} else {
+		len = oct & 0x7F;
+		if (len) {
+			/* 8.1.3.5 */
+			while (len--) {
+				if((unsigned)offset>=tvb_length(tvb)){
+					if (length)
+						*length = 999999999;
+					if (ind)
+						*ind = tmp_ind;
+					return offset;
+				}
+				oct = tvb_get_guint8(tvb, offset);
+				offset++;
+				tmp_length = (tmp_length<<8) + oct;
+			}
+		} else {
+			/* 8.1.3.6 */
+			tmp_ind = TRUE;
+			/* TO DO */
+		}
+	}
+
+	/* check that the length is sane */
+	if(tmp_length>(guint32)tvb_reported_length_remaining(tvb,offset)){
+		proto_tree_add_text(tree, tvb, old_offset, offset-old_offset, "BER: Error length:%d longer than tvb_reported_length_remaining:%d",tmp_length, tvb_reported_length_remaining(tvb, offset));
+		/* the ignorant mans way to generate [malformed packet] */
+	}
+
+	if (length)
+		*length = tmp_length;
+	if (ind)
+		*ind = tmp_ind;
+
+	return offset;
+}
+
 /* this function tries to dissect an unknown blob as much as possible.
  * everytime this function is called it is a failure to implement a proper
  * dissector in ethereal.
@@ -167,28 +264,30 @@ get_ber_oid_name(char *oid)
  * when it is called it is a BAD thing  not a good thing.
  * It can not handle IMPLICIT tags nor indefinite length.
  */
-static int
-dissect_unknown_ber(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tree *tree)
+int dissect_unknown_ber(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	int start_offset;
-	guint8 class;
+	gint8 class;
 	gboolean pc, ind;
-	guint32 tag;
+	gint32 tag;
 	guint32 len;
 	proto_item *item=NULL;
 	proto_tree *next_tree=NULL;
+	tvbuff_t *next_tvb;
 
 	start_offset=offset;
 
-	offset=dissect_ber_identifier(pinfo, NULL, tvb, offset, &class, &pc, &tag);
-	offset=dissect_ber_length(pinfo, NULL, tvb, offset, &len, &ind);
+	offset=get_ber_identifier(tvb, offset, &class, &pc, &tag);
+	offset=get_ber_length_dont_check_len(NULL, tvb, offset, &len, &ind);
 
 	if(len>(guint32)tvb_length_remaining(tvb, offset)){
 		/* hmm   maybe something bad happened or the frame is short,
+		   or the ASN1 definition contains implicit tags making
+		   decoding impossible?
 		   since these are not vital outputs just return instead of 
 		   throwing en exception.
 		 */
-		proto_tree_add_text(tree, tvb, offset, len, "BER: Error length:%d longer than tvb_length_ramaining:%d",len, tvb_length_remaining(tvb, offset));
+		proto_tree_add_text(tree, tvb, offset, 0, "BER Failure decoding unknown BER structure. I tried but sometimes decoding unknown BER structures is just impossible");
 		return tvb_length(tvb);
 	}
 
@@ -201,6 +300,9 @@ dissect_unknown_ber(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tree *t
 		case BER_UNI_TAG_ENUMERATED:
 			offset = dissect_ber_integer(FALSE, pinfo, tree, tvb, start_offset, hf_ber_unknown_ENUMERATED, NULL);
 			break;
+		case BER_UNI_TAG_GraphicString:
+			offset = dissect_ber_octet_string(FALSE, pinfo, tree, tvb, start_offset, hf_ber_unknown_GraphicString, NULL);
+			break;
 		case BER_UNI_TAG_OCTETSTRING:
 			offset = dissect_ber_octet_string(FALSE, pinfo, tree, tvb, start_offset, hf_ber_unknown_OCTETSTRING, NULL);
 			break;
@@ -208,11 +310,12 @@ dissect_unknown_ber(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tree *t
 			offset=dissect_ber_object_identifier(FALSE, pinfo, tree, tvb, start_offset, hf_ber_unknown_OID, NULL);
 			break;
 		case BER_UNI_TAG_SEQUENCE:
-			item=proto_tree_add_text(tree, tvb, start_offset, len, "SEQUENCE");
+			item=proto_tree_add_text(tree, tvb, offset, len, "SEQUENCE  (len:%d bytes)   tvb_remaining:%d", len, tvb_length_remaining(tvb, offset));
 			if(item){
 				next_tree=proto_item_add_subtree(item, ett_ber_SEQUENCE);
 			}
-			offset=dissect_unknown_ber(pinfo, tvb, offset, next_tree);
+			next_tvb=tvb_new_subset(tvb, offset, len, len);
+			offset += dissect_unknown_ber(pinfo, next_tvb, 0, next_tree);
 			break;
 		case BER_UNI_TAG_NumericString:
 			offset = dissect_ber_octet_string(FALSE, pinfo, tree, tvb, start_offset, hf_ber_unknown_NumericString, NULL);
@@ -229,11 +332,12 @@ dissect_unknown_ber(packet_info *pinfo, tvbuff_t *tvb, int offset, proto_tree *t
 		}
 		break;
 	case BER_CLASS_CON:
-		item=proto_tree_add_text(tree, tvb, start_offset, len, "[%d]",tag);
+		item=proto_tree_add_text(tree, tvb, offset, len, "[%d]  (len:%d bytes) ",tag,len);
 		if(item){
 			next_tree=proto_item_add_subtree(item, ett_ber_SEQUENCE);
 		}
-		offset=dissect_unknown_ber(pinfo, tvb, offset, next_tree);
+		next_tvb=tvb_new_subset(tvb, offset, len, len);
+		offset += dissect_unknown_ber(pinfo, next_tvb, 0, next_tree);
 		break;
 	default:
 		proto_tree_add_text(tree, tvb, offset, len, "BER: Error can not handle class:%d (0x%02x)",class,tvb_get_guint8(tvb, start_offset));
@@ -434,9 +538,9 @@ dissect_ber_length(packet_info *pinfo _U_, proto_tree *tree, tvbuff_t *tvb, int
 /* 8.7 Encoding of an octetstring value */
 int 
 dissect_ber_octet_string(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id, tvbuff_t **out_tvb) {
-	guint8 class;
+	gint8 class;
 	gboolean pc, ind;
-	guint32 tag;
+	gint32 tag;
 	guint32 len;
 	int end_offset;
 	proto_item *it;
@@ -467,6 +571,8 @@ printf("OCTET STRING dissect_ber_octet_string(%s) entered\n",name);
 		end_offset=offset+len;
 	
 		/* sanity check: we only handle Constructed Universal Sequences */
+		if ((class!=BER_CLASS_APP)&&(class!=BER_CLASS_PRI))
+
 		if( (class!=BER_CLASS_UNI) 
 		  ||((tag<BER_UNI_TAG_NumericString)&&(tag!=BER_UNI_TAG_OCTETSTRING)&&(tag!=BER_UNI_TAG_UTF8String)) ){
 		    tvb_ensure_bytes_exist(tvb, offset-2, 2);
@@ -486,6 +592,8 @@ printf("OCTET STRING dissect_ber_octet_string(%s) entered\n",name);
 	if (pc) {
 		/* constructed */
 		/* TO DO */
+		if(out_tvb)
+			*out_tvb=NULL;
     printf("TODO: handle constructed type in packet-ber.c, dissect_ber_octet_string\n");
 	} else {
 		/* primitive */
@@ -531,25 +639,30 @@ int dissect_ber_octet_string_wcb(gboolean implicit_tag, packet_info *pinfo, prot
 /* 8.8 Encoding of a null value */
 int 
 dissect_ber_null(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id) {
-  guint8 class;
+  gint8 class;
   gboolean pc;
-  guint32 tag, len;
+  gint32 tag;
+  guint32 len;
   int offset_old;
 
-  offset_old = offset;  
-  offset = dissect_ber_identifier(pinfo, tree, tvb, offset, &class, &pc, &tag);
-  if ((pc) ||
-      (!implicit_tag && ((class != BER_CLASS_UNI) || (tag != BER_UNI_TAG_NULL)))) {
-    proto_tree_add_text(tree, tvb, offset_old, offset - offset_old, "BER Error: NULL expected but Class:%d(%s) PC:%d Tag:%d was unexpected", class,val_to_str(class,ber_class_codes,"Unknown"), pc, tag);
+  if(!implicit_tag){
+    offset_old = offset;  
+    offset = dissect_ber_identifier(pinfo, tree, tvb, offset, &class, &pc, &tag);
+    if ((pc) ||
+	(!implicit_tag && ((class != BER_CLASS_UNI) || (tag != BER_UNI_TAG_NULL)))) {
+      proto_tree_add_text(tree, tvb, offset_old, offset - offset_old, "BER Error: NULL expected but Class:%d(%s) PC:%d Tag:%d was unexpected", class,val_to_str(class,ber_class_codes,"Unknown"), pc, tag);
+    }
+
+    offset_old = offset;  
+    offset = dissect_ber_length(pinfo, tree, tvb, offset, &len, NULL);
+    if (len) {
+      proto_tree_add_text(tree, tvb, offset_old, offset - offset_old, "BER Error: NULL expect zero length but Length=%d", len);
+      proto_tree_add_text(tree, tvb, offset, len, "BER Error: unexpected data in NULL type");
+      offset += len;
+    }
   }
 
-  offset_old = offset;  
-  offset = dissect_ber_length(pinfo, tree, tvb, offset, &len, NULL);
-  if (len) {
-    proto_tree_add_text(tree, tvb, offset_old, offset - offset_old, "BER Error: NULL expect zero length but Length=%d", len);
-    proto_tree_add_text(tree, tvb, offset, len, "BER Error: unexpected data in NULL type");
-    offset += len;
-  }
+  proto_tree_add_item(tree, hf_id, tvb, offset, 0, FALSE);
 
   return offset;
 }
@@ -557,9 +670,9 @@ dissect_ber_null(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree, tv
 int
 dissect_ber_integer(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id, guint32 *value)
 {
-	guint8 class;
+	gint8 class;
 	gboolean pc;
-	guint32 tag;
+	gint32 tag;
 	guint32 len;
 	gint32 val;
 	gint64 val64;
@@ -578,7 +691,7 @@ name="unnamed";
 if(tvb_length_remaining(tvb,offset)>3){
 printf("INTEGERnew dissect_ber_integer(%s) entered implicit_tag:%d offset:%d len:%d %02x:%02x:%02x\n",name,implicit_tag,offset,tvb_length_remaining(tvb,offset),tvb_get_guint8(tvb,offset),tvb_get_guint8(tvb,offset+1),tvb_get_guint8(tvb,offset+2));
 }else{
-printf("INTEGERnew dissect_ber_integer(%s) entered implicit_tag:%d len:%d\n",name,implicit_tag,len);
+printf("INTEGERnew dissect_ber_integer(%s) entered implicit_tag:%d \n",name,implicit_tag);
 }
 }
 #endif
@@ -656,9 +769,9 @@ printf("INTEGERnew dissect_ber_integer(%s) entered implicit_tag:%d len:%d\n",nam
 int
 dissect_ber_boolean(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id)
 {
-	guint8 class;
+	gint8 class;
 	gboolean pc;
-	guint32 tag;
+	gint32 tag;
 	guint32 len;
 	guint8 val;
 	header_field_info *hfi;
@@ -695,12 +808,12 @@ dissect_ber_boolean(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree,
  */
 int dissect_ber_sequence(gboolean implicit_tag, packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_sequence_t *seq, gint hf_id, gint ett_id) {
 	gint8 class;
-	gboolean pc, ind, ind_field;
+	gboolean pc, ind = 0, ind_field;
 	gint32 tag;
 	guint32 len;
 	proto_tree *tree = parent_tree;
 	proto_item *item = NULL;
-	int end_offset;
+	int end_offset, tag_start_offset;
 	tvbuff_t *next_tvb;
 
 #ifdef DEBUG_BER
@@ -714,9 +827,9 @@ name=hfinfo->name;
 name="unnamed";
 }
 if(tvb_length_remaining(tvb,offset)>3){
-printf("SEQUENCE dissect_ber_sequence(%s) entered offset:%d len:%d %02x:%02x:%02x\n",name,offset,tvb_length_remaining(tvb,offset),tvb_get_guint8(tvb,offset),tvb_get_guint8(tvb,offset+1),tvb_get_guint8(tvb,offset+2));
+printf("SEQUENCE dissect_ber_sequence(%s) entered offset:%d len:%d %02x:%02x:%02x implicit_tag:%d length_is_indefinite:%d\n",name,offset,tvb_length_remaining(tvb,offset),tvb_get_guint8(tvb,offset),tvb_get_guint8(tvb,offset+1),tvb_get_guint8(tvb,offset+2),implicit_tag,length_is_indefinite);
 }else{
-printf("SEQUENCE dissect_ber_sequence(%s) entered\n",name);
+printf("SEQUENCE dissect_ber_sequence(%s) entered length_is_indefinite:%d\n",name,length_is_indefinite);
 }
 }
 #endif
@@ -734,6 +847,7 @@ printf("SEQUENCE dissect_ber_sequence(%s) entered\n",name);
 		}
 
 		/* sanity check: we only handle Constructed Universal Sequences */
+		if ((class!=BER_CLASS_APP)&&(class!=BER_CLASS_PRI))
 		if ((!pc)
 		||(!implicit_tag&&((class!=BER_CLASS_UNI)
 							||(tag!=BER_UNI_TAG_SEQUENCE)))) {
@@ -742,6 +856,7 @@ printf("SEQUENCE dissect_ber_sequence(%s) entered\n",name);
 			return end_offset;
 		}
 	} else {
+		ind=length_is_indefinite;
 		/* was implicit tag so just use the length of the tvb */
 		len=tvb_length_remaining(tvb,offset);
 		end_offset=offset+len;
@@ -764,15 +879,50 @@ printf("SEQUENCE dissect_ber_sequence(%s) entered\n",name);
 		int hoffset, eoffset, count;
 
 		if(ind){ /* this sequence was of indefinite length, so check for EOC */
+#ifdef DEBUG_BER
+{
+char *name;
+header_field_info *hfinfo;
+if(hf_id>0){
+hfinfo = proto_registrar_get_nth(hf_id);
+name=hfinfo->name;
+} else {
+name="unnamed";
+}
+if(tvb_length_remaining(tvb,offset)>3){
+printf("SEQUENCE dissect_ber_sequence(%s) TESTING FOR EOC implicit_tag:%d offset:%d len:%d %02x:%02x:%02x length_is_indefinite:%d\n",name,implicit_tag,offset,tvb_length_remaining(tvb,offset),tvb_get_guint8(tvb,offset),tvb_get_guint8(tvb,offset+1),tvb_get_guint8(tvb,offset+2),length_is_indefinite);
+}else{
+printf("SEQUENCE dissect_ber_sequence(%s) TESTING FOR EOC length_is_indefinite:%d\n",name,length_is_indefinite);
+}
+}
+#endif
 			if((tvb_get_guint8(tvb, offset)==0)&&(tvb_get_guint8(tvb, offset+1)==0)){
 				if(show_internal_ber_fields){
 					proto_tree_add_text(tree, tvb, offset, 2, "EOC");
 				}
+#ifdef DEBUG_BER
+{
+char *name;
+header_field_info *hfinfo;
+if(hf_id>0){
+hfinfo = proto_registrar_get_nth(hf_id);
+name=hfinfo->name;
+} else {
+name="unnamed";
+}
+if(tvb_length_remaining(tvb,offset)>3){
+printf("SEQUENCE dissect_ber_sq_of(%s) EOC FOUND implicit_tag:%d offset:%d len:%d %02x:%02x:%02x length_is_indefinite:%d\n",name,implicit_tag,offset,tvb_length_remaining(tvb,offset),tvb_get_guint8(tvb,offset),tvb_get_guint8(tvb,offset+1),tvb_get_guint8(tvb,offset+2),length_is_indefinite);
+}else{
+printf("SEQUENCE dissect_ber_sq_of(%s) EOC FOUND length_is_indefinite:%d\n",name,length_is_indefinite);
+}
+}
+#endif
 				return offset+2;
 			}
 		}
 		hoffset = offset;
 		/* read header and len for next field */
+		tag_start_offset=offset;
 		offset = get_ber_identifier(tvb, offset, &class, &pc, &tag);
 		offset = get_ber_length(tree, tvb, offset, &len, &ind_field);
 		eoffset = offset + len;
@@ -780,7 +930,7 @@ ber_sequence_try_again:
 		/* have we run out of known entries in the sequence ?*/
 		if (!seq->func) {
 			/* it was not,  move to the enxt one and try again */
-			proto_tree_add_text(tree, tvb, offset, len, "BER Error: This field lies beyond the end of the known sequence definition.");
+			proto_tree_add_text(tree, tvb, tag_start_offset, offset-tag_start_offset, "BER Error: This field lies beyond the end of the known sequence definition. class:%d pc:%d tag:%d len:%d",class,pc,tag,len);
 			offset = eoffset;
 			continue;
 		}
@@ -795,7 +945,7 @@ ber_sequence_try_again:
  *   { BER_CLASS_CON, 7, BER_FLAGS_OPTIONAL|BER_FLAGS_NOTCHKTAG, dissect_scope },
  * and there should not be a NOTCHKTAG here
  */
-		if( (seq->class==BER_CLASS_CON) && (!(seq->flags&BER_FLAGS_NOOWNTAG)) ){
+		if( ((seq->class==BER_CLASS_CON)||(seq->class==BER_CLASS_APP)||(seq->class==BER_CLASS_PRI)) && (!(seq->flags&BER_FLAGS_NOOWNTAG)) ){
 		  if( (seq->class!=BER_CLASS_ANY) 
 		  &&  (seq->tag!=-1)  
 		  &&( (seq->class!=class)
@@ -874,13 +1024,15 @@ name=hfinfo->name;
 name="unnamed";
 }
 if(tvb_length_remaining(next_tvb,0)>3){
-printf("SEQUENCE dissect_ber_sequence(%s) calling subdissector offset:%d len:%d %02x:%02x:%02x\n",name,offset,tvb_length_remaining(next_tvb,0),tvb_get_guint8(next_tvb,0),tvb_get_guint8(next_tvb,1),tvb_get_guint8(next_tvb,2));
+printf("SEQUENCE dissect_ber_sequence(%s) calling subdissector offset:%d len:%d %02x:%02x:%02x indefinite_len:%d no_own_tag:%d\n",name,offset,tvb_length_remaining(next_tvb,0),tvb_get_guint8(next_tvb,0),tvb_get_guint8(next_tvb,1),tvb_get_guint8(next_tvb,2),ind_field,!!(seq->flags&BER_FLAGS_NOOWNTAG));
 }else{
-printf("SEQUENCE dissect_ber_sequence(%s) calling subdissector\n",name);
+printf("SEQUENCE dissect_ber_sequence(%s) calling subdissector indefinite_len:%d no_own_tag:%d\n",name,ind_field,!!(seq->flags&BER_FLAGS_NOOWNTAG));
 }
 }
 #endif
+		length_is_indefinite=ind_field;
 		count=seq->func(pinfo, tree, next_tvb, 0);
+		length_is_indefinite=FALSE;
 #ifdef DEBUG_BER
 {
 char *name;
@@ -895,7 +1047,7 @@ printf("SEQUENCE dissect_ber_sequence(%s) subdissector ate %d bytes\n",name,coun
 }
 #endif
 		seq++;
-		if (len==0) {
+		if( (len==0)&&(!ind_field) ) {
 			offset = eoffset;
 		} else {
 			offset = hoffset+count;
@@ -923,7 +1075,7 @@ printf("SEQUENCE dissect_ber_sequence(%s) subdissector ate %d bytes\n",name,coun
  * in case it was a CHOICE { } OPTIONAL
  */
 int
-dissect_ber_choice(packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_choice_t *choice, gint hf_id, gint ett_id)
+dissect_ber_choice(packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_choice_t *choice, gint hf_id, gint ett_id, gint *branch_taken)
 {
 	gint8 class;
 	gboolean pc, ind;
@@ -994,8 +1146,14 @@ printf("CHOICE dissect_ber_choice(%s) entered len:%d\n",name,tvb_length_remainin
 	/* loop over all entries until we find the right choice or 
 	   run out of entries */
 	ch = choice;
+	if(branch_taken){
+		*branch_taken=-1;
+	}
 	while(ch->func){
 choice_try_again:
+		if(branch_taken){
+			(*branch_taken)++;
+		}
 #ifdef DEBUG_BER
 printf("CHOICE testing potential subdissector class:%d:(expected)%d  tag:%d:(expected)%d flags:%d\n",class,ch->class,tag,ch->tag,ch->flags);
 #endif
@@ -1073,6 +1231,12 @@ printf("CHOICE dissect_ber_choice(%s) subdissector ate %d bytes\n",name,count);
 		}
 		ch++;
 	}
+
+	if(branch_taken){
+		/* none of the branches were taken so set the param 
+		   back to -1 */
+		*branch_taken=-1;
+	}
 #ifdef REMOVED
 	/*XXX here we should have another flag to the CHOICE to distinguish
 	 * between teh case when we know it is a mandatory   or if the CHOICE is optional == no arm matched */
@@ -1292,15 +1456,15 @@ name=hfinfo->name;
 name="unnamed";
 }
 if(tvb_length_remaining(tvb,offset)>3){
-printf("SQ OF dissect_ber_sq_of(%s) entered implicit_tag:%d offset:%d len:%d %02x:%02x:%02x\n",name,implicit_tag,offset,tvb_length_remaining(tvb,offset),tvb_get_guint8(tvb,offset),tvb_get_guint8(tvb,offset+1),tvb_get_guint8(tvb,offset+2));
+printf("SQ OF dissect_ber_sq_of(%s) entered implicit_tag:%d offset:%d len:%d %02x:%02x:%02x length_is_indefinite:%d\n",name,implicit_tag,offset,tvb_length_remaining(tvb,offset),tvb_get_guint8(tvb,offset),tvb_get_guint8(tvb,offset+1),tvb_get_guint8(tvb,offset+2),length_is_indefinite);
 }else{
-printf("SQ OF dissect_ber_sq_of(%s) entered\n",name);
+printf("SQ OF dissect_ber_sq_of(%s) entered length_is_indefinite:%d\n",name,length_is_indefinite);
 }
 }
 #endif
 
 	if(!implicit_tag){
-		/* first we must read the sequence header */
+		/* first we must read the sequence of header */
 		offset = dissect_ber_identifier(pinfo, tree, tvb, offset, &class, &pc, &tag);
 		offset = dissect_ber_length(pinfo, tree, tvb, offset, &len, &ind);
 		if(ind){
@@ -1313,6 +1477,7 @@ printf("SQ OF dissect_ber_sq_of(%s) entered\n",name);
 		}
 
 		/* sanity check: we only handle Constructed Universal Sequences */
+		if ((class!=BER_CLASS_APP)&&(class!=BER_CLASS_PRI))
 		if (!pc
 			||(!implicit_tag&&((class!=BER_CLASS_UNI)
 							||(tag!=type)))) {
@@ -1322,6 +1487,7 @@ printf("SQ OF dissect_ber_sq_of(%s) entered\n",name);
 			return end_offset;
 		}
 	} else {
+		ind=length_is_indefinite;
 		len=tvb_length_remaining(tvb,offset);
 		end_offset = offset + len;
 	}
@@ -1333,6 +1499,7 @@ printf("SQ OF dissect_ber_sq_of(%s) entered\n",name);
 		guint32 len;
 
 		if(ind){ /* this sequence of was of indefinite length, so check for EOC */
+
 			if((tvb_get_guint8(tvb, offset)==0)&&(tvb_get_guint8(tvb, offset+1)==0)){
 				break;
 			}
@@ -1371,10 +1538,44 @@ printf("SQ OF dissect_ber_sq_of(%s) entered\n",name);
 		int hoffset, count;
 
 		if(ind){ /* this sequence of was of indefinite length, so check for EOC */
+#ifdef DEBUG_BER
+{
+char *name;
+header_field_info *hfinfo;
+if(hf_id>0){
+hfinfo = proto_registrar_get_nth(hf_id);
+name=hfinfo->name;
+} else {
+name="unnamed";
+}
+if(tvb_length_remaining(tvb,offset)>3){
+printf("SQ OF dissect_ber_sq_of(%s) TESTING FOR EOC implicit_tag:%d offset:%d len:%d %02x:%02x:%02x length_is_indefinite:%d\n",name,implicit_tag,offset,tvb_length_remaining(tvb,offset),tvb_get_guint8(tvb,offset),tvb_get_guint8(tvb,offset+1),tvb_get_guint8(tvb,offset+2),length_is_indefinite);
+}else{
+printf("SQ OF dissect_ber_sq_of(%s) TESTING FOR EOC length_is_indefinite:%d\n",name,length_is_indefinite);
+}
+}
+#endif
 			if((tvb_get_guint8(tvb, offset)==0)&&(tvb_get_guint8(tvb, offset+1)==0)){
 				if(show_internal_ber_fields){
 					proto_tree_add_text(tree, tvb, offset, 2, "EOC");
 				}
+#ifdef DEBUG_BER
+{
+char *name;
+header_field_info *hfinfo;
+if(hf_id>0){
+hfinfo = proto_registrar_get_nth(hf_id);
+name=hfinfo->name;
+} else {
+name="unnamed";
+}
+if(tvb_length_remaining(tvb,offset)>3){
+printf("SQ OF dissect_ber_sq_of(%s) EOC FOUND implicit_tag:%d offset:%d len:%d %02x:%02x:%02x length_is_indefinite:%d\n",name,implicit_tag,offset,tvb_length_remaining(tvb,offset),tvb_get_guint8(tvb,offset),tvb_get_guint8(tvb,offset+1),tvb_get_guint8(tvb,offset+2),length_is_indefinite);
+}else{
+printf("SQ OF dissect_ber_sq_of(%s) EOC FOUND length_is_indefinite:%d\n",name,length_is_indefinite);
+}
+}
+#endif
 				return offset+2;
 			}
 		}
@@ -1409,8 +1610,40 @@ printf("SQ OF dissect_ber_sq_of(%s) entered\n",name);
 			hoffset = dissect_ber_length(pinfo, tree, tvb, hoffset, NULL, NULL);
 		}
 		
+#ifdef DEBUG_BER
+{
+char *name;
+header_field_info *hfinfo;
+if(hf_id>0){
+hfinfo = proto_registrar_get_nth(hf_id);
+name=hfinfo->name;
+} else {
+name="unnamed";
+}
+if(tvb_length_remaining(tvb,0)>3){
+printf("SQ OF dissect_ber_sq_of(%s) calling subdissector offset:%d len:%d %02x:%02x:%02x indefinite_len:%d no_own_tag:%d\n",name,offset,tvb_length_remaining(tvb,0),tvb_get_guint8(tvb,0),tvb_get_guint8(tvb,1),tvb_get_guint8(tvb,2),ind_field,!!(seq->flags&BER_FLAGS_NOOWNTAG));
+}else{
+printf("SQ OF dissect_ber_sq_of(%s) calling subdissector indefinite_len:%d no_own_tag:%d\n",name,ind_field,!!(seq->flags&BER_FLAGS_NOOWNTAG));
+}
+}
+#endif
 		/* call the dissector for this field */
+		length_is_indefinite=ind_field;
 		count=seq->func(pinfo, tree, tvb, hoffset)-hoffset;
+		length_is_indefinite=FALSE;
+#ifdef DEBUG_BER
+{
+char *name;
+header_field_info *hfinfo;
+if(hf_id>0){
+hfinfo = proto_registrar_get_nth(hf_id);
+name=hfinfo->name;
+} else {
+name="unnamed";
+}
+printf("SQ OF dissect_ber_sq_of(%s) subdissector ate %d bytes\n",name,count);
+}
+#endif
 		if(ind_field){
 			/* previous field was of indefinite length so we have
 			 * no choice but use whatever the subdissector told us
@@ -1568,15 +1801,18 @@ int dissect_ber_bitstring(gboolean implicit_tag, packet_info *pinfo, proto_tree
 				proto_tree_add_boolean(tree, *(nb->p_id), tvb, offset + len, 0, 0x00);
 			}
 			if (val) {
-				if (item && nb->tstr)
+				if (item && nb->tstr) {
 					proto_item_append_text(item, "%s%s", sep, nb->tstr);
+					term = TRUE;
+				}
 			} else {
-				if (item && nb->fstr)
+				if (item && nb->fstr) {
 					proto_item_append_text(item, "%s%s", sep, nb->fstr);
+					term = TRUE;
+				}
 			}
 			nb++;
-			sep = ", ";
-			term = TRUE;
+			if (term) sep = ", ";
 		}
 		if (term)
 			proto_item_append_text(item, ")");
@@ -1660,6 +1896,9 @@ proto_register_ber(void)
 	{ &hf_ber_unknown_OCTETSTRING, {
 	    "OCTETSTRING", "ber.unknown.OCTETSTRING", FT_BYTES, BASE_HEX,
 	    NULL, 0, "This is an unknown OCTETSTRING", HFILL }},
+	{ &hf_ber_unknown_GraphicString, {
+	    "GRAPHICSTRING", "ber.unknown.GRAPHICSTRING", FT_STRING, BASE_HEX,
+	    NULL, 0, "This is an unknown GRAPHICSTRING", HFILL }},
 	{ &hf_ber_unknown_OID, {
 	    "OID", "ber.unknown.OID", FT_STRING, BASE_NONE,
 	    NULL, 0, "This is an unknown Object Identifier", HFILL }},
