@@ -3,7 +3,7 @@
  * Dissector for the CAST Client Control Protocol
  *   (The "D-Channel"-Protocol for Cisco Systems' IP-Phones)
  *
- * $Id: packet-cast.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-cast.c 14786 2005-06-26 19:56:52Z guy $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -402,7 +402,7 @@ static void dissect_cast_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
   guint32 hdr_data_length;
   guint32 hdr_marker;
   guint32 data_messageid;
-  gchar   *messageid_str;
+  const gchar *messageid_str;
   /*  guint32 data_size; */
 
   guint i = 0;
