@@ -2,7 +2,7 @@
  * Routines for the disassembly of the "Cisco Discovery Protocol"
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id: packet-cdp.c 13752 2005-03-14 19:53:07Z guy $
+ * $Id: packet-cdp.c 14786 2005-06-26 19:56:52Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -654,7 +654,7 @@ dissect_address_tlv(tvbuff_t *tvb, int offset, int length, proto_tree *tree)
     guint8 protocol_type;
     guint8 protocol_length;
     int nlpid;
-    char *protocol_str;
+    const char *protocol_str;
     guint16 address_length;
     char *address_type_str;
     char *address_str;
