@@ -2,7 +2,7 @@
  * Routines for DCERPC NDR dissection
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  *
- * $Id: packet-dcerpc-ndr.c 13006 2005-01-12 21:20:50Z ulfl $
+ * $Id: packet-dcerpc-ndr.c 13198 2005-01-29 20:39:14Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -101,10 +101,15 @@ dissect_ndr_uint32 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
                                   tree, drep, hfindex, pdata);
 }
 
+/* Double uint32
+   This function dissects the 64bit datatype that is common for
+   ms interfaces and which is 32bit aligned.
+   It is really just 2 uint32's
+*/
 int
-dissect_ndr_uint64 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
+dissect_ndr_duint32 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
                     proto_tree *tree, guint8 *drep,
-                    int hfindex, unsigned char *pdata)
+                    int hfindex, guint64 *pdata)
 {
     dcerpc_info *di;
 
@@ -121,6 +126,28 @@ dissect_ndr_uint64 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
                                   tree, drep, hfindex, pdata);
 }
 
+/* uint64 : hyper
+   a 64 bit integer  aligned to proper 8 byte boundaries
+*/
+int
+dissect_ndr_uint64 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
+                    proto_tree *tree, guint8 *drep,
+                    int hfindex, guint64 *pdata)
+{
+    dcerpc_info *di;
+
+    di=pinfo->private_data;
+    if(di->conformant_run){
+      /* just a run to handle conformant arrays, no scalars to dissect */
+      return offset;
+    }
+
+    if (offset % 8) {
+        offset += 8 - (offset % 8);
+    }
+    return dissect_dcerpc_uint64 (tvb, offset, pinfo,
+                                  tree, drep, hfindex, pdata);
+}
 
 int
 dissect_ndr_float(tvbuff_t *tvb, gint offset, packet_info *pinfo,
