@@ -5,7 +5,7 @@
  * Routines for DCERPC over SMB packet disassembly
  * Copyright 2001-2003, Tim Potter <tpot@samba.org>
  *
- * $Id: packet-dcerpc-nt.c 13413 2005-02-16 11:31:56Z sahlberg $
+ * $Id: packet-dcerpc-nt.c 15079 2005-07-26 08:01:16Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -625,7 +625,7 @@ void dcerpc_smb_store_pol_pkts(e_ctx_hnd *policy_hnd, packet_info *pinfo,
 /* Store a text string with a policy handle */
 
 void dcerpc_smb_store_pol_name(e_ctx_hnd *policy_hnd, packet_info *pinfo,
-			       char *name)
+			       const char *name)
 {
 	pol_hash_value *value;
 	pol_value *pol;
@@ -1127,7 +1127,7 @@ void cb_str_postprocess(packet_info *pinfo, proto_tree *tree _U_,
 
 int dissect_ndr_str_pointer_item(tvbuff_t *tvb, gint offset, 
 				 packet_info *pinfo, proto_tree *tree, 
-				 guint8 *drep, int type, char *text, 
+				 guint8 *drep, int type, const char *text, 
 				 int hf_index, int levels)
 {
 	return dissect_ndr_pointer_cb(
@@ -1148,7 +1148,7 @@ dissect_ndr_nt_SID(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	dcerpc_info *di = (dcerpc_info *)pinfo->private_data;
 	dcerpc_call_value *dcv = (dcerpc_call_value *)di->call_data;
 	char *sid_str=NULL;
-	char *name;
+	const char *name;
 
 	if(di->hf_index!=-1){
 		name=proto_registrar_get_name(di->hf_index);
