@@ -2,7 +2,7 @@
  * Copyright 2001, Todd Sabin <tas@webspan.net>
  * Copyright 2003, Tim Potter <tpot@samba.org>
  *
- * $Id: packet-dcerpc.h 13755 2005-03-14 20:51:13Z sahlberg $
+ * $Id: packet-dcerpc.h 15079 2005-07-26 08:01:16Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -183,22 +183,22 @@ typedef void (dcerpc_callback_fnct_t)(packet_info *pinfo, proto_tree *tree, prot
 
 int dissect_ndr_pointer_cb(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 			   proto_tree *tree, guint8 *drep,
-			   dcerpc_dissect_fnct_t *fnct, int type, char *text, 
+			   dcerpc_dissect_fnct_t *fnct, int type, const char *text, 
 			   int hf_index, dcerpc_callback_fnct_t *callback,
 			   void *callback_args);
 
 int dissect_ndr_pointer(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 			proto_tree *tree, guint8 *drep,
-			dcerpc_dissect_fnct_t *fnct, int type, char *text, 
+			dcerpc_dissect_fnct_t *fnct, int type, const char *text, 
 			int hf_index);
 int dissect_deferred_pointers(packet_info *pinfo, tvbuff_t *tvb, int offset, guint8 *drep);
 int dissect_ndr_embedded_pointer(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 			proto_tree *tree, guint8 *drep,
-			dcerpc_dissect_fnct_t *fnct, int type, char *text, 
+			dcerpc_dissect_fnct_t *fnct, int type, const char *text, 
 			int hf_index);
 int dissect_ndr_toplevel_pointer(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 			proto_tree *tree, guint8 *drep,
-			dcerpc_dissect_fnct_t *fnct, int type, char *text, 
+			dcerpc_dissect_fnct_t *fnct, int type, const char *text, 
 			int hf_index);
 
 /* dissect a NDR unidimensional conformant array */
@@ -238,14 +238,14 @@ int dissect_ndr_wchar_vstring(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 typedef struct _dcerpc_sub_dissector {
     guint16 num;
-    gchar   *name;
+    const gchar   *name;
     dcerpc_dissect_fnct_t *dissect_rqst;
     dcerpc_dissect_fnct_t *dissect_resp;
 } dcerpc_sub_dissector;
 
 /* registration function for subdissectors */
 void dcerpc_init_uuid (int proto, int ett, e_uuid_t *uuid, guint16 ver, dcerpc_sub_dissector *procs, int opnum_hf);
-char *dcerpc_get_proto_name(e_uuid_t *uuid, guint16 ver);
+const char *dcerpc_get_proto_name(e_uuid_t *uuid, guint16 ver);
 int dcerpc_get_proto_hf_opnum(e_uuid_t *uuid, guint16 ver);
 dcerpc_sub_dissector *dcerpc_get_proto_sub_dissector(e_uuid_t *uuid, guint16 ver);
 
@@ -254,7 +254,7 @@ dcerpc_sub_dissector *dcerpc_get_proto_sub_dissector(e_uuid_t *uuid, guint16 ver
 value_string *value_string_from_subdissectors(dcerpc_sub_dissector *sd);
 
 /* try to get protocol name registered for this uuid */
-gchar *dcerpc_get_uuid_name(e_uuid_t *uuid, guint16 ver);
+const gchar *dcerpc_get_uuid_name(e_uuid_t *uuid, guint16 ver);
 
 /* Private data passed to subdissectors from the main DCERPC dissector. */
 typedef struct _dcerpc_call_value {
@@ -306,7 +306,7 @@ typedef struct _dcerpc_uuid_value {
     protocol_t *proto;
     int proto_id;
     int ett;
-    gchar *name;
+    const gchar *name;
     dcerpc_sub_dissector *procs;
     int opnum_hf;
 } dcerpc_uuid_value;
