@@ -1,7 +1,7 @@
 /* packet-dcom.c
  * Routines for DCOM generics
  *
- * $Id: packet-dcom.c 14242 2005-04-30 16:08:29Z gerald $
+ * $Id: packet-dcom.c 15079 2005-07-26 08:01:16Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -406,6 +406,21 @@ static const value_string dcom_objref_signature_vals[] = {
 	{ 0,          NULL }
 };
 
+/* although flags, they doesn't seem to be used as such */
+static const value_string dcom_stdobjref_flag_vals[] = {
+	{ 0x0000, "SORF_NULL" },
+	{ 0x0001, "SORF_OXRES1" },
+	{ 0x0020, "SORF_OXRES2" },
+	{ 0x0040, "SORF_OXRES3" },
+	{ 0x0080, "SORF_OXRES4" },
+	{ 0x0100, "SORF_OXRES5" },
+	{ 0x0200, "SORF_OXRES6" },
+	{ 0x0400, "SORF_OXRES7" },
+	{ 0x0800, "SORF_OXRES8" },
+	{ 0x1000, "SORF_NOPING" },
+	{ 0,          NULL }
+};
+
 static const value_string dcom_dcerpc_pointer_vals[] = {
 	{ 0x72657355, "User" },
 	{ 0x42535452, "BSTR" },
@@ -643,8 +658,8 @@ dissect_dcom_simple_resp(tvbuff_t *tvb, int offset,
    Returns the associated string ptr on a match.
    Formats uuid number and returns the resulting string, on failure.
    (copied from val_to_str) */
-gchar* dcom_uuid_to_str(e_uuid_t *uuid) {
-  gchar *ret;
+const gchar* dcom_uuid_to_str(e_uuid_t *uuid) {
+  const gchar *ret;
   static gchar  str[3][64];
   static gchar *cur;
 
@@ -926,6 +941,7 @@ dissect_dcom_SAFEARRAY(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 	offset = dissect_dcom_dcerpc_array_size(tvb, offset, pinfo, sub_tree, drep, &u32ArraySize);
 
+    tvb_ensure_bytes_exist(tvb, offset, u32ArraySize * u32ElementSize);
 	u32VariableOffset = offset + u32ArraySize * u32ElementSize;
 
 	u32Tmp = u32ArraySize;
@@ -1135,10 +1151,10 @@ dissect_dcom_VARIANT(tvbuff_t *tvb, int offset, packet_info *pinfo,
 int
 dissect_dcom_append_UUID(tvbuff_t *tvb, int offset,
 	packet_info *pinfo, proto_tree *tree, guint8 *drep,
-	int hfindex, gchar *field_name, int field_index)
+	int hfindex, const gchar *field_name, int field_index)
 {
 	e_uuid_t uuid;
-	gchar *uuid_name;
+	const gchar *uuid_name;
 
 
 	offset = dissect_dcom_UUID(tvb, offset, pinfo, tree, drep, 
@@ -1165,6 +1181,7 @@ dissect_dcom_append_UUID(tvbuff_t *tvb, int offset,
 
 
 /* get a zero terminated wide character string from tvb */
+/* maxlength is including zero termination */
 /* XXX: is there a function existing somewhere, already implementing this? */
 int
 dcom_tvb_get_nwstringz0(tvbuff_t *tvb, gint offset, guint32 maxlength, gchar *pszStr)
@@ -1174,7 +1191,7 @@ dcom_tvb_get_nwstringz0(tvbuff_t *tvb, gint offset, guint32 maxlength, gchar *ps
 
 
 	/* get LPWSTR to ascii */
-	g_assert(maxlength > 0);
+	DISSECTOR_ASSERT(maxlength > 0);
 	u32Idx = 0;
 	pszStr[0] = 0;
 	while (u32Idx < maxlength-1) {
@@ -1232,13 +1249,18 @@ dissect_dcom_indexed_LPWSTR(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 	offset = dissect_dcom_dcerpc_array_size(tvb, offset, pinfo, sub_tree, drep, 
                         &u32ArraySize);
 
+    DISSECTOR_ASSERT(u32MaxStr != 0);
 	u32ArraySize++;	/* u32MaxStr is including zero termination */
 	if (u32ArraySize < u32MaxStr) {
 		u32MaxStr = u32ArraySize;
 	}
 
 	u32StrStart = offset;
-	offset = dcom_tvb_get_nwstringz0(tvb, offset, u32MaxStr, pszStr);
+    if(u32MaxStr != 0) {
+	    offset = dcom_tvb_get_nwstringz0(tvb, offset, u32MaxStr, pszStr);
+    } else {
+        strcpy(pszStr, "");
+    }
 
 #if GLIB_MAJOR_VERSION < 2
     pszEscaped = g_strescape(pszStr);
@@ -1317,13 +1339,18 @@ dissect_dcom_BSTR(tvbuff_t *tvb, gint offset, packet_info *pinfo,
 
 	u32RealOffset = offset + u32ArraySize*2;
 
+    DISSECTOR_ASSERT(u32MaxStr != 0);
 	u32ArraySize++;	/* u32MaxStr is including zero termination */
 	if (u32ArraySize < u32MaxStr) {
 		u32MaxStr = u32ArraySize;
 	}
 
 	u32StrStart = offset;
-	offset = dcom_tvb_get_nwstringz0(tvb, offset, u32MaxStr, pszStr);
+    if(u32MaxStr != 0) {
+	    offset = dcom_tvb_get_nwstringz0(tvb, offset, u32MaxStr, pszStr);
+    } else {
+        strcpy(pszStr, "");
+    }
 
 #if GLIB_MAJOR_VERSION < 2
     pszEscaped = g_strescape(pszStr);
@@ -1697,7 +1724,7 @@ proto_register_dcom (void)
 		{ &hf_dcom_stdobjref,
 		{ "STDOBJREF", "dcom.stdobjref", FT_NONE, BASE_HEX, NULL, 0x0, "", HFILL }},
 		{ &hf_dcom_stdobjref_flags,
-		{ "Flags", "dcom.stdobjref.flags", FT_UINT32, BASE_HEX, NULL, 0x0, "", HFILL }},
+		{ "Flags", "dcom.stdobjref.flags", FT_UINT32, BASE_HEX, VALS(dcom_stdobjref_flag_vals), 0x0, "", HFILL }},
 		{ &hf_dcom_stdobjref_public_refs,
 		{ "PublicRefs", "dcom.stdobjref.public_refs", FT_UINT32, BASE_HEX, NULL, 0x0, "", HFILL }},
 		{ &hf_dcom_stdobjref_oxid,
