@@ -1,7 +1,7 @@
 /* packet-dcom.h
  * Routines for DCOM generics
  *
- * $Id: packet-dcom.h 13198 2005-01-29 20:39:14Z guy $
+ * $Id: packet-dcom.h 15079 2005-07-26 08:01:16Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -59,8 +59,8 @@ dissect_dcom_that(tvbuff_t *tvb, int offset,
 extern int
 dissect_dcom_append_UUID(tvbuff_t *tvb, int offset,
 	packet_info *pinfo, proto_tree *tree, guint8 *drep,
-	int hfindex, gchar *field_name, int field_index);
-extern gchar* dcom_uuid_to_str(e_uuid_t *uuid);
+	int hfindex, const gchar *field_name, int field_index);
+extern const gchar* dcom_uuid_to_str(e_uuid_t *uuid);
 
 extern int
 dissect_dcom_indexed_WORD(tvbuff_t *tvb, int offset,	packet_info *pinfo,
