@@ -6,7 +6,7 @@
  * SHIRASAKI Yasuhiro <yasuhiro@gnome.gr.jp>
  * Tony Lindstrom <tony.lindstrom@ericsson.com>
  *
- * $Id: packet-dhcpv6.c 12868 2004-12-30 16:45:37Z gerald $
+ * $Id: packet-dhcpv6.c 14969 2005-07-20 12:20:56Z sahlberg $
  *
  * The information used comes from:
  * RFC3315.txt (DHCPv6)
@@ -48,6 +48,7 @@
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/ipv6-utils.h>
+#include "packet-arp.h"
 
 static int proto_dhcpv6 = -1;
 static int hf_dhcpv6_msgtype = -1;
@@ -229,26 +230,60 @@ static const true_false_string fqdn_s = {
 
 /* Adds domain */
 static void
-dhcpv6_domain(proto_tree * subtree, tvbuff_t *tvb, int off, guint16 optlen)
+dhcpv6_domain(proto_tree * subtree, tvbuff_t *tvb, int offset, guint16 optlen)
 {
+    int start_offset=offset;
+    char domain[256];
+    int pos;
     guint8 len;
-    char *domain;
 
-    while (optlen) {
-	len = tvb_get_guint8(tvb, off);
-	if (len==0)
-	    break;
-	if (len>optlen) {
-	    proto_tree_add_text(subtree, tvb, off, optlen, "Malformed option");
-	    return;
-	}
-	domain = tvb_get_string(tvb, off+1, len);
-	proto_tree_add_text(subtree, tvb, off, len+1, "Domain: %s", domain);
-	g_free(domain);
-	off    += len+1;
-	optlen -= len+1;
-    };
-}
+    pos=0;
+    while(optlen){
+        /* this is the start of the domain name */
+        if(!pos){
+            start_offset=offset;
+        }
+        domain[pos]=0;
+
+        /* read length of the next substring */
+        len = tvb_get_guint8(tvb, offset);
+        offset++;
+        optlen--;
+
+        /* if len==0 and pos>0 we have read an entire domain string */
+        if(!len){
+            if(!pos){
+                /* empty string, this must be an error? */
+                proto_tree_add_text(subtree, tvb, start_offset, offset-start_offset, "Malformed option");
+                return;
+            } else {
+                proto_tree_add_text(subtree, tvb, start_offset, offset-start_offset, "Domain: %s", domain);
+                pos=0;
+                continue;
+            }
+        }
+
+        /* add the substring to domain */
+        if(pos){
+            domain[pos]='.';
+            pos++;
+        }
+        if(pos+len>254){
+                /* too long string, this must be an error? */
+                proto_tree_add_text(subtree, tvb, start_offset, offset-start_offset, "Malformed option");
+                return;
+        }
+        tvb_memcpy(tvb, domain+pos, offset, len);
+        pos+=len;
+        offset+=len;
+        optlen-=len;
+    }        
+    
+    if(pos){
+        domain[pos]=0;
+        proto_tree_add_text(subtree, tvb, start_offset, offset-start_offset, "Domain: %s", domain);
+    }
+}    
 
 /* Returns the number of bytes consumed by this option. */
 static int
@@ -258,6 +293,7 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 	guint8 *buf;
 	guint16	opttype;
 	guint16	optlen;
+	guint16	hwtype;
 	guint16	temp_optlen = 0;
 	proto_item *ti;
 	proto_tree *subtree;
@@ -310,15 +346,18 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 					optlen, "DUID: malformed option");
 				break;
 			}
-			/* XXX seconds since Jan 1 2000 */
+			hwtype=tvb_get_ntohs(tvb, off + 2);
 			proto_tree_add_text(subtree, tvb, off + 2, 2,
-				"Hardware type: %u",
-				tvb_get_ntohs(tvb, off + 2));
+				"Hardware type: %s (%u)",
+				arphrdtype_to_str(hwtype, "Unknown"),
+				hwtype);
+			/* XXX seconds since Jan 1 2000 */
 			proto_tree_add_text(subtree, tvb, off + 4, 4,
 				"Time: %u", tvb_get_ntohl(tvb, off + 4));
 			if (optlen > 8) {
 				proto_tree_add_text(subtree, tvb, off + 8,
-					optlen - 8, "Link-layer address");
+					optlen - 8, "Link-layer address: %s",
+					arphrdaddr_to_str(tvb_get_ptr(tvb, off+8, optlen-8), optlen-8, hwtype));
 			}
 			break;
 		case DUID_EN:
@@ -341,12 +380,15 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 					optlen, "DUID: malformed option");
 				break;
 			}
+			hwtype=tvb_get_ntohs(tvb, off + 2);
 			proto_tree_add_text(subtree, tvb, off + 2, 2,
-				"Hardware type: %u",
-				tvb_get_ntohs(tvb, off + 2));
+				"Hardware type: %s (%u)",
+				arphrdtype_to_str(hwtype, "Unknown"),
+				hwtype);
 			if (optlen > 4) {
 				proto_tree_add_text(subtree, tvb, off + 4,
-					optlen - 4, "Link-layer address");
+					optlen - 4, "Link-layer address: %s",
+					arphrdaddr_to_str(tvb_get_ptr(tvb, off+4, optlen-4), optlen-4, hwtype));
 			}
 			break;
 		}
