@@ -2,7 +2,7 @@
  * Definitions for packet disassembly structures and routines used both by
  * DNS and NBNS.
  *
- * $Id: packet-dns.h 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-dns.h 14786 2005-06-26 19:56:52Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -27,14 +27,10 @@
 #ifndef __PACKET_DNS_H__
 #define __PACKET_DNS_H__
 
-char *dns_class_name(int class);
+const char *dns_class_name(int class);
 
 int get_dns_name(tvbuff_t *, int, int, char *, int);
 
 #define MAXDNAME        1025            /* maximum domain name length */
 
-proto_tree *
-add_rr_to_tree(proto_item *, int, tvbuff_t *, int, const char *,
-  int, const char *, const char *, guint, gushort);
-
 #endif /* packet-dns.h */
