@@ -2,7 +2,7 @@
  * Routines for EAP Extensible Authentication Protocol dissection
  * RFC 2284, RFC 3748
  *
- * $Id: packet-eap.c 12167 2004-10-01 07:29:22Z guy $
+ * $Id: packet-eap.c 15046 2005-07-24 20:39:19Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -31,7 +31,7 @@
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include "ppptypes.h"
-#include "reassemble.h"
+#include <epan/reassemble.h>
 
 static int proto_eap = -1;
 static int hf_eap_code = -1;
@@ -597,8 +597,7 @@ dissect_eap_aka(proto_tree *eap_tree, tvbuff_t *tvb, int offset, gint size)
 }
 
 static int
-dissect_eap_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
-		 gboolean fragmented)
+dissect_eap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
   guint8      eap_code;
   guint8      eap_id;
@@ -647,21 +646,21 @@ dissect_eap_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
    * keep them separate?  (Or is that not going to happen?)
    */
   if (pinfo->destport == pinfo->match_port) {
-    conversation = find_conversation(&pinfo->dst, &pinfo->src,
+    conversation = find_conversation(pinfo->fd->num, &pinfo->dst, &pinfo->src,
 				     pinfo->ptype, pinfo->destport,
 				     0, NO_PORT_B);
   } else {
-    conversation = find_conversation(&pinfo->src, &pinfo->dst,
+    conversation = find_conversation(pinfo->fd->num, &pinfo->src, &pinfo->dst,
 				     pinfo->ptype, pinfo->srcport,
 				     0, NO_PORT_B);
   }
   if (conversation == NULL) {
     if (pinfo->destport == pinfo->match_port) {
-      conversation = conversation_new(&pinfo->dst, &pinfo->src,
+      conversation = conversation_new(pinfo->fd->num, &pinfo->dst, &pinfo->src,
 				      pinfo->ptype, pinfo->destport,
 				      0, NO_PORT2);
     } else {
-      conversation = conversation_new(&pinfo->src, &pinfo->dst,
+      conversation = conversation_new(pinfo->fd->num, &pinfo->src, &pinfo->dst,
 				      pinfo->ptype, pinfo->srcport,
 				      0, NO_PORT2);
     }
@@ -695,18 +694,6 @@ dissect_eap_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   eap_len = tvb_get_ntohs(tvb, 2);
   len = eap_len;
 
-  if (fragmented) {
-    /*
-     * This is an EAP fragment inside, for example, RADIUS.  If we don't
-     * have all of the packet data, return the negative of the amount of
-     * additional data we need.
-     */
-    int reported_len = tvb_reported_length_remaining(tvb, 0);
-
-    if (reported_len < len)
-      return -(len - reported_len);
-  }
-
   if (tree) {
     ti = proto_tree_add_item(tree, proto_eap, tvb, 0, len, FALSE);
     eap_tree = proto_item_add_subtree(ti, ett_eap);
@@ -1003,6 +990,7 @@ dissect_eap_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 	    if (fd_head != NULL)            /* Reassembled  */
 	      {
+		proto_item *frag_tree_item;
 
 		next_tvb = tvb_new_real_data(fd_head->data,
 					     fd_head->len,
@@ -1011,7 +999,7 @@ dissect_eap_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		add_new_data_source(pinfo, next_tvb, "Reassembled EAP-TLS");
 
 		show_fragment_seq_tree(fd_head, &eaptls_frag_items,
-		    eap_tree, pinfo, next_tvb);
+		    eap_tree, pinfo, next_tvb, &frag_tree_item);
 
 		call_dissector(ssl_handle, next_tvb, pinfo, eap_tree);
 
@@ -1189,18 +1177,6 @@ dissect_eap_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   return tvb_length(tvb);
 }
 
-static int
-dissect_eap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
-{
-  return dissect_eap_data(tvb, pinfo, tree, FALSE);
-}
-
-static int
-dissect_eap_fragment(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
-{
-  return dissect_eap_data(tvb, pinfo, tree, TRUE);
-}
-
 void
 proto_register_eap(void)
 {
@@ -1264,7 +1240,6 @@ proto_register_eap(void)
   register_init_routine(&eap_init_protocol);
 
   new_register_dissector("eap", dissect_eap, proto_eap);
-  new_register_dissector("eap_fragment", dissect_eap_fragment, proto_eap);
   register_init_routine(eaptls_defragment_init);
 }
 
