@@ -1,7 +1,7 @@
 /* packet-eth.c
  * Routines for ethernet packet disassembly
  *
- * $Id: packet-eth.c 14112 2005-04-17 05:14:44Z gerald $
+ * $Id: packet-eth.c 14884 2005-07-09 00:53:17Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -167,10 +167,10 @@ dissect_eth_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
   eth_hdr 		*volatile ehdr;
   volatile gboolean	is_802_2;
   proto_tree		*volatile fh_tree = NULL;
-  const char		*src_addr, *dst_addr;
+  const guint8		*src_addr, *dst_addr;
   static eth_hdr 	ehdrs[4];
   static int		ehdr_num=0;
-  proto_tree		*tree;
+  proto_tree		*volatile tree;
 
   ehdr_num++;
   if(ehdr_num>=4){
@@ -296,8 +296,8 @@ dissect_eth_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
       col_set_str(pinfo->cinfo, COL_INFO, "Ethernet II");
     if (parent_tree) {
       ti = proto_tree_add_protocol_format(parent_tree, proto_eth, tvb, 0, ETH_HEADER_SIZE,
-		"Ethernet II, Src: %s, Dst: %s",
-		ether_to_str(src_addr), ether_to_str(dst_addr));
+		"Ethernet II, Src: %s (%s), Dst: %s (%s)",
+		get_ether_name(src_addr), ether_to_str(src_addr), get_ether_name(dst_addr), ether_to_str(dst_addr));
 
       fh_tree = proto_item_add_subtree(ti, ett_ether2);
     }
@@ -388,11 +388,11 @@ add_ethernet_trailer(proto_tree *fh_tree, int trailer_id, tvbuff_t *tvb,
       guint32 fcs = crc32_802_tvb(tvb, tvb_length(tvb) - 4);
       if (fcs == sent_fcs) {
 	proto_tree_add_text(fh_tree, trailer_tvb, trailer_length, 4,
-			    "Frame check sequence: 0x%08x (correct)",
+			    "Frame check sequence: 0x%08x [correct]",
 			    sent_fcs);
       } else {
 	proto_tree_add_text(fh_tree, trailer_tvb, trailer_length, 4,
-			    "Frame check sequence: 0x%08x (incorrect, should be 0x%08x)",
+			    "Frame check sequence: 0x%08x [incorrect, should be 0x%08x]",
 			    sent_fcs, fcs);
       }
     }
