@@ -2,7 +2,7 @@
  * Routines for FC distributed Name Server (dNS)
  * Copyright 2001, Dinesh G Dutt <ddutt@andiamo.com>
  *
- * $Id: packet-fcdns.c 13243 2005-02-02 20:07:03Z etxrab $
+ * $Id: packet-fcdns.c 13967 2005-03-29 14:56:09Z gerald $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -1917,7 +1917,7 @@ proto_register_fcdns (void)
     
     /* Register the protocol name and description */
     proto_fcdns = proto_register_protocol("Fibre Channel Name Server",
-                                          "FC-dNS", "FC-dNS");
+                                          "FC-dNS", "fcdns");
 
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_fcdns, hf, array_length(hf));
