@@ -2,7 +2,7 @@
  * Routines for FC Fabric Zone Server
  * Copyright 2001, Dinesh G Dutt <ddutt@andiamo.com>
  *
- * $Id: packet-fcfzs.c 13243 2005-02-02 20:07:03Z etxrab $
+ * $Id: packet-fcfzs.c 13967 2005-03-29 14:56:09Z gerald $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -897,7 +897,7 @@ proto_register_fcfzs(void)
     };
 
     /* Register the protocol name and description */
-    proto_fcfzs = proto_register_protocol("Fibre Channel Fabric Zone Server", "FC FZS", "FZS");
+    proto_fcfzs = proto_register_protocol("Fibre Channel Fabric Zone Server", "FC FZS", "fcfzs");
 
     /* Required function calls to register the header fields and subtrees used */
     proto_register_field_array(proto_fcfzs, hf, array_length(hf));
