@@ -3,7 +3,7 @@
  * RFC 3821, RFC 3643
  * Copyright 2001, Dinesh G Dutt (ddutt@cisco.com)
  *
- * $Id: packet-fcip.c 12906 2004-12-31 21:20:46Z guy $
+ * $Id: packet-fcip.c 14796 2005-06-27 08:27:49Z sahlberg $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -173,7 +173,7 @@ get_next_fcip_header_offset (tvbuff_t *tvb, packet_info *pinfo, gint offset)
      * c)  Replication of encapsulation word 0 in word 1 (1 test);
      * d)  Reserved field and its ones complement (2 tests);
      * e)  Flags field and its ones complement (2 tests);
-     * f)  CRC field is equal to zero (1 test);
+     *    f)  CRC field is equal to zero (1 test); (DONT DO THIS TEST!)
      * g)  SOF fields and ones complement fields (4 tests);
      * h)  Format and values of FC header (1 test);
      * i)  CRC of FC Frame (2 tests);
@@ -268,14 +268,12 @@ NXT_BYTE: while (bytes_remaining) {
         }
         
         /* Test e */
-        
-        /* Test f */
-        if (tvb_get_ntohl (tvb, offset+24)) {
-            /* Failed */
-            offset++;
-            bytes_remaining--;
-            goto NXT_BYTE;
-        }
+
+
+        /* Test f
+	 * We dont test this since some implementations actually provide
+	 * a CRC here.
+	 */
         
         if (bytes_remaining >= (frame_len)) {
             if (tvb_bytes_exist (tvb, offset+frame_len, 8)) {
