@@ -4,7 +4,7 @@
  *
  * Based on CORBAv2.4.2  Chapter 15 GIOP Description.
  *
- * $Id: packet-giop.h 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-giop.h 15043 2005-07-24 19:01:28Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -105,7 +105,7 @@ typedef gboolean (giop_sub_dissector_t)(tvbuff_t *, packet_info *, proto_tree *,
 
 typedef struct giop_sub_handle {
   giop_sub_dissector_t *sub_fn;  /* ptr to sub dissector function */
-  gchar *sub_name;	         /* subdissector string name */
+  const gchar *sub_name;         /* subdissector string name */
   protocol_t *sub_proto;         /* protocol_t for subprotocol */
 } giop_sub_handle_t;
 
@@ -118,7 +118,7 @@ extern gboolean dissect_giop(tvbuff_t *, packet_info *, proto_tree *); /* new in
  * This is for heuristic dissection
  */
 
-extern void register_giop_user(giop_sub_dissector_t *sub, gchar *name,
+extern void register_giop_user(giop_sub_dissector_t *sub, const gchar *name,
     int sub_proto);
 
 /*
