@@ -2,7 +2,7 @@
  * Routines for the Generic Routing Encapsulation (GRE) protocol
  * Brad Robel-Forrest <brad.robel-forrest@watchguard.com>
  *
- * $Id: packet-gre.c 14076 2005-04-14 09:29:23Z sahlberg $
+ * $Id: packet-gre.c 14880 2005-07-08 22:11:13Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -174,10 +174,10 @@ dissect_gre(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	computed_cksum = in_cksum(cksum_vec, 1);
 	if (computed_cksum == 0) {
 	  proto_tree_add_text(gre_tree, tvb, offset, 2,
-			"Checksum: 0x%04x (correct)", cksum);
+			"Checksum: 0x%04x [correct]", cksum);
 	} else {
 	  proto_tree_add_text(gre_tree, tvb, offset, 2,
-			"Checksum: 0x%04x (incorrect, should be 0x%04x)",
+			"Checksum: 0x%04x [incorrect, should be 0x%04x]",
 			cksum, in_cksum_shouldbe(cksum, computed_cksum));
 	}
       } else {
