@@ -1,7 +1,7 @@
 /* packet-gsm_sms_ud.c
  * Routines for GSM SMS TP-UD (GSM 03.40) dissection
  *
- * $Id: packet-gsm_sms_ud.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-gsm_sms_ud.c 14608 2005-06-10 18:28:22Z ulfl $
  *
  * Refer to the AUTHORS file or the AUTHORS section in the man page
  * for contacting the author(s) of this file.
@@ -70,7 +70,7 @@
 #include <epan/packet.h>
 
 #include <epan/prefs.h>
-#include "reassemble.h"
+#include <epan/reassemble.h>
 
 static void dissect_gsm_sms_ud(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 
@@ -632,7 +632,7 @@ proto_reg_handoff_gsm_sms_ud(void)
 			proto_gsm_sms_ud);
 			
 	wsp_handle = find_dissector("wsp-cl");
-	g_assert(wsp_handle);
+	DISSECTOR_ASSERT(wsp_handle);
 }
 
 
