@@ -3,7 +3,7 @@
  * Copyright 2004 _FF_ 
  * Francesco Fondelli <fondelli dot francesco, tiscali dot it>
  *
- * $Id: packet-icep.c 14176 2005-04-24 00:36:11Z gerald $
+ * $Id: packet-icep.c 15027 2005-07-24 02:43:41Z sahlberg $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -72,7 +72,7 @@
 #endif /* 0/1 */
 
 /* fixed values taken from the standard */
-#define ICEP_MAGIC				"IceP"
+static const guint8 icep_magic[] = { 'I', 'c', 'e', 'P' };
 #define ICEP_HEADER_SIZE			14
 #define ICEP_MIN_REPLY_SIZE			5
 #define ICEP_MIN_PARAMS_SIZE			6
@@ -158,8 +158,6 @@ static packet_info *mypinfo;
  * This function dissects an "Ice string", adds hf to "tree" and returns consumed 
  * bytes in "*consumed", if errors "*consumed" is -1.
  *
- * Memory for the new string "*dest" is obtained with g_malloc, and caller 
- * is responsible for it (i.e. don't forget to g_free() it if you pass *dest != NULL).
  * "*dest" is a null terminated version of the dissected Ice string.
  */
 static void dissect_ice_string(proto_tree *tree, int hf_icep, 
@@ -174,7 +172,6 @@ static void dissect_ice_string(proto_tree *tree, int hf_icep,
 	 */
 	
 	guint32 Size = 0;
-	const char *p;
 	char *s = NULL;
 	
 	(*consumed) = 0;
@@ -259,16 +256,11 @@ static void dissect_ice_string(proto_tree *tree, int hf_icep,
 	
 		
 	if ( Size != 0 ) {
-		p = tvb_get_ptr(tvb, offset, Size);
-		s = g_malloc(Size + 1);
-		strncpy(s, p, Size);
-		s[Size] = '\0';
+		s = ep_tvb_get_string(tvb, offset, Size);
 		if (tree && add_hf)
 			proto_tree_add_string(tree, hf_icep, tvb, offset, Size, s);
 	} else {
-		s = g_malloc( strlen("(empty)") + 1 );
-		sprintf(s, "(empty)");
-		s[strlen("(empty)")] = '\0';
+		s = g_strdup("(empty)");
 		/* display the 0x00 Size byte when click on a empty ice_string */
 		if (tree && add_hf)
 			proto_tree_add_string(tree, hf_icep, tvb, offset - 1, 1, s);
@@ -276,8 +268,6 @@ static void dissect_ice_string(proto_tree *tree, int hf_icep,
 	
 	if ( dest != NULL )
 		*dest = s;
-	else
-		g_free(s);
 	
 	offset += Size;
 	(*consumed) += Size;
@@ -490,7 +480,6 @@ static void dissect_ice_context(proto_tree *tree, tvbuff_t *tvb, guint32 offset,
 		
 		if ( consumed_key == -1 ) {
 			(*consumed) = -1;
-			g_free(str_key);
 			return;
 		}
 		
@@ -502,8 +491,6 @@ static void dissect_ice_context(proto_tree *tree, tvbuff_t *tvb, guint32 offset,
 		
 		if ( consumed_value == -1 ) {
 			(*consumed) = -1;
-			g_free(str_value);
-			g_free(str_key);
 			return;
 		}
 		
@@ -519,8 +506,6 @@ static void dissect_ice_context(proto_tree *tree, tvbuff_t *tvb, guint32 offset,
 					    str_key, str_value);
 		}
 		
-		g_free(str_value);
-		g_free(str_key);
 	}
 }
 
@@ -739,8 +724,6 @@ static void dissect_icep_request_common(tvbuff_t *tvb, guint32 offset,
 				col_append_fstr(mypinfo->cinfo, COL_INFO, " %s.%s()", 
 						namestr, opstr);
 			}
-			g_free(opstr);
-			g_free(namestr);
 			opstr = NULL;
 			namestr = NULL;
 		}
@@ -796,10 +779,6 @@ static void dissect_icep_request_common(tvbuff_t *tvb, guint32 offset,
 	
 error:
 	(*total_consumed) = -1;
-	if (namestr)
-		g_free(namestr);
-	if (opstr)
-		g_free(opstr);
 }
 
 
@@ -1246,7 +1225,7 @@ static gboolean dissect_icep(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree
 	
         /* check for magic string (taken from packet-giop.c) */
 	
-	if ( tvb_memeql(tvb, 0, ICEP_MAGIC, 4) == -1 ) {
+	if ( tvb_memeql(tvb, 0, icep_magic, 4) == -1 ) {
 		/* Not a ICEP packet. */
 		return FALSE;
 	}
