@@ -1,7 +1,7 @@
 /* packet-icmpv6.c
  * Routines for ICMPv6 packet disassembly
  *
- * $Id: packet-icmpv6.c 13999 2005-04-01 10:17:05Z sahlberg $
+ * $Id: packet-icmpv6.c 14880 2005-07-08 22:11:13Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -1016,8 +1016,8 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_item *ti, *tf = NULL;
     struct icmp6_hdr icmp6_hdr, *dp;
     struct icmp6_nodeinfo *ni = NULL;
-    char *codename, *typename;
-    char *colcodename, *coltypename;
+    const char *codename, *typename;
+    const char *colcodename, *coltypename;
     int len;
     guint length, reported_length;
     vec_t cksum_vec[4];
@@ -1274,7 +1274,7 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			tvb,
 			offset + offsetof(struct icmp6_hdr, icmp6_cksum), 2,
 			cksum,
-			"Checksum: 0x%04x (correct)", cksum);
+			"Checksum: 0x%04x [correct]", cksum);
 	    } else {
 		proto_tree_add_boolean_hidden(icmp6_tree, hf_icmpv6_checksum_bad,
 			tvb,
@@ -1284,7 +1284,7 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			tvb,
 			offset + offsetof(struct icmp6_hdr, icmp6_cksum), 2,
 			cksum,
-			"Checksum: 0x%04x (incorrect, should be 0x%04x)",
+			"Checksum: 0x%04x [incorrect, should be 0x%04x]",
 			cksum, in_cksum_shouldbe(cksum, computed_cksum));
 	    }
 	} else {
