@@ -1,7 +1,7 @@
 /* packet-igmp.c   2001 Ronnie Sahlberg <See AUTHORS for email>
  * Routines for IGMP packet disassembly
  *
- * $Id: packet-igmp.c 13990 2005-04-01 04:19:28Z guy $
+ * $Id: packet-igmp.c 14884 2005-07-09 00:53:17Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -340,13 +340,13 @@ void igmp_checksum(proto_tree *tree, tvbuff_t *tvb, int hf_index,
 		if (cksum == 0) {
 			proto_tree_add_uint_format(tree, hf_index,
 			    tvb, 2, 2, hdrcksum,
-			    "Header checksum: 0x%04x (correct)", hdrcksum);
+			    "Header checksum: 0x%04x [correct]", hdrcksum);
 		} else {
 			proto_tree_add_boolean_hidden(tree, hf_index_bad,
 			    tvb, 2, 2, TRUE);
 			proto_tree_add_uint_format(tree, hf_index,
 			    tvb, 2, 2, hdrcksum,
-			    "Header checksum: 0x%04x (incorrect, should be 0x%04x)", hdrcksum,in_cksum_shouldbe(hdrcksum,cksum));
+			    "Header checksum: 0x%04x [incorrect, should be 0x%04x]", hdrcksum,in_cksum_shouldbe(hdrcksum,cksum));
 		}
 	} else
 		proto_tree_add_uint(tree, hf_index, tvb, 2, 2, hdrcksum);
@@ -452,7 +452,7 @@ dissect_v3_group_record(tvbuff_t *tvb, proto_tree *parent_tree, int offset)
 	tvb_memcpy(tvb, (guint8 *)&ip, offset+4, 4);
 	item = proto_tree_add_text(parent_tree, tvb, offset, -1,
 		"Group Record : %s  %s",
-			ip_to_str((gchar*)&ip),
+			ip_to_str((guint8*)&ip),
 			val_to_str(tvb_get_guint8(tvb, offset), vs_record_type,"")
 		);
 	tree = proto_item_add_subtree(item, ett_group_record);
