@@ -3,7 +3,7 @@
  * Routines for image/gif media dissection
  * Copyright 2003, 2004, Olivier Biot.
  *
- * $Id: packet-image-gif.c 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-image-gif.c 14459 2005-05-28 00:51:56Z obiot $
  *
  * Refer to the AUTHORS file or the AUTHORS section in the man page
  * for contacting the author(s) of this file.
@@ -66,8 +66,6 @@
 #define DebugLog(x) ;
 #endif
 
-#define PLURALIZE(x) ((x) == 1 ? "" : "s")
-
 #define IMG_GIF "image-gif"
 
 /************************** Variable declarations **************************/
@@ -227,8 +225,8 @@ dissect_gif(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 			proto_item_append_text(ti, " (Global color table present)");
 		proto_item_append_text(ti,
 				" (%u bit%s per color) (%u bit%s per pixel)",
-				color_resolution, PLURALIZE(color_resolution),
-				image_bpp, PLURALIZE(image_bpp));
+				color_resolution, plurality(color_resolution, "", "s"),
+				image_bpp, plurality(image_bpp, "", "s"));
 		subtree = proto_item_add_subtree(ti, ett_global_flags);
 		proto_tree_add_item(subtree, hf_global_color_map_present,
 				tvb, 10, 1, TRUE);
@@ -392,8 +390,8 @@ dissect_gif(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 					proto_item_append_text(ti2, " (Local color table present)");
 				proto_item_append_text(ti2,
 						" (%u bit%s per color) (%u bit%s per pixel)",
-						color_resolution, PLURALIZE(color_resolution),
-						image_bpp, PLURALIZE(image_bpp));
+						color_resolution, plurality(color_resolution, "", "s"),
+						image_bpp, plurality(image_bpp, "", "s"));
 				subtree2 = proto_item_add_subtree(ti2, ett_local_flags);
 				proto_tree_add_item(subtree2, hf_local_color_map_present,
 						tvb, offset, 1, TRUE);
@@ -442,6 +440,8 @@ dissect_gif(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 			}
 		} /* while */
 	}
+	else
+		g_free(str);
 }
 
 
@@ -616,7 +616,7 @@ proto_register_gif(void)
 		{ &hf_image,
 			{	"Image",
 				IMG_GIF ".image",
-				FT_NONE, BASE_NONE, NULL, 0x80,
+				FT_NONE, BASE_NONE, NULL, 0x00,
 				"Image.",
 				HFILL
 			}
