@@ -3,7 +3,7 @@
  * Routines for JFIF image/jpeg media dissection
  * Copyright 2004, Olivier Biot.
  *
- * $Id: packet-image-jfif.c 12071 2004-09-23 17:39:13Z guy $
+ * $Id: packet-image-jfif.c 14786 2005-06-26 19:56:52Z guy $
  *
  * Refer to the AUTHORS file or the AUTHORS section in the man page
  * for contacting the author(s) of this file.
@@ -69,8 +69,6 @@
 #define DebugLog(x) ;
 #endif
 
-#define PLURALIZE(x) ((x) == 1 ? "" : "s")
-
 #define IMG_JFIF "image-jfif"
 
 /************************** Variable declarations **************************/
@@ -519,6 +517,7 @@ process_app0_segment(proto_tree *tree, tvbuff_t *tvb, guint32 len,
 	str = tvb_get_stringz(tvb, 4, &str_size);
 	ti = proto_tree_add_item(subtree, hf_identifier, tvb, 4, str_size, FALSE);
 	if (strcmp(str, "JFIF") == 0) {
+		g_free(str);
 		/* Version */
 		ti = proto_tree_add_none_format(subtree, hf_version,
 				tvb, 9, 2, "Version: %u.%u",
@@ -556,6 +555,7 @@ process_app0_segment(proto_tree *tree, tvbuff_t *tvb, guint32 len,
 			}
 		}
 	} else if (strcmp(str, "JFXX") == 0) {
+		g_free(str);
 		proto_tree_add_item(subtree, hf_extension_code,
 				tvb, 9, 1, FALSE);
 		{
@@ -572,13 +572,13 @@ process_app0_segment(proto_tree *tree, tvbuff_t *tvb, guint32 len,
 			}
 		}
 	} else { /* Unknown */
+		g_free(str);
 		proto_item_append_text(ti, " (unknown identifier)");
 		offset = 4 + str_size;
 
 		proto_tree_add_text(subtree, tvb, offset, -1,
 				"Remaining segment data (%u bytes)", len - 2 - str_size);
 	}
-
 	return;
 }
 
@@ -594,7 +594,8 @@ process_app1_segment(proto_tree *tree, tvbuff_t *tvb, guint32 len,
 	proto_tree *subtree = NULL;
 	char *str;
 	gint str_size;
-	guint32 offset, tiff_start;
+	int offset = 0;
+	int tiff_start;
 
 	if (!tree)
 		return;
@@ -604,13 +605,15 @@ process_app1_segment(proto_tree *tree, tvbuff_t *tvb, guint32 len,
 	subtree = proto_item_add_subtree(ti, ett_marker_segment);
 
 	proto_item_append_text(ti, ": %s (0x%04X)", marker_name, marker);
-	proto_tree_add_item(subtree, hf_marker, tvb, 0, 2, FALSE);
+	proto_tree_add_item(subtree, hf_marker, tvb, offset, 2, FALSE);
+	offset += 2;
 
-	proto_tree_add_item(subtree, hf_len, tvb, 2, 2, FALSE);
+	proto_tree_add_item(subtree, hf_len, tvb, offset, 2, FALSE);
+	offset += 2;
 
-	str = tvb_get_stringz(tvb, 4, &str_size);
-	ti = proto_tree_add_item(subtree, hf_identifier, tvb, 4, str_size, FALSE);
-	offset = tiff_start = 4 + str_size;
+	str = tvb_get_stringz(tvb, offset, &str_size);
+	ti = proto_tree_add_item(subtree, hf_identifier, tvb, offset, str_size, FALSE);
+	offset += str_size;
 	if (strcmp(str, "Exif") == 0) {
 		/*
 		 * Endianness
@@ -620,8 +623,11 @@ process_app1_segment(proto_tree *tree, tvbuff_t *tvb, guint32 len,
 		guint32 val_32;
 		guint16 num_fields;
 
+		g_free(str);
+
 		offset++; /* Skip a byte supposed to be 0x00 */
 
+		tiff_start = offset;
 		val_16 = tvb_get_ntohs(tvb, offset);
 		if (val_16 == 0x4949) {
 			is_little_endian = TRUE;
@@ -643,69 +649,96 @@ process_app1_segment(proto_tree *tree, tvbuff_t *tvb, guint32 len,
 		/*
 		 * Offset to IFD
 		 */
-		if (is_little_endian) {
-			val_16 = tvb_get_letohs(tvb, offset);
-		} else {
-			val_16 = tvb_get_ntohs(tvb, offset);
-		}
-		proto_tree_add_text(subtree, tvb, offset, 4,
-				"Start offset of IFD starting from the TIFF header start: %u bytes", val_16);
-		offset += 4;
-		/*
-		 * Skip the following portion
-		 */
-		proto_tree_add_text(subtree, tvb, offset, val_16 + tiff_start - offset,
-				"Skipped data between end of TIFF header and start of IFD (%u bytes)",
-				val_16 + tiff_start - offset);
-		offset = val_16 + tiff_start + 1;
-		/*
-		 * Process the "0th" IFD
-		 */
-		if (is_little_endian) {
-			num_fields = tvb_get_letohs(tvb, offset);
-		} else {
-			num_fields = tvb_get_ntohs(tvb, offset);
-		}
-		proto_tree_add_text(subtree, tvb, offset, 2, "Number of fields in this IFD: %u", num_fields);
-		offset += 2;
-		while (num_fields-- > 0) {
-			guint16 tag, type;
-			guint32 count, off;
-
-			if (is_little_endian) {
-				tag = tvb_get_letohs(tvb, offset);
-				type = tvb_get_letohs(tvb, offset + 2);
-				count = tvb_get_letohl(tvb, offset + 4);
-				off = tvb_get_letohl(tvb, offset + 8);
-			} else {
-				tag = tvb_get_ntohs(tvb, offset);
-				type = tvb_get_ntohs(tvb, offset + 2);
-				count = tvb_get_ntohl(tvb, offset + 4);
-				off = tvb_get_ntohl(tvb, offset + 8);
-			}
-			/* TODO - refine this */
-			proto_tree_add_text(subtree, tvb, offset, 2,
-					"Exif Tag: 0x%04X (%s), Type: %u (%s), Count: %u, "
-					"Value offset from start of TIFF header: %u",
-					tag, val_to_str(tag, vals_exif_tags, "Unknown Exif tag"),
-					type, val_to_str(type, vals_exif_types, "Unknown Exif type"),
-					count, off);
-			offset += 12;
-		}
-		/*
-		 * Offset to the "1st" IFD
-		 */
 		if (is_little_endian) {
 			val_32 = tvb_get_letohl(tvb, offset);
 		} else {
 			val_32 = tvb_get_ntohl(tvb, offset);
 		}
+		/*
+		 * Check for a bogus val_32 value.
+		 * XXX - bogus value message should also deal with a
+		 * value that's too large and causes an overflow.
+		 * Or should it just check against the segment length,
+		 * which is 16 bits?
+		 */
+		if (val_32 + tiff_start < (guint32)offset + 4) {
+			proto_tree_add_text(subtree, tvb, offset, 4,
+			    "Start offset of IFD starting from the TIFF header start: %u bytes (bogus, should be >= %u",
+			    val_32, offset + 4 - tiff_start);
+			return;
+		}
 		proto_tree_add_text(subtree, tvb, offset, 4,
-				"Offset to next IFD from start of TIFF header: %u bytes", val_32);
-		/* TODO - Continue parsing the "1th" IFD */
+		    "Start offset of IFD starting from the TIFF header start: %u bytes",
+		    val_32);
 		offset += 4;
-		proto_tree_add_text(subtree, tvb, offset, -1, "Remainder of APP1 marker skipped");
+		/*
+		 * Skip the following portion
+		 */
+		if (val_32 + tiff_start > (guint32)offset) {
+			proto_tree_add_text(subtree, tvb, offset, val_32 + tiff_start - offset,
+			    "Skipped data between end of TIFF header and start of IFD (%u bytes)",
+			    val_32 + tiff_start - offset);
+		}
+		offset = val_32 + tiff_start;
+		for (;;) {
+			/*
+			 * Process the IFD
+			 */
+			if (is_little_endian) {
+				num_fields = tvb_get_letohs(tvb, offset);
+			} else {
+				num_fields = tvb_get_ntohs(tvb, offset);
+			}
+			proto_tree_add_text(subtree, tvb, offset, 2, "Number of fields in this IFD: %u", num_fields);
+			offset += 2;
+			while (num_fields-- > 0) {
+				guint16 tag, type;
+				guint32 count, off;
+
+				if (is_little_endian) {
+					tag = tvb_get_letohs(tvb, offset);
+					type = tvb_get_letohs(tvb, offset + 2);
+					count = tvb_get_letohl(tvb, offset + 4);
+					off = tvb_get_letohl(tvb, offset + 8);
+				} else {
+					tag = tvb_get_ntohs(tvb, offset);
+					type = tvb_get_ntohs(tvb, offset + 2);
+					count = tvb_get_ntohl(tvb, offset + 4);
+					off = tvb_get_ntohl(tvb, offset + 8);
+				}
+				/* TODO - refine this */
+				proto_tree_add_text(subtree, tvb, offset, 2,
+				    "Exif Tag: 0x%04X (%s), Type: %u (%s), Count: %u, "
+				    "Value offset from start of TIFF header: %u",
+				    tag, val_to_str(tag, vals_exif_tags, "Unknown Exif tag"),
+				    type, val_to_str(type, vals_exif_types, "Unknown Exif type"),
+				    count, off);
+				offset += 12;
+			}
+			/*
+			 * Offset to the next IFD
+			 */
+			if (is_little_endian) {
+				val_32 = tvb_get_letohl(tvb, offset);
+			} else {
+				val_32 = tvb_get_ntohl(tvb, offset);
+			}
+			if (val_32 != 0 &&
+			    val_32 + tiff_start < (guint32)offset + 4) {
+				proto_tree_add_text(subtree, tvb, offset, 4,
+				    "Offset to next IFD from start of TIFF header: %u bytes (bogus, should be >= %u)",
+				    val_32, offset + 4 - tiff_start);
+				return;
+			}
+			proto_tree_add_text(subtree, tvb, offset, 4,
+			    "Offset to next IFD from start of TIFF header: %u bytes",
+			    val_32);
+			offset += 4;
+			if (val_32 == 0)
+				break;
+		}
 	} else {
+		g_free(str);
 		proto_tree_add_text(subtree, tvb, offset, -1,
 				"Remaining segment data (%u bytes)", len - 2 - str_size);
 		proto_item_append_text(ti, " (Unknown identifier)");
@@ -740,8 +773,10 @@ process_app2_segment(proto_tree *tree, tvbuff_t *tvb, guint32 len,
 	str = tvb_get_stringz(tvb, 4, &str_size);
 	ti = proto_tree_add_item(subtree, hf_identifier, tvb, 4, str_size, FALSE);
 	if (strcmp(str, "FPXR") == 0) {
+		g_free(str);
 		proto_tree_add_text(tree, tvb, 0, -1, "Exif FlashPix APP2 application marker");
 	} else {
+		g_free(str);
 		proto_tree_add_text(subtree, tvb, 4 + str_size, -1,
 				"Remaining segment data (%u bytes)", len - 2 - str_size);
 		proto_item_append_text(ti, " (Unknown identifier)");
@@ -785,7 +820,7 @@ dissect_jfif(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 	 * Process the remaining markers and marker segments
 	 */
 	while (offset < tvb_len) {
-		char *str;
+		const char *str;
 		marker = tvb_get_ntohs(tvb, offset);
 		str = match_strval(marker, vals_marker);
 		if (str) { /* Known marker */
