@@ -1,12 +1,18 @@
 /* packet-ip.c
  * Routines for IP and miscellaneous IP protocol packet disassembly
  *
- * $Id: packet-ip.c 14051 2005-04-11 08:43:51Z sahlberg $
+ * $Id: packet-ip.c 15007 2005-07-23 00:46:14Z sahlberg $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
+ * Monday, June 27, 2005
+ * Support for the ICMP extensions for MPLS
+ * (http://www.ietf.org/proceedings/01aug/I-D/draft-ietf-mpls-icmp-02.txt)
+ * by   Maria-Luiza Crivat <luizacri@gmail.com>
+ * &    Brice Augustin <bricecotte@gmail.com>
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -56,7 +62,7 @@ static int ip_tap = -1;
 
 static void dissect_icmp(tvbuff_t *, packet_info *, proto_tree *);
 
-/* Decode the old IPv4 TOS field as the DiffServ DS Field */
+/* Decode the old IPv4 TOS field as the DiffServ DS Field (RFC2474/2475) */
 static gboolean g_ip_dscp_actif = TRUE;
 
 /* Defragment fragmented IP datagrams */
@@ -65,6 +71,10 @@ static gboolean ip_defragment = FALSE;
 /* Place IP summary in proto tree */
 static gboolean ip_summary_in_tree = TRUE;
 
+/* Decode the end of the ICMP payload as ICMP MPLS extensions
+if the packet in the payload has more than 128 bytes */
+static gboolean favor_icmp_mpls_ext = FALSE;
+
 static int proto_ip = -1;
 static int hf_ip_version = -1;
 static int hf_ip_hdr_len = -1;
@@ -81,8 +91,11 @@ static int hf_ip_tos_cost = -1;
 static int hf_ip_len = -1;
 static int hf_ip_id = -1;
 static int hf_ip_dst = -1;
+static int hf_ip_dst_host = -1;
 static int hf_ip_src = -1;
+static int hf_ip_src_host = -1;
 static int hf_ip_addr = -1;
+static int hf_ip_host = -1;
 static int hf_ip_flags = -1;
 static int hf_ip_flags_rf = -1;
 static int hf_ip_flags_df = -1;
@@ -161,9 +174,27 @@ static int hf_icmp_mip_reserved = -1;
 static int hf_icmp_mip_coa = -1;
 static int hf_icmp_mip_challenge = -1;
 
+/* MPLS extensions */
+static int hf_icmp_mpls = -1;
+static int hf_icmp_mpls_version = -1;
+static int hf_icmp_mpls_reserved = -1;
+static int hf_icmp_mpls_checksum = -1;
+static int hf_icmp_mpls_checksum_bad = -1;
+static int hf_icmp_mpls_length = -1;
+static int hf_icmp_mpls_class = -1;
+static int hf_icmp_mpls_c_type = -1;
+static int hf_icmp_mpls_label = -1;
+static int hf_icmp_mpls_exp = -1;
+static int hf_icmp_mpls_s = -1;
+static int hf_icmp_mpls_ttl = -1;
+
 static gint ett_icmp = -1;
 static gint ett_icmp_mip = -1;
 static gint ett_icmp_mip_flags = -1;
+/* MPLS extensions */
+static gint ett_icmp_mpls = -1;
+static gint ett_icmp_mpls_object = -1;
+static gint ett_icmp_mpls_stack_object = -1;
 
 /* ICMP definitions */
 
@@ -529,7 +560,7 @@ dissect_ipopt_timestamp(const ip_tcp_opt *optp, tvbuff_t *tvb,
           "(suboption would go past end of option)");
         break;
       }
-      tvb_memcpy(tvb, (char *)&addr, offset + optoffset, sizeof(addr));
+      tvb_memcpy(tvb, (guint8 *)&addr, offset + optoffset, sizeof(addr));
       ts = tvb_get_ntohl(tvb, offset + optoffset + 4);
       optlen -= 8;
       proto_tree_add_text(field_tree, tvb, offset + optoffset,      8,
@@ -834,6 +865,7 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
   const guchar		*src_addr, *dst_addr;
   guint32 		src32, dst32;
   proto_tree *tree;
+  proto_item *item;
 
   tree=parent_tree;
 
@@ -973,13 +1005,15 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
     if (tree) {
       if (ipsum == 0) {
 	proto_tree_add_uint_format(ip_tree, hf_ip_checksum, tvb, offset + 10, 2, iph->ip_sum,
-              "Header checksum: 0x%04x (correct)", iph->ip_sum);
+              "Header checksum: 0x%04x [correct]", iph->ip_sum);
       }
       else {
-	proto_tree_add_boolean_hidden(ip_tree, hf_ip_checksum_bad, tvb, offset + 10, 2, TRUE);
 	proto_tree_add_uint_format(ip_tree, hf_ip_checksum, tvb, offset + 10, 2, iph->ip_sum,
-          "Header checksum: 0x%04x (incorrect, should be 0x%04x)", iph->ip_sum,
+          "Header checksum: 0x%04x [incorrect, should be 0x%04x]", iph->ip_sum,
 	  in_cksum_shouldbe(iph->ip_sum, ipsum));
+	item = proto_tree_add_boolean(ip_tree, hf_ip_checksum_bad, tvb, offset + 10, 2, TRUE);
+	PROTO_ITEM_SET_GENERATED(item);
+    PROTO_ITEM_SET_HIDDEN(item);
       }
     }
   } else {
@@ -995,11 +1029,18 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
   if (tree) {
     memcpy(&addr, iph->ip_src.data, 4);
     if (ip_summary_in_tree) {
-      proto_item_append_text(ti, ", Src Addr: %s (%s)",
+      proto_item_append_text(ti, ", Src: %s (%s)",
 		get_hostname(addr), ip_to_str(iph->ip_src.data));
     }
     proto_tree_add_ipv4(ip_tree, hf_ip_src, tvb, offset + 12, 4, addr);
-    proto_tree_add_ipv4_hidden(ip_tree, hf_ip_addr, tvb, offset + 12, 4, addr);
+    item = proto_tree_add_ipv4(ip_tree, hf_ip_addr, tvb, offset + 12, 4, addr);
+    PROTO_ITEM_SET_HIDDEN(item);
+    item = proto_tree_add_string(ip_tree, hf_ip_src_host, tvb, offset + 12, 4, get_hostname(addr));
+    PROTO_ITEM_SET_GENERATED(item);
+    PROTO_ITEM_SET_HIDDEN(item);
+    item = proto_tree_add_string(ip_tree, hf_ip_host, tvb, offset + 12, 4, get_hostname(addr));
+    PROTO_ITEM_SET_GENERATED(item);
+    PROTO_ITEM_SET_HIDDEN(item);
   }
   dst_addr = tvb_get_ptr(tvb, offset + IPH_DST, 4);
   dst32 = tvb_get_ntohl(tvb, offset + IPH_DST);
@@ -1010,11 +1051,18 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
   if (tree) {
     memcpy(&addr, iph->ip_dst.data, 4);
     if (ip_summary_in_tree) {
-      proto_item_append_text(ti, ", Dst Addr: %s (%s)",
+      proto_item_append_text(ti, ", Dst: %s (%s)",
 		get_hostname(addr), ip_to_str(iph->ip_dst.data));
     }
     proto_tree_add_ipv4(ip_tree, hf_ip_dst, tvb, offset + 16, 4, addr);
-    proto_tree_add_ipv4_hidden(ip_tree, hf_ip_addr, tvb, offset + 16, 4, addr);
+    item = proto_tree_add_ipv4(ip_tree, hf_ip_addr, tvb, offset + 16, 4, addr);
+    PROTO_ITEM_SET_HIDDEN(item);
+    item = proto_tree_add_string(ip_tree, hf_ip_dst_host, tvb, offset + 16, 4, get_hostname(addr));
+    PROTO_ITEM_SET_GENERATED(item);
+    PROTO_ITEM_SET_HIDDEN(item);
+    item = proto_tree_add_string(ip_tree, hf_ip_host, tvb, offset + 16, 4, get_hostname(addr));
+    PROTO_ITEM_SET_GENERATED(item);
+    PROTO_ITEM_SET_HIDDEN(item);
   }
 
   if (tree) {
@@ -1275,6 +1323,282 @@ dissect_mip_extensions(tvbuff_t *tvb, size_t offset, proto_tree *tree)
 
 } /* dissect_mip_extensions */
 
+#define MPLS_STACK_ENTRY_OBJECT_CLASS           1
+#define MPLS_EXTENDED_PAYLOAD_OBJECT_CLASS      2
+
+#define MPLS_STACK_ENTRY_C_TYPE                 1
+#define MPLS_EXTENDED_PAYLOAD_C_TYPE            1
+
+/* XXX no header defines these macros ??? */
+#ifndef min
+#define min(a,b) (((a)<(b))?(a):(b))
+#endif
+
+#ifndef max
+#define max(a,b) (((a)>(b))?(a):(b))
+#endif
+
+/*
+ * Dissect the MPLS extensions
+ */
+static void
+dissect_mpls_extensions(tvbuff_t *tvb, size_t offset, proto_tree *tree)
+{
+    guint8          version;
+    guint8          class_num;
+    guint8          c_type;
+    guint8          ttl;
+    guint8          tmp;
+    guint16         reserved;
+    guint16         cksum, computed_cksum;
+    guint16         obj_length, obj_trunc_length;
+    proto_item      *ti, *tf_object, *tf_entry;
+    proto_tree      *mpls_tree=NULL, *mpls_object_tree, *mpls_stack_object_tree;
+    guint           obj_end_offset;
+    guint           reported_length;
+    guint           label;
+    gboolean        unknown_object;
+    
+    if (!tree)
+        return;
+    
+    reported_length = tvb_reported_length_remaining(tvb, offset);
+
+    if (reported_length < 4 /* Common header */)
+    {
+        proto_tree_add_text(tree, tvb, offset,
+                            reported_length,
+                            "MPLS Extensions (truncated)");
+        return;
+    }
+    
+    /* Add a tree for the MPLS extensions */           
+    ti = proto_tree_add_none_format(tree, hf_icmp_mpls, tvb,
+                                            offset, reported_length, "MPLS Extensions");
+
+    mpls_tree = proto_item_add_subtree(ti, ett_icmp_mpls);
+
+    /* Version */
+    version = hi_nibble(tvb_get_guint8(tvb, offset));
+    proto_tree_add_uint(mpls_tree, hf_icmp_mpls_version, tvb, offset, 1, version);
+
+    /* Reserved */
+    reserved = tvb_get_ntohs(tvb, offset) & 0x0fff;
+    proto_tree_add_uint_format(mpls_tree, hf_icmp_mpls_reserved,
+                                tvb, offset, 2, reserved,
+                                "Reserved: 0x%03x", reserved);
+
+    /* Checksum */
+    cksum = tvb_get_ntohs(tvb, offset + 2);
+    
+    computed_cksum = ip_checksum(tvb_get_ptr(tvb, offset, reported_length),
+                                    reported_length);
+
+    if (computed_cksum == 0)
+    {
+        proto_tree_add_uint_format(mpls_tree, hf_icmp_mpls_checksum, tvb, offset + 2, 2,
+                                    cksum, "Checksum: 0x%04x [correct]", cksum);
+    }
+    else
+    {
+        proto_tree_add_boolean_hidden(mpls_tree, hf_icmp_mpls_checksum_bad, tvb,
+                                            offset + 2, 2, TRUE);
+
+        proto_tree_add_uint_format(mpls_tree, hf_icmp_mpls_checksum, tvb, offset + 2, 2,
+                                    cksum,
+                                    "Checksum: 0x%04x [incorrect, should be 0x%04x]",
+                                    cksum, in_cksum_shouldbe(cksum, computed_cksum));
+    }
+
+    if (version != 1 && version != 2)
+    {
+        /* Unsupported version */
+        proto_item_append_text(ti, " (unsupported version)");
+        return;
+    }
+
+    /* Skip the common header */
+    offset += 4;
+
+    /* While there is enough room to read an object */
+    while (tvb_reported_length_remaining(tvb, offset) >= 4 /* Object header */)
+    {
+        /* Object length */
+        obj_length = tvb_get_ntohs(tvb, offset);
+
+        obj_trunc_length =  min(obj_length, tvb_reported_length_remaining(tvb, offset));
+
+        obj_end_offset = offset + obj_trunc_length;
+
+        /* Add a subtree for this object (the text will be reset later) */
+        tf_object = proto_tree_add_text(mpls_tree, tvb, offset,
+                                        max(obj_trunc_length, 4),
+                                        "Unknown object");
+
+        mpls_object_tree = proto_item_add_subtree(tf_object, ett_icmp_mpls_object);
+
+        proto_tree_add_uint(mpls_object_tree, hf_icmp_mpls_length, tvb, offset, 2, obj_length);
+
+        /* Class */
+        class_num = tvb_get_guint8(tvb, offset + 2);
+        proto_tree_add_uint(mpls_object_tree, hf_icmp_mpls_class, tvb, offset + 2, 1, class_num);
+
+        /* C-Type */
+        c_type = tvb_get_guint8(tvb, offset + 3);
+        proto_tree_add_uint(mpls_object_tree, hf_icmp_mpls_c_type, tvb, offset + 3, 1, c_type);
+
+        if (obj_length < 4 /* Object header */)
+        {
+            /* Thanks doc/README.developer :)) */
+            proto_item_set_text(tf_object, "Object with bad length");
+            break;
+        }
+
+        /* Skip the object header */
+        offset += 4;
+
+        /* Default cases will set this flag to TRUE */
+        unknown_object = FALSE;
+        
+        switch (class_num)
+        {
+            case MPLS_STACK_ENTRY_OBJECT_CLASS:
+                switch (c_type)
+                {
+                    case MPLS_STACK_ENTRY_C_TYPE:
+
+                        proto_item_set_text(tf_object, "MPLS Stack Entry");
+
+                        /* For each entry */
+                        while (offset + 4 <= obj_end_offset)
+                        {
+                            if (tvb_reported_length_remaining(tvb, offset) < 4)
+                            {
+                                /* Not enough room in the packet ! */
+                                break;
+                            }
+
+                            /* Create a subtree for each entry (the text will be set later) */
+                            tf_entry = proto_tree_add_text(mpls_object_tree,
+                                                            tvb, offset, 4, " ");
+                            mpls_stack_object_tree = proto_item_add_subtree(tf_entry, 
+                                                                            ett_icmp_mpls_stack_object);
+
+                            /* Label */
+                            label =  (guint)tvb_get_ntohs(tvb, offset);
+                            tmp = tvb_get_guint8(tvb, offset + 2);
+                            label = (label << 4) + (tmp >> 4);
+
+                            proto_tree_add_uint(mpls_stack_object_tree,
+                                                    hf_icmp_mpls_label,
+                                                    tvb,
+                                                    offset,
+                                                    3,
+                                                    label << 4);
+
+                            proto_item_set_text(tf_entry, "Label: %u", label);
+
+                            /* Experimental field (also called "CoS") */
+                            proto_tree_add_uint(mpls_stack_object_tree,
+                                                    hf_icmp_mpls_exp,
+                                                    tvb,
+                                                    offset + 2,
+                                                    1,
+                                                    tmp);
+
+                            proto_item_append_text(tf_entry, ", Exp: %u", (tmp >> 1) & 0x07);
+                                                    
+                            /* Stack bit */
+                            proto_tree_add_boolean(mpls_stack_object_tree,
+                                                    hf_icmp_mpls_s,
+                                                    tvb,
+                                                    offset + 2,
+                                                    1,
+                                                    tmp);
+
+                            proto_item_append_text(tf_entry, ", S: %u", tmp  & 0x01);
+                                                    
+                            /* TTL */
+                            ttl = tvb_get_guint8(tvb, offset + 3);
+
+                            proto_tree_add_item(mpls_stack_object_tree,
+                                                hf_icmp_mpls_ttl,
+                                                tvb,
+                                                offset + 3,
+                                                1,
+                                                FALSE);
+
+                            proto_item_append_text(tf_entry, ", TTL: %u", ttl);
+                                                
+                            /* Skip the entry */
+                            offset += 4;
+
+                        } /* end while */
+
+                        if (offset < obj_end_offset)
+                            proto_tree_add_text(mpls_object_tree, tvb,
+                                                offset,
+                                                obj_end_offset - offset,
+                                                "%ld junk bytes",
+                                                (long)(obj_end_offset - offset));
+
+                        break;
+                    default:
+
+                        unknown_object = TRUE;
+
+                        break;
+                } /* end switch c_type */
+                break;
+            case MPLS_EXTENDED_PAYLOAD_OBJECT_CLASS:
+                switch (c_type)
+                {
+                    case MPLS_EXTENDED_PAYLOAD_C_TYPE:
+                        proto_item_set_text(tf_object, "Extended Payload");
+
+                        /* This object contains some portion of the original packet
+                        that could not fit in the 128 bytes of the ICMP payload */
+                        if (obj_trunc_length > 4)
+                            proto_tree_add_text(mpls_object_tree, tvb,
+                                                offset, obj_trunc_length - 4,
+                                                "Data (%d bytes)", obj_trunc_length - 4);
+
+                        break;
+                    default:
+
+                        unknown_object = TRUE;
+
+                        break;
+                } /* end switch c_type */
+                break;
+            default:
+
+                unknown_object = TRUE;
+
+                break;
+        } /* end switch class_num */
+        
+        /* The switches couldn't decode the object */
+        if (unknown_object == TRUE)
+        {
+            proto_item_set_text(tf_object, "Unknown object (%d/%d)", class_num, c_type);
+            
+            if (obj_trunc_length > 4)
+                proto_tree_add_text(mpls_object_tree, tvb,
+                                    offset, obj_trunc_length - 4,
+                                    "Data (%d bytes)", obj_trunc_length - 4);
+        }
+        
+        /* */
+        if (obj_trunc_length < obj_length)
+            proto_item_append_text(tf_object, " (truncated)");
+
+        /* Go to the end of the object */
+        offset = obj_end_offset;
+
+    } /* end while */
+} /* end dissect_mpls_extensions */
+
 static const gchar *unreach_str[] = {"Network unreachable",
                                      "Host unreachable",
                                      "Protocol unreachable",
@@ -1331,6 +1655,7 @@ dissect_icmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   int        i;
   gboolean   save_in_error_pkt;
   tvbuff_t   *next_tvb;
+  proto_item *item;
 
   if (check_col(pinfo->cinfo, COL_PROTOCOL))
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "ICMP");
@@ -1449,13 +1774,14 @@ dissect_icmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       if (computed_cksum == 0) {
         proto_tree_add_uint_format(icmp_tree, hf_icmp_checksum, tvb, 2, 2,
  			  cksum,
-			  "Checksum: 0x%04x (correct)", cksum);
+			  "Checksum: 0x%04x [correct]", cksum);
       } else {
-        proto_tree_add_boolean_hidden(icmp_tree, hf_icmp_checksum_bad,
+        item = proto_tree_add_boolean(icmp_tree, hf_icmp_checksum_bad,
 			  tvb, 2, 2, TRUE);
+        PROTO_ITEM_SET_HIDDEN(item);
         proto_tree_add_uint_format(icmp_tree, hf_icmp_checksum, tvb, 2, 2,
 		  cksum,
-		  "Checksum: 0x%04x (incorrect, should be 0x%04x)",
+		  "Checksum: 0x%04x [incorrect, should be 0x%04x]",
 		  cksum, in_cksum_shouldbe(cksum, computed_cksum));
       }
     } else {
@@ -1522,10 +1848,31 @@ dissect_icmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	/* Decode the IP header and first 64 bits of data from the
 	   original datagram. */
 	next_tvb = tvb_new_subset(tvb, 8, -1, -1);
+	
+	/* There is a collision between RFC 1812 and draft-ietf-mpls-icmp-02.
+	We don't know how to decode the 128th and following bytes of the ICMP payload.
+	According to draft-ietf-mpls-icmp-02, these bytes should be decoded as MPLS extensions
+	whereas RFC 1812 tells us to decode them as a portion of the original packet.
+	Let the user decide.
+	
+	Here the user decided to favor MPLS extensions.
+	Force the IP dissector to decode only the first 128 bytes. */
+	if ((tvb_reported_length(tvb) > 8 + 128) &&
+			favor_icmp_mpls_ext && (tvb_get_ntohs(tvb, 8 + 2) > 128))
+		set_actual_length(next_tvb, 128);
+	
 	call_dissector(ip_handle, next_tvb, pinfo, icmp_tree);
 
 	/* Restore the "we're inside an error packet" flag. */
 	pinfo->in_error_pkt = save_in_error_pkt;
+
+	/* Decode MPLS extensions if the payload has at least 128 bytes, and
+		- the original packet in the ICMP payload has less than 128 bytes, or
+		- the user favors the MPLS extensions analysis */
+	if ((tvb_reported_length(tvb) > 8 + 128)
+			&& (tvb_get_ntohs(tvb, 8 + 2) <= 128 || favor_icmp_mpls_ext))
+		dissect_mpls_extensions(tvb, 8 + 128, icmp_tree);
+	
 	break;
 
       case ICMP_ECHOREPLY:
@@ -1644,14 +1991,26 @@ proto_register_ip(void)
 		{ "Destination",	"ip.dst", FT_IPv4, BASE_NONE, NULL, 0x0,
 			"", HFILL }},
 
+		{ &hf_ip_dst_host,
+		{ "Destination Host",		"ip.dst_host", FT_STRING, BASE_NONE, NULL, 0x0,
+			"", HFILL }},
+
 		{ &hf_ip_src,
 		{ "Source",		"ip.src", FT_IPv4, BASE_NONE, NULL, 0x0,
 			"", HFILL }},
 
+		{ &hf_ip_src_host,
+		{ "Source Host",		"ip.src_host", FT_STRING, BASE_NONE, NULL, 0x0,
+			"", HFILL }},
+
 		{ &hf_ip_addr,
 		{ "Source or Destination Address", "ip.addr", FT_IPv4, BASE_NONE, NULL, 0x0,
 			"", HFILL }},
 
+		{ &hf_ip_host,
+		{ "Source or Destination Host", "ip.host", FT_STRING, BASE_NONE, NULL, 0x0,
+			"", HFILL }},
+
 		{ &hf_ip_flags,
 		{ "Flags",		"ip.flags", FT_UINT8, BASE_HEX, NULL, 0x0,
 			"", HFILL }},
@@ -1746,7 +2105,7 @@ proto_register_ip(void)
 	ip_module = prefs_register_protocol(proto_ip, NULL);
 	prefs_register_bool_preference(ip_module, "decode_tos_as_diffserv",
 	    "Decode IPv4 TOS field as DiffServ field",
-	    "Whether the IPv4 type-of-service field should be decoded as a Differentiated Services field",
+	    "Whether the IPv4 type-of-service field should be decoded as a Differentiated Services field (see RFC2474/RFC2475)",
 	    &g_ip_dscp_actif);
 	prefs_register_bool_preference(ip_module, "defragment",
 		"Reassemble fragmented IP datagrams",
@@ -1890,17 +2249,80 @@ proto_register_icmp(void)
     { &hf_icmp_mip_challenge,
       { "Challenge", "icmp.mip.challenge",    FT_BYTES, BASE_NONE, NULL, 0x0,
 	"", HFILL}},
+
+    { &hf_icmp_mpls,
+      { "ICMP Extensions for MPLS",	"icmp.mpls",	FT_NONE, BASE_NONE,	NULL, 0x0,
+	"", HFILL }},
+    
+	{ &hf_icmp_mpls_version,
+		{ "Version",		"icmp.mpls.version", FT_UINT8, BASE_DEC, NULL, 0x0,
+			"", HFILL }},
+            
+    { &hf_icmp_mpls_reserved,
+      { "Reserved",	"icmp.mpls.res",	FT_UINT16, BASE_HEX,	NULL, 0x0,
+      	"", HFILL }},
+
+	{ &hf_icmp_mpls_checksum,
+      { "Checksum",	"icmp.mpls.checksum",	FT_UINT16, BASE_HEX,	NULL, 0x0,
+      	"", HFILL }},
+
+	{ &hf_icmp_mpls_checksum_bad,
+      { "Bad Checksum",	"icmp.mpls.checksum_bad",	FT_BOOLEAN, BASE_NONE,	NULL, 0x0,
+	"", HFILL }},
+
+	{ &hf_icmp_mpls_length,
+      { "Length",	"icmp.mpls.length",	FT_UINT16, BASE_HEX,	NULL, 0x0,
+      	"", HFILL }},
+
+	{ &hf_icmp_mpls_class,
+		{ "Class",	"icmp.mpls.class", FT_UINT8, BASE_DEC, NULL, 0x0,
+			"", HFILL }},
+
+	{ &hf_icmp_mpls_c_type,
+		{ "C-Type",	"icmp.mpls.ctype", FT_UINT8, BASE_DEC, NULL, 0x0,
+			"", HFILL }},
+
+	{ &hf_icmp_mpls_label,
+		{ "Label",	"icmp.mpls.label", FT_UINT24, BASE_DEC, NULL, 0x00fffff0,
+			"", HFILL }},
+
+	{ &hf_icmp_mpls_exp,
+		{ "Experimental",	"icmp.mpls.exp", FT_UINT24, BASE_DEC,
+			NULL, 0x0e,
+			"", HFILL }},
+
+	{ &hf_icmp_mpls_s,
+		{ "Stack bit",	"icmp.mpls.s", FT_BOOLEAN, 24, TFS(&flags_set_truth), 0x01,
+			"", HFILL }},
+
+	{ &hf_icmp_mpls_ttl,
+		{ "Time to live",	"icmp.mpls.ttl", FT_UINT8, BASE_DEC, NULL, 0x0,
+			"", HFILL }}
+
   };
   static gint *ett[] = {
     &ett_icmp,
 	&ett_icmp_mip,
-	&ett_icmp_mip_flags
+	&ett_icmp_mip_flags,
+	/* MPLS extensions */
+	&ett_icmp_mpls,
+	&ett_icmp_mpls_object,
+	&ett_icmp_mpls_stack_object
   };
-
+  
+  module_t *icmp_module;
+  
   proto_icmp = proto_register_protocol("Internet Control Message Protocol",
 				       "ICMP", "icmp");
   proto_register_field_array(proto_icmp, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+  
+  icmp_module = prefs_register_protocol(proto_icmp, NULL);
+  
+  prefs_register_bool_preference(icmp_module, "favor_icmp_mpls",
+	    "Favor ICMP extensions for MPLS",
+	    "Whether the 128th and following bytes of the ICMP payload should be decoded as MPLS extensions or as a portion of the original packet",
+	    &favor_icmp_mpls_ext);
 }
 
 void
