@@ -1,7 +1,7 @@
 /* packet-ipv6.c
  * Routines for IPv6 packet disassembly
  *
- * $Id: packet-ipv6.c 12130 2004-09-29 00:52:45Z guy $
+ * $Id: packet-ipv6.c 15079 2005-07-26 08:01:16Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -37,7 +37,7 @@
 #include "ip_opts.h"
 #include <epan/addr_resolv.h>
 #include <epan/prefs.h>
-#include "reassemble.h"
+#include <epan/reassemble.h>
 #include <epan/ipproto.h>
 #include "etypes.h"
 #include "ppptypes.h"
@@ -210,8 +210,8 @@ dissect_routing6(tvbuff_t *tvb, int offset, proto_tree *tree) {
     struct ip6_rthdr rt;
     guint len;
     proto_tree *rthdr_tree;
-	proto_item *ti;
-    char buf[sizeof(struct ip6_rthdr0) + sizeof(struct e_in6_addr) * 23];
+    proto_item *ti;
+    guint8 buf[sizeof(struct ip6_rthdr0) + sizeof(struct e_in6_addr) * 23];
 
     tvb_memcpy(tvb, (guint8 *)&rt, offset, sizeof(rt));
     len = (rt.ip6r_len + 1) << 3;
@@ -363,7 +363,7 @@ dissect_ipv6_options(tvbuff_t *tvb, int offset, guint length,
   const ip_tcp_opt *optp;
   opt_len_type      len_type;
   unsigned int      optlen;
-  char             *name;
+  const char       *name;
   char              name_str[7+1+1+2+2+1+1];	/* "Unknown (0x%02x)" */
   void            (*dissect)(const struct ip_tcp_opt *, tvbuff_t *,
 				int, guint, packet_info *, proto_tree *);
@@ -450,7 +450,7 @@ dissect_ipv6_options(tvbuff_t *tvb, int offset, guint length,
 }
 
 static int
-dissect_opts(tvbuff_t *tvb, int offset, proto_tree *tree, char *optname)
+dissect_opts(tvbuff_t *tvb, int offset, proto_tree *tree, const char *optname)
 {
     struct ip6_ext ext;
     int len;
@@ -513,7 +513,7 @@ dissect_opts(tvbuff_t *tvb, int offset, proto_tree *tree, char *optname)
 		break;
 	    case IP6OPT_RTALERT:
 	      {
-		char *rta;
+		const char *rta;
 
 		tmp = tvb_get_guint8(tvb, p + 1);
 		if (tmp == 2) {
@@ -792,7 +792,7 @@ again:
            put something in the Info column; leave it there. */
       	if (!ah) {
           if (hopopts || routing || dstopts) {
-            char *sep = "IPv6 ";
+            const char *sep = "IPv6 ";
             if (hopopts) {
               col_append_fstr(pinfo->cinfo, COL_INFO, "%shop-by-hop options",
                              sep);
@@ -953,6 +953,7 @@ proto_reg_handoff_ipv6(void)
   dissector_add("null.type", BSD_AF_INET6_DARWIN, ipv6_handle);
   dissector_add("chdlctype", ETHERTYPE_IPv6, ipv6_handle);
   dissector_add("fr.ietf", NLPID_IP6, ipv6_handle);
+  dissector_add("osinl.excl", NLPID_IP6, ipv6_handle);
   dissector_add("x.25.spi", NLPID_IP6, ipv6_handle);
   dissector_add("arcnet.protocol_id", ARCNET_PROTO_IPv6, ipv6_handle);
 
