@@ -8,7 +8,7 @@
  * (draft-ietf-ipsec-ikev2-17.txt)
  * Shoichi Sakane <sakane@tanu.org>
  *
- * $Id: packet-isakmp.c 13974 2005-03-29 22:23:09Z gerald $
+ * $Id: packet-isakmp.c 14983 2005-07-22 02:07:43Z sahlberg $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -46,19 +46,21 @@
 #include <epan/ipv6-utils.h>
 #include <epan/ipproto.h>
 #include <epan/dissectors/packet-x509if.h>
+#include <epan/dissectors/packet-isakmp.h>
 
 #define isakmp_min(a, b)  ((a<b) ? a : b)
 
 #define ARLEN(a) (sizeof(a)/sizeof(a[0]))
 
 static int proto_isakmp = -1;
+static int hf_ike_certificate_authority = -1;
+static int hf_ike_v2_certificate_authority = -1;
+static int hf_ike_nat_keepalive = -1;
 
 static gint ett_isakmp = -1;
 static gint ett_isakmp_flags = -1;
 static gint ett_isakmp_payload = -1;
 
-static int isakmp_version = 0;
-
 #define UDP_PORT_ISAKMP	500
 #define TCP_PORT_ISAKMP 500
 
@@ -88,65 +90,73 @@ struct isakmp_hdr {
   guint32	length;
 };
 
-static proto_tree *dissect_payload_header(tvbuff_t *, int, int, guint8,
+static proto_tree *dissect_payload_header(tvbuff_t *, int, int, int, guint8,
     guint8 *, guint16 *, proto_tree *);
 
 static void dissect_sa(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_proposal(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_transform(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_transform2(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_key_exch(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_id(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_cert(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
-static void dissect_certreq(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
+static void dissect_certreq_v1(tvbuff_t *, int, int, proto_tree *,
+    packet_info *, int, int);
+static void dissect_certreq_v2(tvbuff_t *, int, int, proto_tree *,
+    packet_info *, int, int);
 static void dissect_hash(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_auth(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_sig(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_nonce(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_notif(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_delete(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_vid(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_config(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_nat_discovery(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_nat_original_address(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_ts(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_enc(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 static void dissect_eap(tvbuff_t *, int, int, proto_tree *,
-    packet_info *, int);
+    packet_info *, int, int);
 
-static const char *payloadtype2str(guint8);
-static const char *exchtype2str(guint8);
+static void
+dissect_payloads(tvbuff_t *tvb, proto_tree *tree, int isakmp_version,
+		 guint8 initial_payload, int offset, int length,
+		 packet_info *pinfo);
+
+
+static const char *payloadtype2str(int, guint8);
+static const char *exchtype2str(int, guint8);
 static const char *doitype2str(guint32);
-static const char *msgtype2str(guint16);
+static const char *msgtype2str(int, guint16);
 static const char *situation2str(guint32);
 static const char *v1_attrval2str(int, guint16, guint32);
 static const char *v2_attrval2str(guint16, guint32);
-static const char *cfgtype2str(guint8);
-static const char *cfgattr2str(guint16);
-static const char *id2str(guint8);
+static const char *cfgtype2str(int, guint8);
+static const char *cfgattr2str(int, guint16);
+static const char *id2str(int, guint8);
 static const char *v2_tstype2str(guint8);
 static const char *v2_auth2str(guint8);
-static const char *certtype2str(guint8);
+static const char *certtype2str(int, guint8);
 
 static gboolean get_num(tvbuff_t *, int, guint16, guint32 *);
 
@@ -157,7 +167,7 @@ static gboolean get_num(tvbuff_t *, int, guint16, guint32 *);
 struct payload_func {
   guint8 type;
   const char *	str;
-  void (*func)(tvbuff_t *, int, int, proto_tree *, packet_info *, int);
+  void (*func)(tvbuff_t *, int, int, proto_tree *, packet_info *, int, int);
 };
 
 static struct payload_func v1_plfunc[] = {
@@ -168,7 +178,7 @@ static struct payload_func v1_plfunc[] = {
   {  4, "Key Exchange",		dissect_key_exch  },
   {  5, "Identification",	dissect_id        },
   {  6, "Certificate",		dissect_cert      },
-  {  7, "Certificate Request",	dissect_certreq   },
+  {  7, "Certificate Request",	dissect_certreq_v1},
   {  8, "Hash",			dissect_hash      },
   {  9, "Signature",		dissect_sig       },
   { 10, "Nonce",		dissect_nonce     },
@@ -190,7 +200,7 @@ static struct payload_func v2_plfunc[] = {
   { 35, "Identification - I",	dissect_id        },
   { 36, "Identification - R",	dissect_id        },
   { 37, "Certificate",		dissect_cert      },
-  { 38, "Certificate Request",	dissect_certreq   },
+  { 38, "Certificate Request",	dissect_certreq_v2},
   { 39, "Authentication",	dissect_auth      },
   { 40, "Nonce",		dissect_nonce     },
   { 41, "Notification",		dissect_notif     },
@@ -203,7 +213,7 @@ static struct payload_func v2_plfunc[] = {
   { 48, "Extensible Authentication",	dissect_eap	  },
 };
 
-static struct payload_func * getpayload_func(guint8);
+static struct payload_func * getpayload_func(guint8, int);
 
 #define VID_LEN 16
 #define VID_MS_LEN 20
@@ -321,11 +331,18 @@ static const guint8 VID_draft_ietf_ipsec_heartbeats_00[VID_LEN_8]= {0x8D, 0xB7,
 */
 static const guint8 VID_HeartBeat_Notify[VID_LEN] = {0x48, 0x65, 0x61, 0x72, 0x74, 0x42, 0x65, 0x61, 0x74, 0x5f, 0x4e, 0x6f, 0x74, 0x69, 0x66, 0x79}; 
 
-static int hf_ike_certificate_authority = -1;
+void
+isakmp_dissect_payloads(tvbuff_t *tvb, proto_tree *tree, int isakmp_version,
+			guint8 initial_payload, int offset, int length,
+			packet_info *pinfo)
+{
+  dissect_payloads(tvb, tree, isakmp_version, initial_payload, offset, length,
+		   pinfo);
+}
 
 static void
-dissect_payloads(tvbuff_t *tvb, proto_tree *tree, guint8 initial_payload,
-		 int offset, int length, packet_info *pinfo)
+dissect_payloads(tvbuff_t *tvb, proto_tree *tree, int isakmp_version,
+		 guint8 initial_payload, int offset, int length, packet_info *pinfo)
 {
   guint8 payload, next_payload;
   guint16		payload_length;
@@ -343,14 +360,15 @@ dissect_payloads(tvbuff_t *tvb, proto_tree *tree, guint8 initial_payload,
 			  tvb_bytes_to_str(tvb, offset, length));
       break;
     }
-    ntree = dissect_payload_header(tvb, offset, length, payload,
-      &next_payload, &payload_length, tree);
+    ntree = dissect_payload_header(tvb, offset, length, isakmp_version,
+      payload, &next_payload, &payload_length, tree);
     if (ntree == NULL)
       break;
     if (payload_length >= 4) {	/* XXX = > 4? */
       tvb_ensure_bytes_exist(tvb, offset + 4, payload_length - 4);
-      if ((f = getpayload_func(payload)) != NULL && f->func != NULL)
-        (*f->func)(tvb, offset + 4, payload_length - 4, ntree, pinfo, -1);
+      if ((f = getpayload_func(payload, isakmp_version)) != NULL && f->func != NULL)
+        (*f->func)(tvb, offset + 4, payload_length - 4, ntree, pinfo,
+                   isakmp_version, -1);
       else {
         proto_tree_add_text(ntree, tvb, offset + 4, payload_length - 4,
                             "Payload");
@@ -374,7 +392,7 @@ dissect_payloads(tvbuff_t *tvb, proto_tree *tree, guint8 initial_payload,
 }
 
 static struct payload_func *
-getpayload_func(guint8 payload)
+getpayload_func(guint8 payload, int isakmp_version)
 {
   struct payload_func *f = 0;
   int i, len;
@@ -401,6 +419,7 @@ dissect_isakmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   struct isakmp_hdr 	hdr;
   proto_item *		ti;
   proto_tree *		isakmp_tree = NULL;
+  int			isakmp_version;
 
   if (check_col(pinfo->cinfo, COL_PROTOCOL))
     col_set_str(pinfo->cinfo, COL_PROTOCOL, "ISAKMP");
@@ -412,12 +431,24 @@ dissect_isakmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     isakmp_tree = proto_item_add_subtree(ti, ett_isakmp);
   }
 
+  /* RFC3948 2.3 NAT Keepalive packet:
+   * 1 byte payload with the value 0xff.
+   */
+  if( (tvb_length(tvb)==1) && (tvb_get_guint8(tvb, offset)==0xff) ){
+    if (check_col(pinfo->cinfo, COL_INFO)){
+      col_add_str(pinfo->cinfo, COL_INFO, "NAT Keepalive");
+    }
+    proto_tree_add_item(isakmp_tree, hf_ike_nat_keepalive, tvb, offset, 1, FALSE);
+    return;
+  }
+
   hdr.length = tvb_get_ntohl(tvb, offset + sizeof(hdr) - sizeof(hdr.length));
   hdr.exch_type = tvb_get_guint8(tvb, sizeof(hdr.icookie) + sizeof(hdr.rcookie) + sizeof(hdr.next_payload) + sizeof(hdr.version));
   hdr.version = tvb_get_guint8(tvb, sizeof(hdr.icookie) + sizeof(hdr.rcookie) + sizeof(hdr.next_payload));
   isakmp_version = hi_nibble(hdr.version);	/* save the version */
   if (check_col(pinfo->cinfo, COL_INFO))
-    col_add_str(pinfo->cinfo, COL_INFO, exchtype2str(hdr.exch_type));
+    col_add_str(pinfo->cinfo, COL_INFO,
+                exchtype2str(isakmp_version, hdr.exch_type));
 
   if (tree) {
     tvb_memcpy(tvb, (guint8 *)&hdr.icookie, offset, sizeof(hdr.icookie));
@@ -433,7 +464,8 @@ dissect_isakmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     hdr.next_payload = tvb_get_guint8(tvb, offset);
     proto_tree_add_text(isakmp_tree, tvb, offset, sizeof(hdr.next_payload),
 			"Next payload: %s (%u)",
-			payloadtype2str(hdr.next_payload), hdr.next_payload);
+			payloadtype2str(isakmp_version, hdr.next_payload),
+			hdr.next_payload);
     offset += sizeof(hdr.next_payload);
 
     proto_tree_add_text(isakmp_tree, tvb, offset, sizeof(hdr.version),
@@ -444,7 +476,8 @@ dissect_isakmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     hdr.exch_type = tvb_get_guint8(tvb, offset);
     proto_tree_add_text(isakmp_tree, tvb, offset, sizeof(hdr.exch_type),
 			"Exchange type: %s (%u)",
-			exchtype2str(hdr.exch_type), hdr.exch_type);
+			exchtype2str(isakmp_version, hdr.exch_type),
+			hdr.exch_type);
     offset += sizeof(hdr.exch_type);
 
     {
@@ -510,13 +543,15 @@ dissect_isakmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			len, plurality(len, "", "s"));
       }
     } else
-      dissect_payloads(tvb, isakmp_tree, hdr.next_payload, offset, len, pinfo);
+      dissect_payloads(tvb, isakmp_tree, isakmp_version, hdr.next_payload,
+		       offset, len, pinfo);
   }
 }
 
 static proto_tree *
-dissect_payload_header(tvbuff_t *tvb, int offset, int length, guint8 payload,
-    guint8 *next_payload_p, guint16 *payload_length_p, proto_tree *tree)
+dissect_payload_header(tvbuff_t *tvb, int offset, int length,
+    int isakmp_version, guint8 payload, guint8 *next_payload_p,
+    guint16 *payload_length_p, proto_tree *tree)
 {
   guint8		next_payload;
   guint16		payload_length;
@@ -532,12 +567,13 @@ dissect_payload_header(tvbuff_t *tvb, int offset, int length, guint8 payload,
   payload_length = tvb_get_ntohs(tvb, offset + 2);
 
   ti = proto_tree_add_text(tree, tvb, offset, payload_length,
-            "%s payload", payloadtype2str(payload));
+            "%s payload", payloadtype2str(isakmp_version, payload));
   ntree = proto_item_add_subtree(ti, ett_isakmp_payload);
 
   proto_tree_add_text(ntree, tvb, offset, 1,
 		      "Next payload: %s (%u)",
-		      payloadtype2str(next_payload), next_payload);
+		      payloadtype2str(isakmp_version, next_payload),
+		      next_payload);
   if (isakmp_version == 2) {
     proto_tree_add_text(ntree, tvb, offset + 1, 1, "%s",
         	decode_boolean_bitfield(tvb_get_guint8(tvb, offset + 1), 0x80,
@@ -552,7 +588,7 @@ dissect_payload_header(tvbuff_t *tvb, int offset, int length, guint8 payload,
 
 static void
 dissect_sa(tvbuff_t *tvb, int offset, int length, proto_tree *tree, 
-    packet_info *pinfo, int unused _U_)
+    packet_info *pinfo, int isakmp_version, int unused _U_)
 {
   guint32		doi;
   guint32		situation;
@@ -586,7 +622,8 @@ dissect_sa(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
       offset += 4;
       length -= 4;
 
-      dissect_payloads(tvb, tree, LOAD_TYPE_PROPOSAL, offset, length, pinfo);
+      dissect_payloads(tvb, tree, isakmp_version, LOAD_TYPE_PROPOSAL, offset,
+		       length, pinfo);
     } else {
       /* Unknown */
       proto_tree_add_text(tree, tvb, offset, length,
@@ -594,13 +631,14 @@ dissect_sa(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 			tvb_bytes_to_str(tvb, offset, length));
     }
   } else if (isakmp_version == 2) {
-    dissect_payloads(tvb, tree, LOAD_TYPE_PROPOSAL, offset, length, pinfo);
+    dissect_payloads(tvb, tree, isakmp_version, LOAD_TYPE_PROPOSAL, offset,
+		     length, pinfo);
   }
 }
 
 static void
 dissect_proposal(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version, int unused _U_)
 {
   guint8		protocol_id;
   guint8		spi_size;
@@ -645,8 +683,8 @@ dissect_proposal(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
   }
 
   while (num_transforms > 0) {
-    ntree = dissect_payload_header(tvb, offset, length, LOAD_TYPE_TRANSFORM,
-      &next_payload, &payload_length, tree);
+    ntree = dissect_payload_header(tvb, offset, length, isakmp_version,
+      LOAD_TYPE_TRANSFORM, &next_payload, &payload_length, tree);
     if (ntree == NULL)
       break;
     if (length < payload_length) {
@@ -657,10 +695,10 @@ dissect_proposal(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
     if (payload_length >= 4) {
       if (isakmp_version == 1)
         dissect_transform(tvb, offset + 4, payload_length - 4, ntree,
-			pinfo, protocol_id);
+			pinfo, isakmp_version, protocol_id);
       else if (isakmp_version == 2)
         dissect_transform2(tvb, offset + 4, payload_length - 4, ntree,
-			pinfo, protocol_id);
+			pinfo, isakmp_version, protocol_id);
     }
     else
       proto_tree_add_text(ntree, tvb, offset + 4, payload_length - 4, "Payload");
@@ -672,7 +710,7 @@ dissect_proposal(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_transform(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int protocol_id)
+    packet_info *pinfo _U_, int isakmp_version _U_, int protocol_id)
 {
   static const value_string vs_v1_attr[] = {
     { 1,	"Encryption-Algorithm" },
@@ -973,7 +1011,7 @@ v2_aft2str(guint16 aft)
 
 static void
 dissect_transform2(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   guint8 transform_type;
   guint16 transform_id;
@@ -1031,7 +1069,7 @@ dissect_transform2(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_key_exch(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version, int unused _U_)
 {
   guint16 dhgroup;
 
@@ -1048,7 +1086,7 @@ dissect_key_exch(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_id(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo, int unused _U_)
+    packet_info *pinfo, int isakmp_version, int unused _U_)
 {
   guint8		id_type;
   guint8		protocol_id;
@@ -1056,7 +1094,8 @@ dissect_id(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
   id_type = tvb_get_guint8(tvb, offset);
   proto_tree_add_text(tree, tvb, offset, 1,
-		      "ID type: %s (%u)", id2str(id_type), id_type);
+		      "ID type: %s (%u)",
+		      id2str(isakmp_version, id_type), id_type);
   offset += 1;
   length -= 1;
 
@@ -1110,14 +1149,14 @@ dissect_id(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_cert(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version, int unused _U_)
 {
   guint8		cert_enc;
 
   cert_enc = tvb_get_guint8(tvb, offset);
   proto_tree_add_text(tree, tvb, offset, 1,
 		      "Certificate encoding: %u - %s",
-		      cert_enc, certtype2str(cert_enc));
+		      cert_enc, certtype2str(isakmp_version, cert_enc));
   offset += 1;
   length -= 1;
 
@@ -1125,38 +1164,59 @@ dissect_cert(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 }
 
 static void
-dissect_certreq(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo, int unused _U_)
+dissect_certreq_v1(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
+    packet_info *pinfo, int isakmp_version, int unused _U_)
 {
   guint8		cert_type;
 
   cert_type = tvb_get_guint8(tvb, offset);
   proto_tree_add_text(tree, tvb, offset, 1,
 		      "Certificate type: %u - %s",
-		      cert_type, certtype2str(cert_type));
+		      cert_type, certtype2str(isakmp_version, cert_type));
   offset += 1;
   length -= 1;
 
   if (length) {
-    if (cert_type == 4)
+    if (cert_type == 4){
       dissect_x509if_Name(FALSE, tvb, offset, pinfo, tree, hf_ike_certificate_authority);
-    else
+    } else {
       proto_tree_add_text(tree, tvb, offset, length, "Certificate Authority");
+    }
   }
   else
     proto_tree_add_text(tree, tvb, offset, length, "Certificate Authority (empty)");
 }
 
+static void
+dissect_certreq_v2(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
+    packet_info *pinfo _U_, int isakmp_version, int unused _U_)
+{
+  guint8		cert_type;
+
+  cert_type = tvb_get_guint8(tvb, offset);
+  proto_tree_add_text(tree, tvb, offset, 1,
+		      "Certificate type: %u - %s",
+		      cert_type, certtype2str(isakmp_version, cert_type));
+  offset += 1;
+  length -= 1;
+
+  /* this is a list of 20 byte SHA-1 hashes */
+  while (length) {
+    proto_tree_add_item(tree, hf_ike_v2_certificate_authority, tvb, offset, 20, FALSE);
+    length-=20;
+  }
+}
+
 static void
 dissect_hash(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   proto_tree_add_text(tree, tvb, offset, length, "Hash Data");
 }
 
 static void
 dissect_auth(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   guint8 auth;
 
@@ -1171,14 +1231,14 @@ dissect_auth(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_sig(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   proto_tree_add_text(tree, tvb, offset, length, "Signature Data");
 }
 
 static void
 dissect_nonce(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   proto_tree_add_text(tree, tvb, offset, length, "Nonce Data");
 }
@@ -1204,7 +1264,7 @@ v2_ipcomptype2str(guint8 type)
 
 static void
 dissect_notif(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version, int unused _U_)
 {
   guint32		doi;
   guint8		protocol_id;
@@ -1236,7 +1296,8 @@ dissect_notif(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
   msgtype = tvb_get_ntohs(tvb, offset);
   proto_tree_add_text(tree, tvb, offset, 2,
-		      "Message type: %s (%u)", msgtype2str(msgtype), msgtype);
+		      "Message type: %s (%u)",
+		      msgtype2str(isakmp_version, msgtype), msgtype);
   offset += 2;
   length -= 2;
 
@@ -1266,7 +1327,7 @@ dissect_notif(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_delete(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   guint32		doi;
   guint8		protocol_id;
@@ -1315,7 +1376,7 @@ dissect_delete(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_vid(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   guint32 CPproduct, CPversion;
   const guint8 * pVID;
@@ -1525,14 +1586,15 @@ dissect_vid(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_config(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version, int unused _U_)
 {
   guint8		type;
 
   if (isakmp_version == 1) {
     type = tvb_get_guint8(tvb, offset);
     proto_tree_add_text(tree, tvb, offset, 1,
-    			"Type %s (%u)", cfgtype2str(type), type);
+    			"Type %s (%u)",
+    			cfgtype2str(isakmp_version, type), type);
     offset += 2;
     length -= 2;
 
@@ -1543,7 +1605,8 @@ dissect_config(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
   } else if (isakmp_version == 2) {
     type = tvb_get_guint8(tvb, offset);
     proto_tree_add_text(tree, tvb, offset, 1,
-    			"CFG Type %s (%u)", cfgtype2str(type), type);
+    			"CFG Type %s (%u)",
+    			cfgtype2str(isakmp_version, type), type);
     offset += 4;
     length -= 4;
   }
@@ -1558,7 +1621,8 @@ dissect_config(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
     if (aft & 0x8000) {
       val = tvb_get_ntohs(tvb, offset + 2);
       proto_tree_add_text(tree, tvb, offset, 4,
-			  "%s (%u)", cfgattr2str(type), val);
+			  "%s (%u)",
+			  cfgattr2str(isakmp_version, type), val);
       offset += 4;
       length -= 4;
     }
@@ -1568,11 +1632,11 @@ dissect_config(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
       if (!get_num(tvb, offset + 4, len, &val)) {
         proto_tree_add_text(tree, tvb, offset, pack_len,
 			    "%s: <too big (%u bytes)>",
-			    cfgattr2str(type), len);
+			    cfgattr2str(isakmp_version, type), len);
       } else {
         proto_tree_add_text(tree, tvb, offset, 4,
-			    "%s (%ue)", cfgattr2str(type),
-			    val);
+			    "%s (%ue)",
+			    cfgattr2str(isakmp_version, type), val);
       }
       offset += pack_len;
       length -= pack_len;
@@ -1582,7 +1646,7 @@ dissect_config(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_nat_discovery(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   proto_tree_add_text(tree, tvb, offset, length,
 		      "Hash of address and port: %s",
@@ -1591,7 +1655,7 @@ dissect_nat_discovery(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_nat_original_address(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version, int unused _U_)
 {
   guint8 id_type;
   guint32 addr_ipv4;
@@ -1599,7 +1663,8 @@ dissect_nat_original_address(tvbuff_t *tvb, int offset, int length, proto_tree *
 
   id_type = tvb_get_guint8(tvb, offset);
   proto_tree_add_text(tree, tvb, offset, 1,
-		      "ID type: %s (%u)", id2str(id_type), id_type);
+		      "ID type: %s (%u)",
+		      id2str(isakmp_version, id_type), id_type);
   offset += 1;
   length -= 1;
 
@@ -1643,7 +1708,7 @@ dissect_nat_original_address(tvbuff_t *tvb, int offset, int length, proto_tree *
 
 static void
 dissect_ts(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   guint8	num, tstype, protocol_id, addrlen;
   guint16	len, port;
@@ -1724,7 +1789,7 @@ dissect_ts(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_enc(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   proto_tree_add_text(tree, tvb, offset, 4, "Initialization Vector: 0x%s",
                       tvb_bytes_to_str(tvb, offset, 4));
@@ -1733,17 +1798,17 @@ dissect_enc(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
 
 static void
 dissect_eap(tvbuff_t *tvb, int offset, int length, proto_tree *tree,
-    packet_info *pinfo _U_, int unused _U_)
+    packet_info *pinfo _U_, int isakmp_version _U_, int unused _U_)
 {
   proto_tree_add_text(tree, tvb, offset, length, "EAP Message");
 }
 
 static const char *
-payloadtype2str(guint8 type)
+payloadtype2str(int isakmp_version, guint8 type)
 {
   struct payload_func *f;
 
-  if ((f = getpayload_func(type)) != NULL)
+  if ((f = getpayload_func(type, isakmp_version)) != NULL)
       return f->str;
 
   if (isakmp_version == 1) {
@@ -1761,7 +1826,7 @@ payloadtype2str(guint8 type)
 }
 
 static const char *
-exchtype2str(guint8 type)
+exchtype2str(int isakmp_version, guint8 type)
 {
   static const value_string vs_v1_exchange[] = {
     { 0,	"NONE" },
@@ -1780,6 +1845,7 @@ exchtype2str(guint8 type)
     { 34,	"IKE_SA_INIT" },
     { 35,	"IKE_AUTH " },
     { 36,	"CREATE_CHILD_SA" },
+    { 37,	"INFORMATIONAL" },
     { 0,	NULL },
   };
 
@@ -1807,7 +1873,7 @@ doitype2str(guint32 type)
 }
 
 static const char *
-msgtype2str(guint16 type)
+msgtype2str(int isakmp_version, guint16 type)
 {
   static const value_string vs_v1_notifmsg[] = {
     { 0,	"<UNKNOWN>" },
@@ -1842,9 +1908,9 @@ msgtype2str(guint16 type)
     { 29,	"UNSUPPORTED-EXCHANGE-TYPE" },
     { 30,	"UNEQUAL-PAYLOAD-LENGTHS" },
     { 8192,	"RESERVED" },
-    { 16384,	"RESPONDER-LIFETIME" },
-    { 24576,	"REPLAY-STATUS" },
-    { 24577,	"DOI-specific codes" },	/* XXX missing number ? */
+    { 16384,	"CONNECTED" },
+    { 24576,	"RESPONDER-LIFETIME" },
+    { 24577,	"REPLAY-STATUS" },
     { 24578,	"INITIAL-CONTACT" },
     { 0,	NULL },
   };
@@ -2161,7 +2227,7 @@ v1_attrval2str(int ike_p1, guint16 att_type, guint32 value)
 }
 
 static const char *
-cfgtype2str(guint8 type)
+cfgtype2str(int isakmp_version, guint8 type)
 {
   static const value_string vs_v1_cfgtype[] = {
     { 0,	"Reserved" },
@@ -2200,7 +2266,7 @@ cfgtype2str(guint8 type)
 }
 
 static const char *
-id2str(guint8 type)
+id2str(int isakmp_version, guint8 type)
 {
   static const value_string vs_v1_ident[] = {
     { 0,	"RESERVED" },
@@ -2279,7 +2345,7 @@ v2_auth2str(guint8 type)
 }
 
 static const char *
-cfgattr2str(guint16 ident)
+cfgattr2str(int isakmp_version, guint16 ident)
 {
   static const value_string vs_v1_cfgattr[] = {
     { 0,	"RESERVED" },
@@ -2349,7 +2415,7 @@ cfgattr2str(guint16 ident)
 }
 
 static const char *
-certtype2str(guint8 type)
+certtype2str(int isakmp_version, guint8 type)
 {
   static const value_string vs_v1_certtype[] = {
     { 0,	"NONE" },
@@ -2426,6 +2492,12 @@ proto_register_isakmp(void)
     { &hf_ike_certificate_authority,
       { "Certificate Authority Distinguished Name", "ike.cert_authority_dn", FT_UINT32, BASE_DEC, NULL, 0x0, "Certificate Authority Distinguished Name", HFILL }
     },
+    { &hf_ike_v2_certificate_authority,
+      { "Certificate Authority", "ike.cert_authority", FT_BYTES, BASE_HEX, NULL, 0x0, "SHA-1 hash of the Certificate Authority", HFILL }
+    },
+    { &hf_ike_nat_keepalive,
+      { "NAT Keepalive", "ike.nat_keepalive", FT_NONE, BASE_HEX, NULL, 0x0, "NAT Keepalive packet", HFILL }
+    },
   };
   static gint *ett[] = {
     &ett_isakmp,
