@@ -10,7 +10,7 @@
  *
  * for information on Modbus/TCP.
  *
- * $Id: packet-mbtcp.c 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-mbtcp.c 14786 2005-06-26 19:56:52Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -212,7 +212,8 @@ dissect_mbtcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	int		offset, group_offset, packet_type;
 	guint		i;
 	gint		packet_len, payload_start, payload_len;
-	char		*func_string = "", pkt_type_str[9] = "";
+	const char	*func_string = "";
+	char		pkt_type_str[9] = "";
 	char		err_str[100] = "";
 	guint32		byte_cnt, group_byte_cnt, group_word_cnt;
 	guint32		packet_num;	/* num to uniquely identify different mbtcp
