@@ -9,7 +9,7 @@
  * Portions Copyright (c) by James Coe 2000-2002
  * Portions Copyright (c) Novell, Inc. 2000-2003
  *
- * $Id: packet-ncp.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-ncp.c 14197 2005-04-27 04:09:15Z gerald $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -49,7 +49,7 @@
 #include "packet-ipx.h"
 #include "packet-tcp.h"
 #include "packet-ncp-int.h"
-#include "reassemble.h"
+#include <epan/reassemble.h>
 #include <epan/conversation.h>
 
 int proto_ncp = -1;
@@ -312,7 +312,7 @@ dissect_ncp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	struct ncp_common_header	header;
 	guint16				nw_connection, ncp_burst_seqno, ncp_ack_seqno;
 	guint16				flags = 0;
-	char				flags_str[1+3+1+3+1+3+1+1];
+	char				flags_str[2+3+1+3+1+3+1+3+1+3+1+1];
 	char				*sep;
 	proto_tree			*flags_tree = NULL;
 	int				hdr_offset = 0;
@@ -355,7 +355,7 @@ dissect_ncp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		 * packets we will be able to determine if we need 
 		 * to also dissect with a signature.
 		 */
-		conversation = find_conversation(&pinfo->src, &pinfo->dst,
+		conversation = find_conversation(pinfo->fd->num, &pinfo->src, &pinfo->dst,
 		    PT_NCP, (guint32) pinfo->srcport, (guint32) pinfo->destport,
 		    0);
 		if ((ncpiph.length & 0x80000000) ||
@@ -382,7 +382,7 @@ dissect_ncp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 					/* It's not part of any conversation
 					 * - create a new one.
 					 */
-					conversation = conversation_new(&pinfo->src,
+					conversation = conversation_new(pinfo->fd->num, &pinfo->src,
 					    &pinfo->dst, PT_NCP,
 					    (guint32) pinfo->srcport,
 					    (guint32) pinfo->destport, 0);
@@ -443,7 +443,7 @@ dissect_ncp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 					/* It's not part of any conversation
 					 * - create a new one.
 					 */
-					conversation = conversation_new(&pinfo->src,
+					conversation = conversation_new(pinfo->fd->num, &pinfo->src,
 					    &pinfo->dst, PT_NCP,
 					    (guint32) pinfo->srcport,
 					    (guint32) pinfo->destport, 0);
