@@ -3,7 +3,7 @@
  * Original Author Mark C. Brown <mbrown@hp.com>
  * Copyright (C) 2004 Hewlett-Packard Development Company, L.P.
  *
- * $Id: packet-pagp.c 14025 2005-04-07 10:04:50Z sahlberg $
+ * $Id: packet-pagp.c 15031 2005-07-24 03:01:41Z sahlberg $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -391,16 +391,14 @@ dissect_pagp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                                                                                 
 		switch (tlv) {
 		   case PAGP_TLV_DEVICE_NAME:
-			ch = tvb_get_string(tvb, offset+4, len-4);
+			ch = ep_tvb_get_string(tvb, offset+4, len-4);
 			proto_tree_add_string(tlv_tree, hf_pagp_tlv_device_name,
 			   tvb, offset+4, len-4, ch);
-			g_free(ch);
 			break;
 		   case PAGP_TLV_PORT_NAME:
-			ch = tvb_get_string(tvb, offset+4, len-4);
+			ch = ep_tvb_get_string(tvb, offset+4, len-4);
 			proto_tree_add_string(tlv_tree, hf_pagp_tlv_port_name,
 			   tvb, offset+4, len-4, ch);
-			g_free(ch);
 			break;
 		   case PAGP_TLV_AGPORT_MAC:
 			p_sys = tvb_get_ptr(tvb, offset+4, 6);
@@ -542,6 +540,16 @@ proto_register_pagp(void)
 	FT_ETHER,	BASE_NONE,	NULL,	0x0,
       	"Source MAC on frames for this aggregate", HFILL }},
 
+    { &hf_pagp_flush_local_device_id,
+      { "Flush Local Device ID",	"pagp.flushlocaldevid",
+	FT_ETHER,	BASE_NONE,	NULL,	0x0,
+      	"Flush local device ID", HFILL }},
+
+    { &hf_pagp_flush_partner_device_id,
+      { "Flush Partner Device ID",	"pagp.flushpartnerdevid",
+	FT_ETHER,	BASE_NONE,	NULL,	0x0,
+      	"Flush remote device ID", HFILL }},
+
     { &hf_pagp_flush_transaction_id,
       { "Transaction ID",		"pagp.transid",
 	FT_UINT32,	BASE_HEX,	NULL,	0x0,
