@@ -2,7 +2,7 @@
  * Routines for PIM disassembly
  * (c) Copyright Jun-ichiro itojun Hagino <itojun@itojun.org>
  *
- * $Id: packet-pim.c 14157 2005-04-20 21:55:14Z guy $
+ * $Id: packet-pim.c 14880 2005-07-08 22:11:13Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -196,12 +196,12 @@ dissect_pimv1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	    if (computed_cksum == 0) {
 		proto_tree_add_uint_format(pim_tree, hf_pim_cksum, tvb,
 			    offset, 2, pim_cksum,
-			    "Checksum: 0x%04x (correct)",
+			    "Checksum: 0x%04x [correct]",
 			    pim_cksum);
 	    } else {
 		proto_tree_add_uint_format(pim_tree, hf_pim_cksum, tvb,
 			    offset, 2, pim_cksum,
-			    "Checksum: 0x%04x (incorrect, should be 0x%04x)",
+			    "Checksum: 0x%04x [incorrect, should be 0x%04x]",
 			    pim_cksum, in_cksum_shouldbe(pim_cksum, computed_cksum));
 	    }
 	} else {
@@ -611,7 +611,7 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
     guint16 pim_cksum, computed_cksum;
     vec_t cksum_vec[4];
     guint32 phdr[2];
-    char *typestr;
+    const char *typestr;
     proto_tree *pim_tree = NULL;
     proto_item *ti;
     proto_tree *pimopt_tree = NULL;
@@ -709,19 +709,19 @@ dissect_pim(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 	    default:
 	    	/* PIM is available for IPv4 and IPv6 right now */
 	    	computed_cksum = 0;	/* squelch GCC complaints */
-		g_assert_not_reached();
+		DISSECTOR_ASSERT_NOT_REACHED();
 		break;
 	    }
 
 	    if (computed_cksum == 0) {
 		proto_tree_add_uint_format(pim_tree, hf_pim_cksum, tvb,
 			offset + 2, 2, pim_cksum,
-			"Checksum: 0x%04x (correct)",
+			"Checksum: 0x%04x [correct]",
 			pim_cksum);
 	    } else {
 		proto_tree_add_uint_format(pim_tree, hf_pim_cksum, tvb,
 			offset + 2, 2, pim_cksum,
-			"Checksum: 0x%04x (incorrect, should be 0x%04x)",
+			"Checksum: 0x%04x [incorrect, should be 0x%04x]",
 			pim_cksum, in_cksum_shouldbe(pim_cksum, computed_cksum));
 	    }
 	} else {
