@@ -2,7 +2,7 @@
 *
 * Routine to dissect ISO 8823 OSI Presentation Protocol packets
 *
-* $Id: packet-pres.c 14307 2005-05-04 19:55:17Z gerald $
+* $Id: packet-pres.c 15043 2005-07-24 19:01:28Z guy $
 *
 * Yuriy Sidelnikov <YSidelnikov@hotmail.com>
 *
@@ -722,6 +722,9 @@ new_item_len+(asn->offset-*offset)+1,
 				{
 				acse	=	get_integer_value(asn,new_item_len,offset);
 				print_value(asn,pres_tree_ms,tvb,offset,new_item_len);
+				if(session){
+					session->pres_ctx_id=acse;
+				}
 				}
 					break;
 			case OCTET_ALIGNED:
@@ -1081,7 +1084,7 @@ static void
 dissect_parse_error(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		    proto_tree *tree, const char *field_name, int ret)
 {
-	char *errstr;
+	const char *errstr;
 	errstr = asn1_err_to_str(ret);
 
 	if (tree != NULL)
