@@ -2,7 +2,7 @@
  * Routines for Q.931 frame disassembly
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-q931.c 13098 2005-01-17 22:26:33Z etxrab $
+ * $Id: packet-q931.c 15031 2005-07-24 03:01:41Z sahlberg $
  *
  * Modified by Andreas Sikkema for possible use with H.323
  *
@@ -33,12 +33,14 @@
 #include <glib.h>
 #include <string.h>
 #include <epan/packet.h>
+#include <epan/tap.h>
 #include <epan/strutil.h>
 #include "nlpid.h"
 #include "packet-q931.h"
 #include "packet-e164.h"
 #include <epan/prefs.h>
-#include "reassemble.h"
+#include <epan/reassemble.h>
+#include <epan/emem.h>
 
 #include "lapd_sapi.h"
 #include "packet-tpkt.h"
@@ -54,6 +56,10 @@
  * http://www.andrews-arnold.co.uk/isdn/q931cause.html
  * http://www.tulatelecom.ru/staff/german/DSSHelp/MessList/InfEl/InfElList.html
  */
+static void reset_q931_packet_info(q931_packet_info *pi);
+static gboolean have_valid_q931_pi=FALSE;
+static q931_packet_info *q931_pi=NULL;
+static int q931_tap = -1;
 
 static int proto_q931 					= -1;
 static int hf_q931_discriminator			= -1;
@@ -129,45 +135,7 @@ static void
 dissect_q931_IEs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *root_tree,
     proto_tree *q931_tree, gboolean is_tpkt, int offset, int initial_codeset);
 
-/*
- * Q.931 message types.
- */
-#define	Q931_ESCAPE		0x00
-#define	Q931_ALERTING		0x01
-#define	Q931_CALL_PROCEEDING	0x02
-#define	Q931_CONNECT		0x07
-#define	Q931_CONNECT_ACK	0x0F
-#define	Q931_PROGRESS		0x03
-#define	Q931_SETUP		0x05
-#define	Q931_SETUP_ACK		0x0D
-#define	Q931_HOLD		0x24
-#define	Q931_HOLD_ACK		0x28
-#define	Q931_HOLD_REJECT	0x30
-#define	Q931_RESUME		0x26
-#define	Q931_RESUME_ACK		0x2E
-#define	Q931_RESUME_REJECT	0x22
-#define	Q931_RETRIEVE		0x31
-#define	Q931_RETRIEVE_ACK	0x33
-#define	Q931_RETRIEVE_REJECT	0x37
-#define	Q931_SUSPEND		0x25
-#define	Q931_SUSPEND_ACK	0x2D
-#define	Q931_SUSPEND_REJECT	0x21
-#define	Q931_USER_INFORMATION	0x20
-#define	Q931_DISCONNECT		0x45
-#define	Q931_RELEASE		0x4D
-#define	Q931_RELEASE_COMPLETE	0x5A
-#define	Q931_RESTART		0x46
-#define	Q931_RESTART_ACK	0x4E
-#define	Q931_CONGESTION_CONTROL	0x79
-#define	Q931_FACILITY		0x62
-#define	Q931_INFORMATION	0x7B
-#define	Q931_NOTIFY		0x6E
-#define	Q931_REGISTER		0x64
-#define	Q931_SEGMENT		0x60
-#define	Q931_STATUS		0x7D
-#define	Q931_STATUS_ENQUIRY	0x75
-
-static const value_string q931_message_type_vals[] = {
+const value_string q931_message_type_vals[] = {
 	{ Q931_ESCAPE,			"ESCAPE" },
 	{ Q931_ALERTING,		"ALERTING" },
 	{ Q931_CALL_PROCEEDING,		"CALL PROCEEDING" },
@@ -202,6 +170,11 @@ static const value_string q931_message_type_vals[] = {
 	{ Q931_SEGMENT,			"SEGMENT" },
 	{ Q931_STATUS,			"STATUS" },
 	{ Q931_STATUS_ENQUIRY,		"STATUS ENQUIRY" },
+	{ Q931_VERSION,			"VERSION" },
+	{ Q931_GROUIP_SERVICE,		"GROUP SERVICE" },
+	{ Q931_GROUIP_SERVICE_ACK,	"GROUP SERVICE ACK" },
+	{ Q931_RESYNC_REQ,		"RESYNC REQ" },
+	{ Q931_RESYNC_RESP,		"RESYNC RESP" },
 	{ 0,				NULL }
 };
 
@@ -289,6 +262,9 @@ static const true_false_string q931_extension_ind_value = {
 #define	Q931_IE_CUG			0x47	/* Closed user group */
 #define	Q931_IE_REVERSE_CHARGE_IND	0x4A	/* Reverse charging indication */
 #define	Q931_IE_CONNECTED_NUMBER_DEFAULT        0x4C	/* Connected Number */
+#define	Q931_IE_INTERFACE_SERVICE	0x66	/* q931+ Interface Service */
+#define	Q931_IE_CHANNEL_STATUS		0x67	/* q931+ Channel Status */
+#define	Q931_IE_VERSION_INFO		0x68	/* q931+ Version Info */
 #define	Q931_IE_CALLING_PARTY_NUMBER	0x6C	/* Calling Party Number */
 #define	Q931_IE_CALLING_PARTY_SUBADDR	0x6D	/* Calling Party Subaddress */
 #define	Q931_IE_CALLED_PARTY_NUMBER	0x70	/* Called Party Number */
@@ -367,6 +343,9 @@ static const value_string q931_info_element_vals0[] = {
 	{ Q931_IE_CUG,				"Closed user group" },
 	{ Q931_IE_REVERSE_CHARGE_IND,		"Reverse charging indication" },
 	{ Q931_IE_CONNECTED_NUMBER_DEFAULT,     "Connected number" },
+	{ Q931_IE_INTERFACE_SERVICE,		"Interface Service" },
+	{ Q931_IE_CHANNEL_STATUS,		"Channel Status" },
+	{ Q931_IE_VERSION_INFO,			"Version Info" },
 	{ Q931_IE_CALLING_PARTY_NUMBER,		"Calling party number" },
 	{ Q931_IE_CALLING_PARTY_SUBADDR,	"Calling party subaddress" },
 	{ Q931_IE_CALLED_PARTY_NUMBER,		"Called party number" },
@@ -1166,10 +1145,9 @@ static const value_string q931_rejection_reason_vals[] = {
 
 void
 dissect_q931_cause_ie(tvbuff_t *tvb, int offset, int len,
-    proto_tree *tree, int hf_cause_value)
+    proto_tree *tree, int hf_cause_value, guint8 *cause_value)
 {
 	guint8 octet;
-	guint8 cause_value;
 	guint8 coding_standard;
 	guint8 rejection_reason;
 
@@ -1210,15 +1188,21 @@ dissect_q931_cause_ie(tvbuff_t *tvb, int offset, int len,
 	if (len == 0)
 		return;
 	octet = tvb_get_guint8(tvb, offset);
-	cause_value = octet & 0x7F;
-	proto_tree_add_uint(tree, hf_cause_value, tvb, offset, 1, cause_value);
+	*cause_value = octet & 0x7F;
+
+	/* add cause value to packet info for use in tap */
+	if(have_valid_q931_pi) {
+		q931_pi->cause_value = *cause_value;
+	}
+
+	proto_tree_add_uint(tree, hf_cause_value, tvb, offset, 1, *cause_value);
 	proto_tree_add_boolean(tree, hf_q931_extension_ind, tvb, offset, 1, octet);
 	offset += 1;
 	len -= 1;
 
 	if (len == 0)
 		return;
-	switch (cause_value) {
+	switch (*cause_value) {
 
 	case Q931_CAUSE_UNALLOC_NUMBER:
 	case Q931_CAUSE_NO_ROUTE_TO_DEST:
@@ -1436,7 +1420,7 @@ dissect_q931_channel_identification_ie(tvbuff_t *tvb, int offset, int len,
 		proto_tree_add_text(tree, tvb, offset, 1,
 		    "Channel selection: %s",
 		    val_to_str(octet & 0x03, q931_basic_channel_selection_vals,
-		      NULL));
+		      "Unknown (0x%02X)"));
 	}
 	offset += 1;
 	len -= 1;
@@ -1903,7 +1887,7 @@ dissect_q931_pl_binary_parameters_ie(tvbuff_t *tvb, int offset, int len,
 	octet = tvb_get_guint8(tvb, offset);
 	proto_tree_add_text(tree, tvb, offset, 1,
 	    "Fast select: %s",
-	    val_to_str(octet & 0x18, q931_fast_selected_vals, NULL));
+	    val_to_str(octet & 0x18, q931_fast_selected_vals, "Unknown (0x%02X)"));
 	proto_tree_add_text(tree, tvb, offset, 1,
 	    "%s",
 	    (octet & 0x04) ? "No request/request denied" :
@@ -2105,13 +2089,17 @@ dissect_q931_number_ie(tvbuff_t *tvb, int offset, int len,
 	if ( number_plan == 1 ) {
 		if ( e164_info.e164_number_type != NONE ){
 
-			e164_info.E164_number_str = tvb_get_string(tvb, offset, len);
+			e164_info.E164_number_str = ep_tvb_get_string(tvb, offset, len);
 			e164_info.E164_number_length = len;
 			dissect_e164_number(tvb, tree, offset, len, e164_info);
-			g_free(e164_info.E164_number_str);
 		}
 	}
 
+    /* Collect q931_packet_info */
+    if ( e164_info.e164_number_type == CALLING_PARTY_NUMBER && have_valid_q931_pi)
+          q931_pi->calling_number = ep_tvb_get_string(tvb, offset, len);
+    if ( e164_info.e164_number_type == CALLED_PARTY_NUMBER && have_valid_q931_pi)
+          q931_pi->called_number = ep_tvb_get_string(tvb, offset, len);
 }
 
 /*
@@ -2145,7 +2133,7 @@ dissect_q931_party_subaddr_ie(tvbuff_t *tvb, int offset, int len,
 	proto_tree_add_text(tree, tvb, offset, 1,
 	    "Odd/even indicator: %s",
 	    val_to_str(octet & 0x10, q931_odd_even_indicator_vals,
-	      NULL));
+	      "Unknown (0x%02X)"));
 	offset += 1;
 	len -= 1;
 
@@ -2352,6 +2340,12 @@ dissect_q931_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	fragment_data *fd_head;
 	tvbuff_t *next_tvb = NULL;
 
+	q931_pi=ep_alloc(sizeof(q931_packet_info));
+
+	/* Init struct for collecting q931_packet_info */
+	reset_q931_packet_info(q931_pi);
+	have_valid_q931_pi=TRUE;
+
 	if (check_col(pinfo->cinfo, COL_PROTOCOL))
 		col_set_str(pinfo->cinfo, COL_PROTOCOL, "Q.931");
 
@@ -2382,10 +2376,18 @@ dissect_q931_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			call_ref[0] &= 0x7F;
 			proto_tree_add_bytes(q931_tree, hf_q931_call_ref,
 			    tvb, offset, call_ref_len, call_ref);
+		} else
+		{       /* info for the tap */
+			call_ref[0] &= 0x7F;
 		}
+		/* XXX - Should crv be something besides a guint32? */
+		g_memmove(&(q931_pi->crv), call_ref, call_ref_len > sizeof(q931_pi->crv) ? sizeof(q931_pi->crv) : call_ref_len );
 		offset += call_ref_len;
 	}
 	message_type = tvb_get_guint8(tvb, offset);
+	if(have_valid_q931_pi) {
+		q931_pi->message_type = message_type;
+	}
 	if (check_col(pinfo->cinfo, COL_INFO)) {
 		col_add_str(pinfo->cinfo, COL_INFO,
 		    val_to_str(message_type, q931_message_type_vals,
@@ -2436,7 +2438,10 @@ dissect_q931_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 				tvb_set_child_real_data_tvbuff(tvb, next_tvb);
 				add_new_data_source(pinfo, next_tvb, "Reassembled Q.931 IEs");
 				/* Show all fragments. */
-				if (tree) show_fragment_seq_tree(fd_head, &q931_frag_items, q931_tree, pinfo, next_tvb);
+                if (tree) {
+                    proto_item *frag_tree_item;
+                    show_fragment_seq_tree(fd_head, &q931_frag_items, q931_tree, pinfo, next_tvb, &frag_tree_item);
+                }
 			} else {  /* only 1 segment */
 				next_tvb = tvb_new_subset(tvb, offset, -1, -1);
 			}
@@ -2468,6 +2473,7 @@ dissect_q931_IEs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *root_tree,
 	proto_item	*ti;
 	proto_tree	*ie_tree = NULL;
 	guint8		info_element;
+	guint8		dummy;
 	guint16		info_element_len;
 	int		codeset, locked_codeset;
 	gboolean	non_locking_shift, first_segment;
@@ -2689,189 +2695,248 @@ dissect_q931_IEs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *root_tree,
 					proto_tree_add_text(q931_tree, tvb, offset + 4, tvb_reported_length_remaining(tvb, offset + 4), "Message segment");
 					info_element_len += tvb_reported_length_remaining(tvb, offset + 4);
 				}
-			} else if (q931_tree != NULL) {
+			} else {
+				/*
+				 * For the calling number, called number,
+				 * and release cause IEs, don't check
+				 * for the tree being null, as
+				 * the dissectors for those IEs also
+				 * supply information for the tap used
+				 * in VoIP calls.
+				 */
 				switch ((codeset << 8) | info_element) {
 
 				case CS0 | Q931_IE_BEARER_CAPABILITY:
 				case CS0 | Q931_IE_LOW_LAYER_COMPAT:
-					dissect_q931_bearer_capability_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_bearer_capability_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_CAUSE:
 					dissect_q931_cause_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree,
-					    hf_q931_cause_value);
+						offset + 2, info_element_len,
+						ie_tree,
+						hf_q931_cause_value, &dummy);
 					break;
 
 				case CS0 | Q931_IE_CALL_STATE:
-					dissect_q931_call_state_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_call_state_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_CHANNEL_IDENTIFICATION:
-					dissect_q931_channel_identification_ie(
-					    tvb, offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_channel_identification_ie(
+							tvb, offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_PROGRESS_INDICATOR:
-					dissect_q931_progress_indicator_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_progress_indicator_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_NETWORK_SPECIFIC_FACIL:
 				case CS0 | Q931_IE_TRANSIT_NETWORK_SEL:
-					dissect_q931_ns_facilities_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_ns_facilities_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_NOTIFICATION_INDICATOR:
-					dissect_q931_notification_indicator_ie(
-					    tvb, offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_notification_indicator_ie(
+							tvb, offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_DISPLAY:
-					dissect_q931_ia5_ie(tvb, offset + 2,
-					    info_element_len, ie_tree,
-					    "Display information");
+					if (q931_tree != NULL) {
+						dissect_q931_ia5_ie(tvb, offset + 2,
+							info_element_len, ie_tree,
+							"Display information");
+					}
 					break;
 
 				case CS0 | Q931_IE_DATE_TIME:
-					dissect_q931_date_time_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_date_time_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_KEYPAD_FACILITY:
-					dissect_q931_ia5_ie(tvb, offset + 2,
-					    info_element_len, ie_tree,
-					    "Keypad facility");
+					if (q931_tree != NULL) {
+						dissect_q931_ia5_ie(tvb, offset + 2,
+							info_element_len, ie_tree,
+							"Keypad facility");
+					}
 					break;
 
 				case CS0 | Q931_IE_SIGNAL:
-					dissect_q931_signal_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_signal_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_INFORMATION_RATE:
-					dissect_q931_information_rate_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_information_rate_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_E2E_TRANSIT_DELAY:
-					dissect_q931_e2e_transit_delay_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_e2e_transit_delay_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_TD_SELECTION_AND_INT:
-					dissect_q931_td_selection_and_int_ie(
-					    tvb, offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_td_selection_and_int_ie(
+							tvb, offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_PL_BINARY_PARAMETERS:
-					dissect_q931_pl_binary_parameters_ie(
-					    tvb, offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_pl_binary_parameters_ie(
+							tvb, offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_PL_WINDOW_SIZE:
-					dissect_q931_pl_window_size_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_pl_window_size_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_PACKET_SIZE:
-					dissect_q931_packet_size_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_packet_size_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_CUG:
-					dissect_q931_cug_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_cug_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_REVERSE_CHARGE_IND:
-					dissect_q931_reverse_charge_ind_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_reverse_charge_ind_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
+				case CS0 | Q931_IE_CONNECTED_NUMBER_DEFAULT:
+					if (q931_tree != NULL) {
+						dissect_q931_number_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree,
+							hf_q931_connected_number, e164_info);
+					}
+					break;
+
+
 				case CS0 | Q931_IE_CALLING_PARTY_NUMBER:
 					e164_info.e164_number_type = CALLING_PARTY_NUMBER;
 					dissect_q931_number_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree,
-					    hf_q931_calling_party_number, e164_info);
-					break;
-
-				case CS0 | Q931_IE_CONNECTED_NUMBER_DEFAULT:
-					dissect_q931_number_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree,
-					    hf_q931_connected_number, e164_info);
+						offset + 2, info_element_len,
+						ie_tree,
+						hf_q931_calling_party_number, e164_info);
 					break;
 
 				case CS0 | Q931_IE_CALLED_PARTY_NUMBER:
 					e164_info.e164_number_type = CALLED_PARTY_NUMBER;
 					dissect_q931_number_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree,
-					    hf_q931_called_party_number, e164_info);
-					break;
-
-				case CS0 | Q931_IE_REDIRECTING_NUMBER:
-					dissect_q931_number_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree,
-					    hf_q931_redirecting_number, e164_info);
+						offset + 2, info_element_len,
+						ie_tree,
+						hf_q931_called_party_number, e164_info);
 					break;
 
 				case CS0 | Q931_IE_CALLING_PARTY_SUBADDR:
 				case CS0 | Q931_IE_CALLED_PARTY_SUBADDR:
-					dissect_q931_party_subaddr_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_party_subaddr_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
+					break;
+
+				case CS0 | Q931_IE_REDIRECTING_NUMBER:
+					if (q931_tree != NULL) {
+						dissect_q931_number_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree,
+							hf_q931_redirecting_number, e164_info);
+					}
 					break;
 
 				case CS0 | Q931_IE_RESTART_INDICATOR:
-					dissect_q931_restart_indicator_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_restart_indicator_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_HIGH_LAYER_COMPAT:
-					dissect_q931_high_layer_compat_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_high_layer_compat_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				case CS0 | Q931_IE_USER_USER:
-					dissect_q931_user_user_ie(tvb,
-					    offset + 2, info_element_len,
-					    ie_tree);
+					if (q931_tree != NULL) {
+						dissect_q931_user_user_ie(tvb,
+							offset + 2, info_element_len,
+							ie_tree);
+					}
 					break;
 
 				default:
-					proto_tree_add_text(ie_tree, tvb,
-					    offset + 2, info_element_len,
-					    "Data: %s",
-					    bytes_to_str(
-					      tvb_get_ptr(tvb, offset + 2,
-					          info_element_len),
-						  info_element_len));
+					if (q931_tree != NULL) {
+						proto_tree_add_text(ie_tree, tvb,
+							offset + 2, info_element_len,
+							"Data: %s",
+							bytes_to_str(
+							  tvb_get_ptr(tvb, offset + 2,
+								  info_element_len),
+							  info_element_len));
+					}
 					break;
 				}
 			}
@@ -2879,6 +2944,10 @@ dissect_q931_IEs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *root_tree,
 		}
 		codeset = locked_codeset;
 	}
+	if(have_valid_q931_pi) {
+		tap_queue_packet(q931_tap, pinfo, q931_pi);
+	}
+	have_valid_q931_pi=FALSE;
 }
 
 /*
@@ -3143,6 +3212,8 @@ proto_register_q931(void)
 	    "Reassemble segmented Q.931 messages",
 	    "Reassemble segmented Q.931 messages (Q.931 - Annex H)",
 	    &q931_reassembly);
+       /* Register for tapping */
+       q931_tap = register_tap("q931");
 }
 
 void
@@ -3166,3 +3237,15 @@ proto_reg_handoff_q931(void)
 	 */
 	heur_dissector_add("tcp", dissect_q931_tpkt, proto_q931);
 }
+
+static void reset_q931_packet_info(q931_packet_info *pi)
+{
+    if(pi == NULL) {
+        return;
+    }
+
+    pi->calling_number = NULL;
+    pi->called_number = NULL;
+    pi->cause_value = 0xFF;
+    pi->crv = -1;
+}
