@@ -7,7 +7,7 @@
  *	http://www.dgs.monash.edu.au/~timf/bottim/
  *	http://www.opt-sci.Arizona.EDU/Pandora/default.asp
  *
- * $Id: packet-quake2.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-quake2.c 15031 2005-07-24 03:01:41Z sahlberg $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -117,10 +117,9 @@ dissect_quake2_ConnectionlessPacket(tvbuff_t *tvb, packet_info *pinfo _U_,
 
         len = tvb_length_remaining(tvb, offset);
         if (cl_tree) {
-                text = tvb_get_string(tvb, offset, len);
+                text = ep_tvb_get_string(tvb, offset, len);
                 proto_tree_add_string(cl_tree, hf_quake2_connectionless_text,
                         tvb, offset, len, text);
-                g_free(text);
         }
         offset += len;
 
