@@ -4,7 +4,7 @@
  * Based on routines from tcpdump patches by
  *   Ken Hornstein <kenh@cmf.nrl.navy.mil>
  *
- * $Id: packet-rx.c 11615 2004-08-06 19:57:49Z guy $
+ * $Id: packet-rx.c 14064 2005-04-13 20:59:39Z gerald $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -39,6 +39,15 @@
 #include "packet-rx.h"
 #include <epan/addr_resolv.h>
 
+/*
+ * See
+ *
+ *	http://web.mit.edu/kolya/afs/rx/rx-spec
+ *
+ * XXX - is the "Epoch" really a UN*X time?  The high-order bit, according
+ * to that spec, is a flag bit.
+ */
+
 #define UDP_PORT_RX_LOW		7000
 #define UDP_PORT_RX_HIGH	7009
 #define UDP_PORT_RX_AFS_BACKUPS	7021
@@ -231,6 +240,7 @@ dissect_rx_response(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree,
 			offset, 4, tl);
 		offset += 4;
 
+		tvb_ensure_bytes_exist(tvb, offset, tl);
 		proto_tree_add_item(tree, hf_rx_ticket, tvb, offset, tl, FALSE);
 		offset += tl;
 	}
