@@ -4,7 +4,7 @@
  * Jason Lango <jal@netapp.com>
  * Liberally copied from packet-http.c, by Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-sdp.c 14180 2005-04-24 18:43:42Z lroland $
+ * $Id: packet-sdp.c 15034 2005-07-24 04:24:30Z sahlberg $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -96,6 +96,8 @@ static int hf_media = -1;
 static int hf_media_title = -1;
 static int hf_unknown = -1;
 static int hf_invalid = -1;
+static int hf_ipbcp_version = -1;
+static int hf_ipbcp_type = -1;
 
 /* hf_owner subfields*/
 static int hf_owner_username = -1;
@@ -362,7 +364,7 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		tokenoffset = 2;
 		if (hf == hf_unknown)
 			tokenoffset = 0;
-		string = tvb_get_string(tvb, offset + tokenoffset,
+		string = ep_tvb_get_string(tvb, offset + tokenoffset,
 		    linelen - tokenoffset);
 		sub_ti = proto_tree_add_string_format(sdp_tree,hf,tvb, offset,
 					       linelen, string,
@@ -370,7 +372,6 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					       proto_registrar_get_name(hf),
 					       format_text(string,
 					         linelen - tokenoffset));
-		g_free(string);
 		call_sdp_subdissector(tvb_new_subset(tvb,offset+tokenoffset,
 						     linelen-tokenoffset,
 						     linelen-tokenoffset),
@@ -815,7 +816,8 @@ static void dissect_sdp_encryption_key(tvbuff_t *tvb, proto_item * ti){
 static void dissect_sdp_session_attribute(tvbuff_t *tvb, proto_item * ti){
   proto_tree *sdp_session_attribute_tree;
   gint offset, next_offset, tokenlen;
-
+  guint8 *field_name;
+  
   offset = 0;
   next_offset = 0;
   tokenlen = 0;
@@ -834,11 +836,44 @@ static void dissect_sdp_session_attribute(tvbuff_t *tvb, proto_item * ti){
 		      hf_session_attribute_field,
 		      tvb, offset, tokenlen, FALSE);
 
+  field_name = ep_tvb_get_string(tvb, offset, tokenlen);
+  
   offset = next_offset + 1;
-  proto_tree_add_item(sdp_session_attribute_tree,
-		      hf_session_attribute_value,
-		      tvb, offset, -1, FALSE);
 
+  if (strcmp(field_name, "ipbcp") == 0) {
+	  
+	  offset = tvb_pbrk_guint8(tvb,offset,-1,"0123456789");
+	  
+	  if (offset == -1)
+		  return;
+	  
+	  next_offset = tvb_find_guint8(tvb,offset,-1,' ');
+	  
+	  if (next_offset == -1)
+		  return;
+	  
+	  tokenlen = next_offset - offset;
+	  
+	  proto_tree_add_item(sdp_session_attribute_tree,hf_ipbcp_version,tvb,offset,tokenlen,FALSE);
+
+	  offset = tvb_pbrk_guint8(tvb,offset,-1,"ABCDEFGHIJKLMNOPQRSTUVWXYZ");
+
+	  if (offset == -1)
+		  return;
+
+	  tokenlen = tvb_find_line_end(tvb,offset,-1, &next_offset, FALSE);
+	  
+	  if (tokenlen == -1) 
+		  return;
+	  
+	  proto_tree_add_item(sdp_session_attribute_tree,hf_ipbcp_type,tvb,offset,tokenlen,FALSE);
+	  
+  } else {
+	  proto_tree_add_item(sdp_session_attribute_tree,
+						  hf_session_attribute_value,
+						  tvb, offset, -1, FALSE);
+
+  }
 }
 
 static void
@@ -929,14 +964,13 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
     
     if (strcmp(transport_info->media_proto[transport_info->media_count],
                "RTP/AVP") == 0) {
-      media_format = tvb_get_string(tvb, offset, tokenlen);
+      media_format = ep_tvb_get_string(tvb, offset, tokenlen);
       proto_tree_add_string(sdp_media_tree, hf_media_format, tvb, offset,
                              tokenlen, val_to_str(atol(media_format), rtp_payload_type_vals, "%u"));
 	  index = transport_info->media[transport_info->media_count].pt_count;
 	  transport_info->media[transport_info->media_count].pt[index] = atol(media_format);
 	  if (index < (SDP_MAX_RTP_PAYLOAD_TYPES-1))
 		  transport_info->media[transport_info->media_count].pt_count++;
-      g_free(media_format);
     } else {
       proto_tree_add_item(sdp_media_tree, hf_media_format, tvb,
 			  offset, tokenlen, FALSE);
@@ -983,7 +1017,7 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, proto_item * ti, transpor
 		      hf_media_attribute_field,
 		      tvb, offset, tokenlen, FALSE);
 
-  field_name = tvb_get_string(tvb, offset, tokenlen);
+  field_name = ep_tvb_get_string(tvb, offset, tokenlen);
 
   offset = next_offset + 1;
   proto_tree_add_item(sdp_media_attribute_tree,
@@ -995,21 +1029,19 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, proto_item * ti, transpor
 	gint *key;
 
 	next_offset = tvb_find_guint8(tvb,offset,-1,' ');
-	g_free(field_name);
 
     if(next_offset == -1)
 		return;
 
     tokenlen = next_offset - offset;
 
-	payload_type = tvb_get_string(tvb, offset, tokenlen);
+    payload_type = ep_tvb_get_string(tvb, offset, tokenlen);
 
     offset = next_offset + 1;
 
     next_offset = tvb_find_guint8(tvb,offset,-1,'/');
 
     if(next_offset == -1){
-		g_free(payload_type);
         return;
     }
 
@@ -1053,8 +1085,7 @@ static void dissect_sdp_media_attribute(tvbuff_t *tvb, proto_item * ti, transpor
 		else
 			g_hash_table_insert(transport_info->media[ transport_info->media_count-1 ].rtp_dyn_payload, key, encoding_name);
 
-    g_free(payload_type);
-  } else g_free(field_name);
+  }
 }
 
 void
@@ -1261,7 +1292,14 @@ proto_register_sdp(void)
       { "Media Attribute Value",
 	"sdp.media_attribute.value",FT_STRING, BASE_NONE, NULL, 0x0,
 	"Media Attribute Value", HFILL }},
-
+    { &hf_ipbcp_version,
+      { "IPBCP Protocol Version",
+	"ipbcp.version",FT_STRING, BASE_NONE, NULL, 0x0,
+	"IPBCP Protocol Version", HFILL }},
+    { &hf_ipbcp_type,
+      { "IPBCP Command Type",
+	"ipbcp.command",FT_STRING, BASE_NONE, NULL, 0x0,
+	"IPBCP Command Type", HFILL }},
   };
   static gint *ett[] = {
     &ett_sdp,
