@@ -1,6 +1,6 @@
 /* packet-sip.h
  *
- * $Id: packet-sip.h 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-sip.h 13225 2005-02-01 12:12:35Z lroland $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -31,6 +31,12 @@ typedef struct _sip_info_value_t
     gchar	*request_method;
     guint	 response_code;
 	guchar	resend;
+    /* added for VoIP calls analysis, see gtk/voip_calls.c*/
+    gchar   *tap_call_id;
+    gchar   *tap_from_addr;
+    gchar   *tap_to_addr;
+    guint32 tap_cseq_number;
+    gchar   *reason_phrase;
 } sip_info_value_t;
 
 extern void dfilter_store_sip_from_addr(tvbuff_t *tvb,proto_tree *tree,guint parameter_offset, 
