@@ -4,8 +4,9 @@
  * Copyright 2002, Tim Potter <tpot@samba.org>
  * Copyright 2002, Richard Sharpe <rsharpe@ns.aus.com>
  * Copyright 2003, Richard Sharpe <rsharpe@richardsharpe.com>
+ * Copyright 2005, Ronnie Sahlberg (krb decryption)
  *
- * $Id: packet-spnego.c 13850 2005-03-21 10:52:57Z sahlberg $
+ * $Id: packet-spnego.c 15043 2005-07-24 19:01:28Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -42,6 +43,7 @@
 
 #include <epan/asn1.h>
 #include "format-oid.h"
+#include "packet-ber.h"
 #include "packet-dcerpc.h"
 #include "packet-gssapi.h"
 #include "packet-kerberos.h"
@@ -65,6 +67,8 @@ static int proto_spnego = -1;
 static int proto_spnego_krb5 = -1;
 
 static int hf_spnego = -1;
+static int hf_spnego_mech = -1;
+static int hf_spnego_this_mech = -1;
 static int hf_spnego_negtokeninit = -1;
 static int hf_spnego_negtokentarg = -1;
 static int hf_spnego_mechtype = -1;
@@ -146,6 +150,38 @@ static const true_false_string tfs_reqflags_integ = {
   "Per-message Integrity NOT Requested"
 };
 
+/*
+ * This takes an OID in binary form, not an OID as a text string, as
+ * an argument.
+ */
+static gssapi_oid_value *
+gssapi_lookup_oid(subid_t *oid, guint oid_len)
+{
+	gchar *oid_key;
+	gchar *p;
+	unsigned int i;
+	int len;
+	gssapi_oid_value *value;
+
+	/*
+	 * Convert the OID to a string, as text strings are used as
+	 * keys in the OID hash table.
+	 */
+	oid_key = g_malloc(oid_len * 22 + 1);
+	p = oid_key;
+	len = sprintf(p, "%lu", (unsigned long)oid[0]);
+	p += len;
+	for (i = 1; i < oid_len;i++) {
+		len = sprintf(p, ".%lu", (unsigned long)oid[i]);
+		p += len;
+	}
+
+	value = gssapi_lookup_oid_str(oid_key);
+	g_free(oid_key);
+	return value;
+}
+
+
 /* Display an ASN1 parse error.  Taken from packet-snmp.c */
 
 static dissector_handle_t data_handle;
@@ -162,7 +198,7 @@ static void
 dissect_parse_error(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		    proto_tree *tree, const char *field_name, int ret)
 {
-	char *errstr;
+	const char *errstr;
 
 	errstr = asn1_err_to_str(ret);
 
@@ -420,13 +456,13 @@ arcfour_mic_key(void *key_data, size_t key_size, int key_type,
 		void *cksum_data, size_t cksum_size,
 		void *key6_data)
 {
-    char k5_data[16];
-    char T[4];
+    guint8 k5_data[16];
+    guint8 T[4];
 
     memset(T, 0, 4);
 
     if (key_type == KEYTYPE_ARCFOUR_56) {
-	char L40[14] = "fortybits";
+	guint8 L40[14] = "fortybits";
 
 	memcpy(L40 + 10, T, sizeof(T));
 	md5_hmac(
@@ -471,20 +507,20 @@ usage2arcfour(int usage)
 }
 
 static int
-arcfour_mic_cksum(char *key_data, int key_length,
+arcfour_mic_cksum(guint8 *key_data, int key_length,
 		  unsigned usage,
 		  u_char sgn_cksum[8],
-		  const char *v1, size_t l1,
+		  const void *v1, size_t l1,
 		  const void *v2, size_t l2,
 		  const void *v3, size_t l3)
 {
-    const char signature[] = "signaturekey";
-    char ksign_c[16];
+    const guint8 signature[] = "signaturekey";
+    guint8 ksign_c[16];
     unsigned char t[4];
     md5_state_t ms;
     unsigned char digest[16];
     int rc4_usage;
-    char cksum[16];
+    guint8 cksum[16];
     
     rc4_usage=usage2arcfour(usage);
     md5_hmac(signature, sizeof(signature), 
@@ -537,16 +573,16 @@ gssapi_verify_pad(unsigned char *wrapped_data, int wrapped_length,
 
 static int
 decrypt_arcfour(packet_info *pinfo,
-	 char *input_message_buffer,
-	 char *output_message_buffer,
-	 char *key_value, int key_size, int key_type)
+	 guint8 *input_message_buffer,
+	 guint8 *output_message_buffer,
+	 guint8 *key_value, int key_size, int key_type)
 {
-    unsigned char Klocaldata[16];
+    guint8 Klocaldata[16];
     int ret;
-    int32_t seq_number;
+    gint32 seq_number;
     size_t datalen;
-    char k6_data[16], SND_SEQ[8], Confounder[8];
-    char cksum_data[8];
+    guint8 k6_data[16], SND_SEQ[8], Confounder[8];
+    guint8 cksum_data[8];
     int cmp;
     int conf_flag;
     size_t padlen = 0;
@@ -982,69 +1018,48 @@ dissect_spnego_krb5_wrap(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree
 
 static int
 dissect_spnego_mechTypes(tvbuff_t *tvb, int offset, packet_info *pinfo,
-			 proto_tree *tree, ASN1_SCK *hnd,
+			 proto_tree *tree,
 			 gssapi_oid_value **next_level_value_p)
 {
 	proto_item *item = NULL;
 	proto_tree *subtree = NULL;
-	gboolean def;
-	guint len1, len, cls, con, tag, nbytes;
-	subid_t *oid;
-	gchar *oid_string;
-	int ret;
 	gboolean saw_mechanism = FALSE;
+	int start_offset, start_oid_offset, end_oid_offset;
+	gint8 class;
+	gboolean pc, ind_field;
+	gint32 tag;
+	guint32 len1;
+	gchar oid[MAX_OID_STR_LEN];
 
+	start_offset=offset;
 	/*
 	 * MechTypeList ::= SEQUENCE OF MechType
 	 */
+	offset = get_ber_identifier(tvb, offset, &class, &pc, &tag);
+	offset = get_ber_length(tree, tvb, offset, &len1, &ind_field);
 
-	ret = asn1_header_decode(hnd, &cls, &con, &tag, &def, &len1);
-
-	if (ret != ASN1_ERR_NOERROR) {
-	  dissect_parse_error(tvb, offset, pinfo, subtree,
-			      "SPNEGO last sequence header", ret);
-	  goto done;
-	}
-
-	if (!(cls == ASN1_UNI && con == ASN1_CON && tag == ASN1_SEQ)) {
+	if (!(class == BER_CLASS_UNI && pc && tag == BER_UNI_TAG_SEQUENCE)) {
 	  proto_tree_add_text(
-			      subtree, tvb, offset, 0,
-			      "Unknown header (cls=%d, con=%d, tag=%d)",
-			      cls, con, tag);
+			      tree, tvb, offset, 0,
+			      "Unknown header (class=%d, pc=%d, tag=%d)",
+			      class, pc, tag);
 	  goto done;
 	}
 
-	offset = hnd->offset;
-
-	item = proto_tree_add_item(tree, hf_spnego_mechtype, tvb, offset, 
-				   len1, FALSE);
+	item = proto_tree_add_item(tree, hf_spnego_mechtype, tvb, 
+				start_offset, len1, FALSE);
 	subtree = proto_item_add_subtree(item, ett_spnego_mechtype);
 
 	/*
-	 * Now, the object IDs ... We should translate them: FIXME
+	 * Now, the object IDs ...
 	 */
-
-	while (len1) {
+	start_oid_offset=offset;
+	end_oid_offset = start_oid_offset+len1;
+	while (offset<end_oid_offset) {
 	  gssapi_oid_value *value;
 
-	  ret = asn1_oid_decode(hnd, &oid, &len, &nbytes);
-
-	  if (ret != ASN1_ERR_NOERROR) {
-	    dissect_parse_error(tvb, offset, pinfo, subtree,
-				"SPNEGO mechTypes token", ret);
-	    goto done;
-	  }
-
-	  oid_string = format_oid(oid, len);
-	  value = gssapi_lookup_oid(oid, len);
-	  if (value)
-	    proto_tree_add_text(subtree, tvb, offset, nbytes, "OID: %s (%s)",
-				oid_string, value->comment);
-	  else
-	    proto_tree_add_text(subtree, tvb, offset, nbytes, "OID: %s",
-				oid_string);
-
-	  g_free(oid_string);
+	  offset=dissect_ber_object_identifier(FALSE, pinfo, subtree, tvb, offset, hf_spnego_mech, oid);
+	  value = gssapi_lookup_oid_str(oid);
 
 	  /*
 	   * Tell our caller the first mechanism we see, so that if
@@ -1062,10 +1077,6 @@ dissect_spnego_mechTypes(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	      *next_level_value_p = value;
 	    saw_mechanism = TRUE;
 	  }
-
-	  offset += nbytes;
-	  len1 -= nbytes;
-
 	}
 
  done:
@@ -1347,9 +1358,10 @@ dissect_spnego_negTokenInit(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 
 	  case SPNEGO_mechTypes:
 
-	    offset = dissect_spnego_mechTypes(tvb, offset, pinfo,
-					      subtree, hnd,
+	    offset = dissect_spnego_mechTypes(tvb, hnd->offset, pinfo,
+					      subtree,
 					      next_level_value_p);
+	    hnd->offset=offset;
 
 	    break;
 
@@ -1804,18 +1816,19 @@ dissect_spnego_wrap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	proto_item *item;
 	proto_tree *subtree;
-	int ret, offset = 0;
 	int return_offset;
-	ASN1_SCK hnd;
-	gboolean def;
-	guint len1, cls, con, tag, nbytes;
-	guint oid_len;
-	subid_t *oid;
-	gchar *oid_string;
 	conversation_t *conversation;
 	gssapi_oid_value *next_level_value;
 	tvbuff_t *token_tvb;
-	int len;
+	int len, offset, start_offset;
+	gint8 class;
+	gboolean pc, ind_field;
+	gint32 tag;
+	guint32 len1;
+	gchar oid[MAX_OID_STR_LEN];
+
+	start_offset=0;
+	offset=start_offset;
 
 	/*
 	 * We need this later, so lets get it now ...
@@ -1855,66 +1868,32 @@ dissect_spnego_wrap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 * with the "optional" "use in non-initial tokens" being chosen.
 	 */
 
-	asn1_open(&hnd, tvb, offset);
-
 	/*
 	 * Get the first header ...
 	 */
+	offset = get_ber_identifier(tvb, offset, &class, &pc, &tag);
+	offset = get_ber_length(tree, tvb, offset, &len1, &ind_field);
 
-	ret = asn1_header_decode(&hnd, &cls, &con, &tag, &def, &len1);
-
-	if (ret != ASN1_ERR_NOERROR) {
-		dissect_parse_error(tvb, offset, pinfo, subtree,
-				    "SPNEGO context header", ret);
-		return_offset = tvb_length(tvb);
-		goto done;
-	}
-
-	if (!(cls == ASN1_APL && con == ASN1_CON && tag == 0)) {
+	if (!(class == BER_CLASS_APP && pc && tag == 0)) {
 		proto_tree_add_text(
-			subtree, tvb, offset, 0,
-			"Unknown header (cls=%d, con=%d, tag=%d)",
-			cls, con, tag);
+			subtree, tvb, start_offset, 0,
+			"Unknown header (class=%d, pc=%d, tag=%d)",
+			class, pc, tag);
 		return_offset = tvb_length(tvb);
 		goto done;
 	}
 
-	offset = hnd.offset;
-
 	/*
 	 * Get the OID, and find the handle, if any
-	 */
-
-	ret = asn1_oid_decode(&hnd, &oid, &oid_len, &nbytes);
-
-	if (ret != ASN1_ERR_NOERROR) {
-		dissect_parse_error(tvb, offset, pinfo, tree,
-				    "SPNEGO wrap token", ret);
-		return_offset = tvb_length(tvb);
-		goto done;
-	}
-
-	oid_string = format_oid(oid, oid_len);
-	next_level_value = gssapi_lookup_oid(oid, oid_len);
-
-	/*
-	 * XXX - what should we do if this doesn't match the value
+ 	 *
+	 * XXX - what should we do if this OID doesn't match the value
 	 * attached to the frame or conversation?  (That would be
 	 * bogus, but that's not impossible - some broken implementation
 	 * might negotiate some security mechanism but put the OID
 	 * for some other security mechanism in GSS_Wrap tokens.)
 	 */
-	if (next_level_value)
-	  proto_tree_add_text(tree, tvb, offset, nbytes, 
-			      "thisMech: %s (%s)",
-			      oid_string, next_level_value->comment);
-	else
-	  proto_tree_add_text(tree, tvb, offset, nbytes, "thisMech: %s",
-			      oid_string);
-
-	g_free(oid_string);
-
-	offset += nbytes;
+	offset=dissect_ber_object_identifier(FALSE, pinfo, subtree, tvb, offset, hf_spnego_this_mech, oid);
+	next_level_value = gssapi_lookup_oid_str(oid);
 
 	/*
 	 * Now dissect the GSS_Wrap token; it's assumed to be in the
@@ -1942,7 +1921,6 @@ dissect_spnego_wrap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	} else
 	  return_offset = tvb_length(tvb);
  done:
-	asn1_close(&hnd, &offset);
 
 	return return_offset;
 }
@@ -1954,6 +1932,12 @@ proto_register_spnego(void)
 		{ &hf_spnego,
 		  { "SPNEGO", "spnego", FT_NONE, BASE_NONE, NULL, 0x0,
 		    "SPNEGO", HFILL }},
+		{ &hf_spnego_mech, {
+		    "Mech", "spnego.mech", FT_STRING, BASE_NONE,
+		    NULL, 0, "This is a SPNEGO Object Identifier", HFILL }},
+		{ &hf_spnego_this_mech, {
+		    "thisMech", "spnego.this_mech", FT_STRING, BASE_NONE,
+		    NULL, 0, "This is a SPNEGO Object Identifier", HFILL }},
 		{ &hf_spnego_negtokeninit,
 		  { "negTokenInit", "spnego.negtokeninit", FT_NONE, BASE_NONE,
 		    NULL, 0x0, "SPNEGO negTokenInit", HFILL}},
