@@ -9,7 +9,7 @@
  *       In particular I have not had an opportunity to see how it
  *       responds to SRVLOC over TCP.
  *
- * $Id: packet-srvloc.c 12974 2005-01-07 10:44:44Z guy $
+ * $Id: packet-srvloc.c 14182 2005-04-25 03:02:50Z gerald $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -49,7 +49,7 @@
 #include <epan/strutil.h>
 #include <epan/prefs.h>
 #include "packet-tcp.h"
-#include "reassemble.h"
+#include <epan/reassemble.h>
 
 static gboolean srvloc_desegment = TRUE;
 static int proto_srvloc = -1;
@@ -381,10 +381,13 @@ static int
 dissect_authblk_v2(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
     guint16 length;
+    nstime_t ts;
     
     proto_tree_add_item(tree, hf_srvloc_authblkv2_bsd, tvb, offset, 2, FALSE);
     proto_tree_add_item(tree, hf_srvloc_authblkv2_len, tvb, offset+2, 2, FALSE);
-    proto_tree_add_item(tree, hf_srvloc_authblkv2_timestamp, tvb, offset+4, 4, FALSE);
+    ts.nsecs = 0;
+    ts.secs = tvb_get_ntohl(tvb, offset + 4);
+    proto_tree_add_time(tree, hf_srvloc_authblkv2_timestamp, tvb, offset+4, 4, &ts);
     length = tvb_get_ntohs(tvb, offset + 8);
     proto_tree_add_uint(tree, hf_srvloc_authblkv2_slpspilen, tvb, offset + 8, 2, length);
     offset += 10;
@@ -427,7 +430,7 @@ static guint8*
 unicode_to_bytes(tvbuff_t *tvb, int offset, int length, gboolean endianness)
 {
   const char	*ascii_text = tvb_get_ptr(tvb, offset, length);
-  guint8	i, j=0;
+  int	i, j=0;
   guint8	c_char, c_char1;
   static guint8 byte_array[255];
 
