@@ -2,7 +2,7 @@
  * Routines for Simple Traversal of UDP Through NAT dissection
  * Copyright 2003, Shiang-Ming Huang <smhuang@pcs.csie.nctu.edu.tw>
  *
- * $Id: packet-stun.c 13063 2005-01-16 04:25:27Z guy $
+ * $Id: packet-stun.c 14786 2005-06-26 19:56:52Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -146,7 +146,7 @@ dissect_stun(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_tree *att_tree;
 	guint16 msg_type;
 	guint16 msg_length;
-	char *msg_type_str;
+	const char *msg_type_str;
 	guint16 att_type;
 	guint16 att_length;
 	guint16 offset;
@@ -267,7 +267,7 @@ dissect_stun(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					proto_tree_add_item(att_tree, stun_att_error_number, tvb, offset+3, 1, FALSE);
 					if (att_length < 5)
 						break;
-					proto_tree_add_item(att_tree, stun_att_error_reason, tvb, offset+8, (att_length-4), FALSE);
+					proto_tree_add_item(att_tree, stun_att_error_reason, tvb, offset+4, (att_length-4), FALSE);
 					break;
 				
 				case UNKNOWN_ATTRIBUTES:
