@@ -3,7 +3,7 @@
  * Copyright 2000-2002, Brian Bruns <camber@ais.org>
  * Copyright 2002, Steve Langasek <vorlon@netexpress.net>
  *
- * $Id: packet-tds.c 12832 2004-12-25 13:49:30Z ulfl $
+ * $Id: packet-tds.c 13366 2005-02-09 23:38:00Z lroland $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -157,7 +157,7 @@
 #include <epan/strutil.h>
 
 #include "packet-frame.h"
-#include "reassemble.h"
+#include <epan/reassemble.h>
 #include <epan/prefs.h>
 
 #define TDS_QUERY_PKT        1
@@ -1930,13 +1930,13 @@ dissect_tds_tcp_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 * OK, it passes the test; assume the rest of this conversation
 	 * is TDS.
 	 */
-	conv = find_conversation(&pinfo->src, &pinfo->dst, pinfo->ptype,
+	conv = find_conversation(pinfo->fd->num, &pinfo->src, &pinfo->dst, pinfo->ptype,
             pinfo->srcport, pinfo->destport, 0);
         if (conv == NULL) {
         	/*
         	 * No conversation exists yet - create one.
         	 */
-		conv = conversation_new(&pinfo->src, &pinfo->dst,
+		conv = conversation_new(pinfo->fd->num, &pinfo->src, &pinfo->dst,
 		    pinfo->ptype, pinfo->srcport, pinfo->destport, 0);
 	}
 	conversation_set_dissector(conv, tds_tcp_handle);
