@@ -1,6 +1,6 @@
 /* packet-tzsp.c
  *
- * $Id: packet-tzsp.c 13790 2005-03-17 05:14:01Z gerald $
+ * $Id: packet-tzsp.c 15043 2005-07-24 19:01:28Z guy $
  *
  * Copyright 2002, Tazmen Technologies Inc
  *
@@ -286,7 +286,8 @@ dissect_tzsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint16 encapsulation = 0;
 	int wtap_encap;
 	dissector_handle_t encap_dissector;
-	char *encap_name, *info;
+	const char *encap_name;
+	const char *info;
 	guint8 type;
 
 	if (check_col(pinfo->cinfo, COL_PROTOCOL))
