@@ -2,7 +2,7 @@
  * Routines for Wellfleet Compression frame disassembly
  * Copyright 2001, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet-wcp.c 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-wcp.c 14608 2005-06-10 18:28:22Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -598,7 +598,7 @@ static tvbuff_t *wcp_uncompress( tvbuff_t *src_tvb, int offset, packet_info *pin
 
         }
         CATCH(BoundsError) {
-		g_assert_not_reached();
+		DISSECTOR_ASSERT_NOT_REACHED();
 		g_free(buf);
 		return NULL;
         }
