@@ -2,7 +2,7 @@
  *
  * Routines to dissect WTP component of WAP traffic.
  *
- * $Id: packet-wtp.c 12625 2004-11-30 16:52:21Z gerald $
+ * $Id: packet-wtp.c 13366 2005-02-09 23:38:00Z lroland $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -41,7 +41,7 @@
 #include <string.h>
 #include <glib.h>
 #include <epan/packet.h>
-#include "reassemble.h"
+#include <epan/reassemble.h>
 #include "packet-wap.h"
 #include "packet-wtp.h"
 #include "packet-wsp.h"
