@@ -1,7 +1,7 @@
 /* packet.c
  * Routines for packet disassembly
  *
- * $Id: packet.c 14265 2005-05-02 14:07:33Z tuexen $
+ * $Id: packet.c 15043 2005-07-24 19:01:28Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -187,7 +187,7 @@ static GMemChunk *data_source_chunk = NULL;
  * the tvbuff for the data source and its name.
  */
 void
-add_new_data_source(packet_info *pinfo, tvbuff_t *tvb, char *name)
+add_new_data_source(packet_info *pinfo, tvbuff_t *tvb, const char *name)
 {
 	data_source *src;
 
@@ -365,6 +365,16 @@ struct dissector_handle {
 	protocol_t	*protocol;
 };
 
+/* This function will return
+ * old style dissector :
+ *   length of the payload or 1 of the payload is empty
+ * new dissector :
+ *   >0  this protocol was successfully dissected and this was this protocol.
+ *   0   this packet did not match this protocol.
+ *
+ * The only time this function will return 0 is if it is a new style dissector
+ * and if the dissector rejected the packet.
+ */ 
 static int
 call_dissector_through_handle(dissector_handle_t handle, tvbuff_t *tvb,
     packet_info *pinfo, proto_tree *tree)
@@ -379,9 +389,9 @@ call_dissector_through_handle(dissector_handle_t handle, tvbuff_t *tvb,
 		    proto_get_protocol_short_name(handle->protocol);
 	}
 
-	if (handle->is_new)
+	if (handle->is_new) {
 		ret = (*handle->dissector.new)(tvb, pinfo, tree);
-	else {
+	} else {
 		(*handle->dissector.old)(tvb, pinfo, tree);
 		ret = tvb_length(tvb);
 		if (ret == 0) {
@@ -606,7 +616,7 @@ struct dtbl_entry {
 struct dissector_table {
 	GHashTable	*hash_table;
 	GSList		*dissector_handles;
-	char		*ui_name;
+	const char	*ui_name;
 	ftenum_t	type;
 	int		base;
 };
@@ -896,7 +906,7 @@ find_string_dtbl_entry(dissector_table_t sub_dissectors, const gchar *pattern)
 
 /* Add an entry to a string dissector table. */
 void
-dissector_add_string(const char *name, gchar *pattern,
+dissector_add_string(const char *name, const gchar *pattern,
     dissector_handle_t handle)
 {
 	dissector_table_t sub_dissectors = find_dissector_table( name);
@@ -927,7 +937,7 @@ dissector_add_string(const char *name, gchar *pattern,
 	dtbl_entry->initial = dtbl_entry->current;
 
 /* do the table insertion */
-    	g_hash_table_insert( sub_dissectors->hash_table, pattern,
+    	g_hash_table_insert( sub_dissectors->hash_table, (gpointer)pattern,
     	    (gpointer)dtbl_entry);
 
 	/*
@@ -1359,7 +1369,7 @@ dissector_all_tables_foreach_table (DATFunc_table func,
 }
 
 dissector_table_t
-register_dissector_table(const char *name, char *ui_name, ftenum_t type,
+register_dissector_table(const char *name, const char *ui_name, ftenum_t type,
     int base)
 {
 	dissector_table_t	sub_dissectors;
@@ -1407,7 +1417,7 @@ register_dissector_table(const char *name, char *ui_name, ftenum_t type,
 	return sub_dissectors;
 }
 
-char *
+const char *
 get_dissector_table_ui_name(const char *name)
 {
 	dissector_table_t sub_dissectors = find_dissector_table( name);
@@ -1573,7 +1583,7 @@ static GHashTable *registered_dissectors = NULL;
 
 /* Get the short name of the protocol for a dissector handle, if it has
    a protocol. */
-char *
+const char *
 dissector_handle_get_short_name(dissector_handle_t handle)
 {
 	if (handle->protocol == NULL) {
@@ -1691,7 +1701,9 @@ new_register_dissector(const char *name, new_dissector_t dissector, int proto)
 	    (gpointer) handle);
 }
 
-/* Call a dissector through a handle. */
+/* Call a dissector through a handle and if this fails call the "data"
+ * dissector.
+ */
 int
 call_dissector(dissector_handle_t handle, tvbuff_t *tvb,
     packet_info *pinfo, proto_tree *tree)
@@ -1712,6 +1724,19 @@ call_dissector(dissector_handle_t handle, tvbuff_t *tvb,
 	return ret;
 }
 
+/* Call a dissector through a handle but if the dissector rejected it
+ * return 0 instead of using the default "data" dissector.
+ */
+int
+call_dissector_only(dissector_handle_t handle, tvbuff_t *tvb,
+    packet_info *pinfo, proto_tree *tree)
+{
+	int ret;
+
+	ret = call_dissector_work(handle, tvb, pinfo, tree);
+	return ret;
+}
+
 /*
  * Dumps the "layer type"/"decode as" associations to stdout, similar
  * to the proto_registrar_dump_*() routines.
@@ -1733,7 +1758,7 @@ dissector_dump_decodes_display(gchar *table_name, ftenum_t selector_type _U_,
 	dtbl_entry_t *dtbl_entry;
 	dissector_handle_t handle;
 	gint proto_id;
-	gchar *decode_as;
+	const gchar *decode_as;
 
 	g_assert(sub_dissectors);
 	switch (sub_dissectors->type) {
