@@ -1,7 +1,7 @@
 /* prefs.c
  * Routines for handling preferences
  *
- * $Id: prefs.c 13889 2005-03-24 03:10:31Z guy $
+ * $Id: prefs.c 15043 2005-07-24 19:01:28Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -77,27 +77,27 @@ static int mgcp_udp_port_count;
 
 e_prefs prefs;
 
-static gchar	*gui_ptree_line_style_text[] =
+static const gchar	*gui_ptree_line_style_text[] =
 	{ "NONE", "SOLID", "DOTTED", "TABBED", NULL };
 
-static gchar	*gui_ptree_expander_style_text[] =
+static const gchar	*gui_ptree_expander_style_text[] =
 	{ "NONE", "SQUARE", "TRIANGLE", "CIRCULAR", NULL };
 
-static gchar	*gui_hex_dump_highlight_style_text[] =
+static const gchar	*gui_hex_dump_highlight_style_text[] =
 	{ "BOLD", "INVERSE", NULL };
 
-static gchar	*gui_console_open_text[] =
+static const gchar	*gui_console_open_text[] =
 	{ "NEVER", "AUTOMATIC", "ALWAYS", NULL };
 
-static gchar	*gui_fileopen_style_text[] =
+static const gchar	*gui_fileopen_style_text[] =
 	{ "LAST_OPENED", "SPECIFIED", NULL };
 
 /* GTK knows of two ways representing "both", vertical and horizontal aligned.
  * as this may not work on other guis, we use only "both" in general here */
-static gchar	*gui_toolbar_style_text[] =
+static const gchar	*gui_toolbar_style_text[] =
 	{ "ICONS", "TEXT", "BOTH", NULL };
 
-static gchar	*gui_layout_content_text[] =
+static const gchar	*gui_layout_content_text[] =
 	{ "NONE", "PLIST", "PDETAILS", "PBYTES", NULL };
 
 /*
@@ -162,7 +162,7 @@ prefs_register_module_or_subtree(module_t *parent, const char *name,
     const char *title, gboolean is_subtree, void (*apply_cb)(void))
 {
 	module_t *module;
-	const guchar *p;
+	const char *p;
 
 	module = g_malloc(sizeof (module_t));
 	module->name = name;
@@ -311,7 +311,7 @@ find_module(const char *name)
 {
 	GList *list_entry;
 
-	list_entry = g_list_find_custom(modules, (gpointer)name, module_match);
+	list_entry = g_list_find_custom(modules, name, module_match);
 	if (list_entry == NULL)
 		return NULL;	/* no such module */
 	return (module_t *) list_entry->data;
@@ -404,7 +404,7 @@ register_preference(module_t *module, const char *name, const char *title,
     const char *description, pref_type_t type)
 {
 	pref_t *preference;
-	const guchar *p;
+	const gchar *p;
 
 	preference = g_malloc(sizeof (pref_t));
 	preference->name = name;
@@ -427,8 +427,8 @@ register_preference(module_t *module, const char *name, const char *title,
 	 * and shouldn't require quoting, shifting, etc.
 	 */
 	for (p = name; *p != '\0'; p++)
-		g_assert(isascii(*p) &&
-		    (islower(*p) || isdigit(*p) || *p == '_' || *p == '.'));
+		g_assert(isascii((guchar)*p) &&
+		    (islower((guchar)*p) || isdigit((guchar)*p) || *p == '_' || *p == '.'));
 
 	/*
 	 * Make sure there's not already a preference with that
@@ -476,7 +476,7 @@ find_preference(module_t *module, const char *name)
 {
 	GList *list_entry;
 
-	list_entry = g_list_find_custom(module->prefs, (gpointer)name,
+	list_entry = g_list_find_custom(module->prefs, name,
 	    preference_match);
 	if (list_entry == NULL)
 		return NULL;	/* no such preference */
@@ -487,7 +487,7 @@ find_preference(module_t *module, const char *name)
  * Returns TRUE if the given protocol has registered preferences
  */
 gboolean
-prefs_is_registered_protocol(char *name)
+prefs_is_registered_protocol(const char *name)
 {
 	module_t *m = find_module(name);
 
@@ -498,7 +498,7 @@ prefs_is_registered_protocol(char *name)
  * Returns the module title of a registered protocol
  */
 const char *
-prefs_get_title_by_name(char *name)
+prefs_get_title_by_name(const char *name)
 {
 	module_t *m = find_module(name);
 
@@ -556,7 +556,7 @@ prefs_register_enum_preference(module_t *module, const char *name,
  */
 void
 prefs_register_string_preference(module_t *module, const char *name,
-    const char *title, const char *description, char **var)
+    const char *title, const char *description, const char **var)
 {
 	pref_t *preference;
 
@@ -867,7 +867,7 @@ find_val_for_string(const char *needle, const enum_val_t *haystack,
  * default value that was passed as the third argument is returned.
  */
 static int
-find_index_from_string_array(char *needle, char **haystack, int default_value)
+find_index_from_string_array(char *needle, const char **haystack, int default_value)
 {
 	int i = 0;
 
@@ -895,8 +895,6 @@ print.file: /a/very/long/path/
  *
  */
 
-#define MAX_VAR_LEN    100
-
 #define DEF_NUM_COLS    6
 
 
@@ -918,10 +916,10 @@ read_prefs(int *gpf_errno_return, int *gpf_read_errno_return,
 {
   int         i;
   int         err;
-  char       *pf_path;
-  FILE       *pf;
-  fmt_data   *cfmt;
-  gchar      *col_fmt[] = {"No.",      "%m", "Time",        "%t",
+  char        *pf_path;
+  FILE        *pf;
+  fmt_data    *cfmt;
+  const gchar *col_fmt[] = {"No.",      "%m", "Time",        "%t",
                            "Source",   "%s", "Destination", "%d",
                            "Protocol", "%p", "Info",        "%i"};
 
@@ -1170,12 +1168,15 @@ int
 read_prefs_file(const char *pf_path, FILE *pf, pref_set_pair_cb pref_set_pair_fct)
 {
   enum { START, IN_VAR, PRE_VAL, IN_VAL, IN_SKIP };
-  gchar     cur_var[MAX_VAR_LEN], cur_val[MAX_VAL_LEN];
   int       got_c, state = START;
+  GString  *cur_val;
+  GString  *cur_var;
   gboolean  got_val = FALSE;
-  gint      var_len = 0, val_len = 0, fline = 1, pline = 1;
+  gint      fline = 1, pline = 1;
   gchar     hint[] = "(saving your preferences once should remove this warning)";
 
+  cur_val = g_string_new("");
+  cur_var = g_string_new("");
 
   while ((got_c = getc(pf)) != EOF) {
     if (got_c == '\n') {
@@ -1183,27 +1184,13 @@ read_prefs_file(const char *pf_path, FILE *pf, pref_set_pair_cb pref_set_pair_fc
       fline++;
       continue;
     }
-    if (var_len >= MAX_VAR_LEN) {
-      g_warning ("%s line %d: Variable too long %s", pf_path, fline, hint);
-      state = IN_SKIP;
-      var_len = 0;
-      continue;
-    }
-    if (val_len >= MAX_VAL_LEN) {
-      g_warning ("%s line %d: Value too long %s", pf_path, fline, hint);
-      state = IN_SKIP;
-      var_len = 0;
-      continue;
-    }
 
     switch (state) {
       case START:
         if (isalnum(got_c)) {
-          if (var_len > 0) {
+          if (cur_var->len > 0) {
             if (got_val) {
-              cur_var[var_len] = '\0';
-              cur_val[val_len] = '\0';
-              switch (pref_set_pair_fct(cur_var, cur_val)) {
+              switch (pref_set_pair_fct(cur_var->str, cur_val->str)) {
 
 	      case PREFS_SET_SYNTAX_ERR:
                 g_warning ("%s line %d: Syntax error %s", pf_path, pline, hint);
@@ -1211,7 +1198,7 @@ read_prefs_file(const char *pf_path, FILE *pf, pref_set_pair_cb pref_set_pair_fc
 
 	      case PREFS_SET_NO_SUCH_PREF:
                 g_warning ("%s line %d: No such preference \"%s\" %s", pf_path,
-				pline, cur_var, hint);
+				pline, cur_var->str, hint);
                 break;
 
 	      case PREFS_SET_OBSOLETE:
@@ -1227,10 +1214,10 @@ read_prefs_file(const char *pf_path, FILE *pf, pref_set_pair_cb pref_set_pair_fc
           }
           state      = IN_VAR;
           got_val    = FALSE;
-          cur_var[0] = got_c;
-          var_len    = 1;
+          g_string_truncate(cur_var, 0);
+          g_string_append_c(cur_var, (gchar) got_c);
           pline = fline;
-        } else if (isspace(got_c) && var_len > 0 && got_val) {
+        } else if (isspace(got_c) && cur_var->len > 0 && got_val) {
           state = PRE_VAL;
         } else if (got_c == '#') {
           state = IN_SKIP;
@@ -1240,38 +1227,33 @@ read_prefs_file(const char *pf_path, FILE *pf, pref_set_pair_cb pref_set_pair_fc
         break;
       case IN_VAR:
         if (got_c != ':') {
-          cur_var[var_len] = got_c;
-          var_len++;
+          g_string_append_c(cur_var, (gchar) got_c);
         } else {
           state   = PRE_VAL;
-          val_len = 0;
+          g_string_truncate(cur_val, 0);
           got_val = TRUE;
         }
         break;
       case PRE_VAL:
         if (!isspace(got_c)) {
           state = IN_VAL;
-          cur_val[val_len] = got_c;
-          val_len++;
+          g_string_append_c(cur_val, (gchar) got_c);
         }
         break;
       case IN_VAL:
         if (got_c != '#')  {
-          cur_val[val_len] = got_c;
-          val_len++;
+          g_string_append_c(cur_val, (gchar) got_c);
         } else {
-          while (isspace((guchar)cur_val[val_len]) && val_len > 0)
-            val_len--;
+          while (isspace((guchar)cur_val->str[cur_val->len]) && cur_val->len > 0)
+            g_string_truncate(cur_val, cur_val->len - 1);
           state = IN_SKIP;
         }
         break;
     }
   }
-  if (var_len > 0) {
+  if (cur_var->len > 0) {
     if (got_val) {
-      cur_var[var_len] = '\0';
-      cur_val[val_len] = '\0';
-      switch (pref_set_pair_fct(cur_var, cur_val)) {
+      switch (pref_set_pair_fct(cur_var->str, cur_val->str)) {
 
       case PREFS_SET_SYNTAX_ERR:
         g_warning ("%s line %d: Syntax error %s", pf_path, pline, hint);
@@ -1279,7 +1261,7 @@ read_prefs_file(const char *pf_path, FILE *pf, pref_set_pair_cb pref_set_pair_fc
 
       case PREFS_SET_NO_SUCH_PREF:
         g_warning ("%s line %d: No such preference \"%s\" %s", pf_path,
-			pline, cur_var, hint);
+			pline, cur_var->str, hint);
         break;
 
       case PREFS_SET_OBSOLETE:
@@ -1292,6 +1274,10 @@ read_prefs_file(const char *pf_path, FILE *pf, pref_set_pair_cb pref_set_pair_fc
       g_warning ("%s line %d: Incomplete preference %s", pf_path, pline, hint);
     }
   }
+
+  g_string_free(cur_val, TRUE);
+  g_string_free(cur_var, TRUE);
+
   if (ferror(pf))
     return errno;
   else
@@ -1307,7 +1293,7 @@ read_prefs_file(const char *pf_path, FILE *pf, pref_set_pair_cb pref_set_pair_fc
 int
 prefs_set_pref(char *prefarg)
 {
-	guchar *p, *colonp;
+	gchar *p, *colonp;
 	int ret;
 
 	/*
@@ -1332,7 +1318,7 @@ prefs_set_pref(char *prefarg)
 	 * as we allow it in the preferences file, we might as well
 	 * allow it here).
 	 */
-	while (isspace(*p))
+	while (isspace((guchar)*p))
 		p++;
 	if (*p == '\0') {
 		/*
@@ -1418,8 +1404,8 @@ prefs_set_pref(char *prefarg)
 #define GREEN_COMPONENT(x) (guint16) (((((x) >>  8) & 0xff) * 65535 / 255))
 #define BLUE_COMPONENT(x)  (guint16) ( (((x)        & 0xff) * 65535 / 255))
 
-static gchar *pr_formats[] = { "text", "postscript" };
-static gchar *pr_dests[]   = { "command", "file" };
+static const gchar *pr_formats[] = { "text", "postscript" };
+static const gchar *pr_dests[]   = { "command", "file" };
 
 typedef struct {
   char    letter;
@@ -1435,7 +1421,7 @@ static name_resolve_opt_t name_resolve_opt[] = {
 
 #define N_NAME_RESOLVE_OPT	(sizeof name_resolve_opt / sizeof name_resolve_opt[0])
 
-static char *
+static const char *
 name_resolve_to_string(guint32 name_resolve)
 {
   static char string[N_NAME_RESOLVE_OPT+1];
@@ -2060,7 +2046,7 @@ set_pref(gchar *pref_name, gchar *value)
     case PREF_STRING:
       if (strcmp(*pref->varp.string, value) != 0) {
         module->prefs_changed = TRUE;
-        g_free(*pref->varp.string);
+        g_free((void *)*pref->varp.string);
         *pref->varp.string = g_strdup(value);
       }
       break;
@@ -2213,6 +2199,8 @@ write_module_prefs(gpointer data, gpointer user_data)
 
 /* Write out "prefs" to the user's preferences file, and return 0.
 
+   If the preferences file path is NULL, write to stdout.
+
    If we got an error, stuff a pointer to the path of the preferences file
    into "*pf_path_return", and return the errno. */
 int
@@ -2229,10 +2217,14 @@ write_prefs(char **pf_path_return)
    *   so that duplication can be avoided with filter.c
    */
 
-  pf_path = get_persconffile_path(PF_NAME, TRUE);
-  if ((pf = fopen(pf_path, "w")) == NULL) {
-    *pf_path_return = pf_path;
-    return errno;
+  if (pf_path_return != NULL) {
+    pf_path = get_persconffile_path(PF_NAME, TRUE);
+    if ((pf = fopen(pf_path, "w")) == NULL) {
+      *pf_path_return = pf_path;
+      return errno;
+    }
+  } else {
+    pf = stdout;
   }
 
   fputs("# Configuration file for Ethereal " VERSION ".\n"
