@@ -1,7 +1,7 @@
 /* bootp_stat.c
  * boop_stat   2003 Jean-Michel FAYARD
  *
- * $Id: bootp_stat.c 12910 2005-01-01 02:57:02Z guy $
+ * $Id: bootp_stat.c 13993 2005-04-01 09:08:27Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -268,7 +268,7 @@ dhcpstat_init(char *optarg)
 
     window_present(sp->win);
 
-    retap_packets(&cfile);
+    cf_retap_packets(&cfile);
 }
 
 static tap_dfilter_dlg dhcp_stat_dlg = {
@@ -281,7 +281,7 @@ static tap_dfilter_dlg dhcp_stat_dlg = {
 void
 register_tap_listener_gtkdhcpstat(void)
 {
-	register_ethereal_tap("bootp,stat", dhcpstat_init);
+	register_tap_listener_cmd_arg("bootp,stat", dhcpstat_init);
 
 	register_tap_menu_item("BOOTP-DHCP", REGISTER_TAP_GROUP_NONE,
 	    gtk_tap_dfilter_dlg_cb, NULL, NULL, &(dhcp_stat_dlg));
