@@ -1,7 +1,7 @@
 /* capture_dlg.c
  * Routines for packet capture windows
  *
- * $Id: capture_dlg.c 14208 2005-04-27 20:52:56Z ulfl $
+ * $Id: capture_dlg.c 14540 2005-06-03 09:55:28Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -568,7 +568,7 @@ capture_prep_cb(GtkWidget *w _U_, gpointer d _U_)
 		  "to capture packets.\n\n"
 		  "In order to capture packets, WinPcap must be installed; see\n"
 		  "\n"
-		  "        http://winpcap.polito.it/\n"
+		  "        http://www.winpcap.org/\n"
 		  "\n"
 		  "or the mirror at\n"
 		  "\n"
