@@ -1,7 +1,7 @@
 /* column_prefs.c
  * Dialog box for column preferences
  *
- * $Id: column_prefs.c,v 1.24 2004/05/27 16:48:36 ulfl Exp $
+ * $Id: column_prefs.c 12131 2004-09-29 02:54:22Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -31,8 +31,8 @@
 #include "globals.h"
 #include "column_prefs.h"
 #include "gtkglobals.h"
-#include "prefs.h"
-#include "column.h"
+#include <epan/prefs.h>
+#include <epan/column.h>
 #include "compat_macros.h"
 #include "ui_util.h"
 
@@ -297,6 +297,12 @@ column_prefs_show() {
   gtk_box_pack_start(GTK_BOX(props_hb), fmt_m, FALSE, FALSE, 0);
   gtk_widget_show(fmt_m);
 
+  lb = gtk_label_new("Unlike all other preferences, you have to \"Save\" "
+      "and restart Ethereal to let column changes take effect!");
+  gtk_misc_set_alignment(GTK_MISC(lb), 0.5, 0.5);
+  gtk_box_pack_start (GTK_BOX (main_vb), lb, FALSE, FALSE, 0);
+  gtk_widget_show(lb);
+
   /* select the first row */
 #if GTK_MAJOR_VERSION < 2
   gtk_clist_select_row(GTK_CLIST(column_l), 0, 0);
