@@ -1,7 +1,7 @@
 /* conversations_fddi.c
  * conversations_fddi   2003 Ronnie Sahlberg
  *
- * $Id: conversations_fddi.c 12913 2005-01-01 12:49:54Z guy $
+ * $Id: conversations_fddi.c 13993 2005-04-01 09:08:27Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -78,7 +78,7 @@ fddi_endpoints_cb(GtkWidget *w _U_, gpointer d _U_)
 void
 register_tap_listener_fddi_conversation(void)
 {
-	register_ethereal_tap("conv,fddi", fddi_conversation_init);
+	register_tap_listener_cmd_arg("conv,fddi", fddi_conversation_init);
 
 	register_tap_menu_item("FDDI", REGISTER_TAP_GROUP_CONVERSATION_LIST,
 	    fddi_endpoints_cb, NULL, NULL, NULL);
