@@ -4,7 +4,7 @@
  * conversations_table   2003 Ronnie Sahlberg
  * Helper routines common to all endpoint conversations tap.
  *
- * $Id: conversations_table.c 13463 2005-02-22 01:55:04Z lego $
+ * $Id: conversations_table.c 14887 2005-07-09 11:26:46Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -114,7 +114,10 @@ ct_get_filter_name(address *addr, int specific_addr_type, int port_type, int nam
 				return "fddi.src";
 			case SAT_TOKENRING:
 				return "tr.src";
+                        default:
+                            ;
 			}
+                        break;
 		case AT_IPv4:
 			return "ip.src";
 		case AT_IPv6:
@@ -123,9 +126,18 @@ ct_get_filter_name(address *addr, int specific_addr_type, int port_type, int nam
 			return "ipx.src";
 		case AT_FC:
 			return "fc.s_id";
+		case AT_URI:
+			switch(specific_addr_type){
+			case SAT_JXTA:
+				return "jxta.message.src";
+                        default:
+                            ;
+			}
+                        break;
 		default:
 			;
 		}
+                break;
 	case FN_DST_ADDRESS:
 		switch(addr->type){
 		case AT_ETHER:
@@ -136,7 +148,10 @@ ct_get_filter_name(address *addr, int specific_addr_type, int port_type, int nam
 				return "fddi.dst";
 			case SAT_TOKENRING:
 				return "tr.dst";
+                        default:
+                            ;
 			}
+                        break;
 		case AT_IPv4:
 			return "ip.dst";
 		case AT_IPv6:
@@ -145,9 +160,18 @@ ct_get_filter_name(address *addr, int specific_addr_type, int port_type, int nam
 			return "ipx.dst";
 		case AT_FC:
 			return "fc.d_id";
+		case AT_URI:
+			switch(specific_addr_type){
+			case SAT_JXTA:
+				return "jxta.message.dst";
+                        default:
+                            ;
+			}
+                        break;
 		default:
 			;
 		}
+                break;
 	case FN_ANY_ADDRESS:
 		switch(addr->type){
 		case AT_ETHER:
@@ -158,7 +182,10 @@ ct_get_filter_name(address *addr, int specific_addr_type, int port_type, int nam
 				return "fddi.addr";
 			case SAT_TOKENRING:
 				return "tr.addr";
+                        default:
+                            break;
 			}
+                        break;
 		case AT_IPv4:
 			return "ip.addr";
 		case AT_IPv6:
@@ -167,15 +194,26 @@ ct_get_filter_name(address *addr, int specific_addr_type, int port_type, int nam
 			return "ipx.addr";
 		case AT_FC:
 			return "fc.id";
+		case AT_URI:
+			switch(specific_addr_type){
+			case SAT_JXTA:
+				return "jxta.message.address";
+                        default:
+                            ;
+			}
+                        break;
 		default:
 			;
 		}
+                break;
 	case FN_SRC_PORT:
 		switch(port_type){
 		case PT_TCP:
 			return "tcp.srcport";
 		case PT_UDP:
 			return "udp.srcport";
+                default:
+                        ;
 		}
 		break;
 	case FN_DST_PORT:
@@ -184,6 +222,8 @@ ct_get_filter_name(address *addr, int specific_addr_type, int port_type, int nam
 			return "tcp.dstport";
 		case PT_UDP:
 			return "udp.dstport";
+                default:
+                        ;
 		}
 		break;
 	case FN_ANY_PORT:
@@ -192,6 +232,8 @@ ct_get_filter_name(address *addr, int specific_addr_type, int port_type, int nam
 			return "tcp.port";
 		case PT_UDP:
 			return "udp.port";
+                default:
+                        ;
 		}
 		break;
 	}
@@ -270,7 +312,7 @@ ct_sort_column(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
 {
 	char *text1 = NULL;
 	char *text2 = NULL;
-	int i1, i2;
+	guint64 i1, i2;
 
 	const GtkCListRow *row1 = ptr1;
 	const GtkCListRow *row2 = ptr2;
@@ -290,9 +332,11 @@ ct_sort_column(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
 	case 7:
 	case 8:
 	case 9:
-		i1=atoi(text1);
-		i2=atoi(text2);
-		return i1-i2;
+		sscanf(text1, "%" PRIu64, &i1);
+		sscanf(text2, "%" PRIu64, &i2);
+        /* XXX - this might cause trouble because of overflow problems */
+        /* XXX - is this correct anyway? Subtracting two unsigned values will still be an unsigned value, which will never become negative */
+		return (gint) (i1-i2);
 	}
 	g_assert_not_reached();
 	
@@ -1035,21 +1079,21 @@ draw_ct_table_data(conversations_table *ct)
 
         j=gtk_clist_find_row_from_data(ct->table, (gpointer)i);
 
-        g_snprintf(str, 16, "%u", ct->conversations[i].tx_frames+ct->conversations[i].rx_frames);
+        g_snprintf(str, 16, "%" PRIu64, ct->conversations[i].tx_frames+ct->conversations[i].rx_frames);
         gtk_clist_set_text(ct->table, j, 4, str);
-        g_snprintf(str, 16, "%u", ct->conversations[i].tx_bytes+ct->conversations[i].rx_bytes);
+        g_snprintf(str, 16, "%" PRIu64, ct->conversations[i].tx_bytes+ct->conversations[i].rx_bytes);
         gtk_clist_set_text(ct->table, j, 5, str);
 
 
-        g_snprintf(str, 16, "%u", ct->conversations[i].tx_frames);
+        g_snprintf(str, 16, "%" PRIu64, ct->conversations[i].tx_frames);
         gtk_clist_set_text(ct->table, j, 6, str);
-        g_snprintf(str, 16, "%u", ct->conversations[i].tx_bytes);
+        g_snprintf(str, 16, "%" PRIu64, ct->conversations[i].tx_bytes);
         gtk_clist_set_text(ct->table, j, 7, str);
 
 
-        g_snprintf(str, 16, "%u", ct->conversations[i].rx_frames);
+        g_snprintf(str, 16, "%" PRIu64, ct->conversations[i].rx_frames);
         gtk_clist_set_text(ct->table, j, 8, str);
-        g_snprintf(str, 16, "%u", ct->conversations[i].rx_bytes);
+        g_snprintf(str, 16, "%" PRIu64, ct->conversations[i].rx_bytes);
         gtk_clist_set_text(ct->table, j, 9, str);
 
     }
@@ -1581,19 +1625,19 @@ add_conversation_table_data(conversations_table *ct, const address *src, const a
         entries[2] = "";
         entries[3] = "";
 
-        g_snprintf(frames, 16, "%u", conversation->tx_frames+conversation->rx_frames);
+        g_snprintf(frames, 16, "%" PRIu64, conversation->tx_frames+conversation->rx_frames);
         entries[4]=frames;
-        g_snprintf(bytes, 16, "%u", conversation->tx_bytes+conversation->rx_bytes);
+        g_snprintf(bytes, 16, "%" PRIu64, conversation->tx_bytes+conversation->rx_bytes);
         entries[5]=bytes;
 
-        g_snprintf(txframes, 16, "%u", conversation->tx_frames);
+        g_snprintf(txframes, 16, "%" PRIu64, conversation->tx_frames);
         entries[6]=txframes;
-        g_snprintf(txbytes, 16, "%u", conversation->tx_bytes);
+        g_snprintf(txbytes, 16, "%" PRIu64, conversation->tx_bytes);
         entries[7]=txbytes;
 
-        g_snprintf(rxframes, 16, "%u", conversation->rx_frames);
+        g_snprintf(rxframes, 16, "%" PRIu64, conversation->rx_frames);
         entries[8]=rxframes;
-        g_snprintf(rxbytes, 16, "%u", conversation->rx_bytes);
+        g_snprintf(rxbytes, 16, "%" PRIu64, conversation->rx_bytes);
         entries[9]=rxbytes;
 
         gtk_clist_insert(ct->table, conversation_idx, entries);
