@@ -1,6 +1,6 @@
 /* decode_as_dcerpc.c
  *
- * $Id: decode_as_dcerpc.c 12842 2004-12-27 13:17:20Z ulfl $
+ * $Id: decode_as_dcerpc.c 13515 2005-02-25 10:30:21Z sahlberg $
  *
  * Routines to modify dcerpc bindings on the fly.
  *
@@ -377,7 +377,7 @@ decode_dcerpc_add_page (packet_info *pinfo)
     binding->port_a = pinfo->srcport;
     binding->port_b = pinfo->destport;
     binding->ctx_id = pinfo->dcectxid;
-    binding->smb_fid = dcerpc_get_transport_salt(pinfo, pinfo->dcetransporttype);
+    binding->smb_fid = dcerpc_get_transport_salt(pinfo);
     binding->ifname = NULL;
     /*binding->uuid = NULL;*/
     binding->ver = 0;
