@@ -2,7 +2,7 @@
  * h225 message counter for ethereal
  * Copyright 2003 Lars Roland
  *
- * $Id: h225_counter.c 13289 2005-02-04 18:44:44Z ulfl $
+ * $Id: h225_counter.c 14098 2005-04-16 10:53:09Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -562,8 +562,8 @@ gtk_h225counter_init(char *optarg)
 void
 register_tap_listener_gtk_h225counter(void)
 {
-	register_ethereal_tap("h225,counter", gtk_h225counter_init);
+	register_tap_listener_cmd_arg("h225,counter", gtk_h225counter_init);
 
-	register_tap_menu_item("H.225...", REGISTER_TAP_GROUP_NONE,
+	register_tap_menu_item("H.225...", REGISTER_TAP_GROUP_TELEPHONY,
 	    gtk_tap_dfilter_dlg_cb, NULL, NULL, &(h225_counter_dlg));
 }
