@@ -2,7 +2,7 @@
  * modified from endpoint_talkers_table.c   2003 Ronnie Sahlberg
  * Helper routines common to all host list taps.
  *
- * $Id: hostlist_table.c 12913 2005-01-01 12:49:54Z guy $
+ * $Id: hostlist_table.c 14887 2005-07-09 11:26:46Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -45,13 +45,14 @@
 #include "image/clist_descend.xpm"
 #include "simple_dialog.h"
 #include "globals.h"
-#include "gtk/find_dlg.h"
+#include "find_dlg.h"
 #include "color.h"
 #include "gtk/color_dlg.h"
 #include "gtkglobals.h"
 #include "main.h"
 #include "ui_util.h"
 #include "dlg_utils.h"
+#include "help_dlg.h"
 
 
 #define GTK_MENU_FUNC(a) ((GtkItemFactoryCallback)(a))
@@ -85,7 +86,7 @@ hostlist_port_to_str(int port_type, guint32 port)
 #define FN_ANY_ADDRESS		0
 #define FN_ANY_PORT		1
 
-/* given an address (to distinguis between ipv4 and ipv6 for tcp/udp
+/* given an address (to distinguish between ipv4 and ipv6 for tcp/udp
    a port_type and a name_type (FN_...)
    return a string for the filter name
 
@@ -107,7 +108,10 @@ hostlist_get_filter_name(address *addr, int specific_addr_type, int port_type, i
 				return "fddi.addr";
 			case SAT_TOKENRING:
 				return "tr.addr";
+                        default :
+                                ;
 			}
+                        break;
 		case AT_IPv4:
 			return "ip.addr";
 		case AT_IPv6:
@@ -116,6 +120,14 @@ hostlist_get_filter_name(address *addr, int specific_addr_type, int port_type, i
 			return "ipx.addr";
 		case AT_FC:
 			return "fc.id";
+		case AT_URI:
+			switch(specific_addr_type){
+			case SAT_JXTA:
+				return "jxta.message.address";
+                        default:
+                            ;
+			}
+                        break;
 		default:
 			;
 		}
@@ -199,7 +211,7 @@ hostlist_sort_column(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
 {
 	char *text1 = NULL;
 	char *text2 = NULL;
-	int i1, i2;
+	guint64 i1, i2;
 
 	const GtkCListRow *row1 = ptr1;
 	const GtkCListRow *row2 = ptr2;
@@ -217,9 +229,11 @@ hostlist_sort_column(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
 	case 5:
 	case 6:
 	case 7:
-		i1=atoi(text1);
-		i2=atoi(text2);
-		return i1-i2;
+		sscanf(text1, "%" PRIu64, &i1);
+		sscanf(text2, "%" PRIu64, &i2);
+        /* XXX - this might cause trouble because of overflow problems */
+        /* XXX - is this correct anyway? Subtracting two unsigned values will still be an unsigned value, which will never become negative */
+		return (gint) (i1-i2);
 	}
 	g_assert_not_reached();
 	
@@ -471,14 +485,12 @@ draw_hostlist_table_address(hostlist_table *hl, int hostlist_idx)
 
     rownum=gtk_clist_find_row_from_data(hl->table, (gpointer)hostlist_idx);
 
-    if(!hl->resolve_names)
+    if (!hl->resolve_names)
         entry=address_to_str(&hl->hosts[hostlist_idx].address);
-    else {
+    else
         entry=get_addr_name(&hl->hosts[hostlist_idx].address);
-        if(!entry)
-            entry=address_to_str(&hl->hosts[hostlist_idx].address);
-    }
-    gtk_clist_set_text(hl->table, rownum, 0, entry);
+
+		gtk_clist_set_text(hl->table, rownum, 0, entry);
 
     pt = hl->hosts[hostlist_idx].port_type;
     if(!hl->resolve_names) pt = PT_NONE;
@@ -530,21 +542,21 @@ draw_hostlist_table_data(hostlist_table *hl)
 
         j=gtk_clist_find_row_from_data(hl->table, (gpointer)i);
 
-        g_snprintf(str, 16, "%u", hl->hosts[i].tx_frames+hl->hosts[i].rx_frames);
+        g_snprintf(str, 16, "%" PRIu64, hl->hosts[i].tx_frames+hl->hosts[i].rx_frames);
         gtk_clist_set_text(hl->table, j, 2, str);
-        g_snprintf(str, 16, "%u", hl->hosts[i].tx_bytes+hl->hosts[i].rx_bytes);
+        g_snprintf(str, 16, "%" PRIu64, hl->hosts[i].tx_bytes+hl->hosts[i].rx_bytes);
         gtk_clist_set_text(hl->table, j, 3, str);
 
 
-        g_snprintf(str, 16, "%u", hl->hosts[i].tx_frames);
+        g_snprintf(str, 16, "%" PRIu64, hl->hosts[i].tx_frames);
         gtk_clist_set_text(hl->table, j, 4, str);
-        g_snprintf(str, 16, "%u", hl->hosts[i].tx_bytes);
+        g_snprintf(str, 16, "%" PRIu64, hl->hosts[i].tx_bytes);
         gtk_clist_set_text(hl->table, j, 5, str);
 
 
-        g_snprintf(str, 16, "%u", hl->hosts[i].rx_frames);
+        g_snprintf(str, 16, "%" PRIu64, hl->hosts[i].rx_frames);
         gtk_clist_set_text(hl->table, j, 6, str);
-        g_snprintf(str, 16, "%u", hl->hosts[i].rx_bytes);
+        g_snprintf(str, 16, "%" PRIu64, hl->hosts[i].rx_bytes);
         gtk_clist_set_text(hl->table, j, 7, str);
 
     }
@@ -723,7 +735,7 @@ init_hostlist_table(gboolean hide_ports, char *table_name, char *tap_name, char
     char title[256];
     GtkWidget *vbox;
     GtkWidget *bbox;
-    GtkWidget *close_bt;
+    GtkWidget *close_bt, *help_bt;
     gboolean ret;
 
 
@@ -746,19 +758,28 @@ init_hostlist_table(gboolean hide_ports, char *table_name, char *tap_name, char
     }
 
     /* Button row. */
-    bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
+    if(topic_available(HELP_STATS_ENDPOINTS_DIALOG)) {
+        bbox = dlg_button_row_new(GTK_STOCK_CLOSE, GTK_STOCK_HELP, NULL);
+    } else {
+        bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
+    }
     gtk_box_pack_end(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
 
     close_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_CLOSE);
     window_set_cancel_button(hosttable->win, close_bt, window_cancel_button_cb);
 
+    if(topic_available(HELP_STATS_ENDPOINTS_DIALOG)) {
+        help_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_HELP);
+        SIGNAL_CONNECT(help_bt, "clicked", topic_cb, HELP_STATS_ENDPOINTS_DIALOG);
+    }
+
     SIGNAL_CONNECT(hosttable->win, "delete_event", window_delete_event_cb, NULL);
     SIGNAL_CONNECT(hosttable->win, "destroy", hostlist_win_destroy_cb, hosttable);
 
     gtk_widget_show_all(hosttable->win);
     window_present(hosttable->win);
 
-    retap_packets(&cfile);
+    cf_retap_packets(&cfile);
 	
     /* Keep clist frozen to cause modifications to the clist (inserts, appends, others that are extremely slow
 	   in GTK2) to not be drawn, allow refreshes to occur at strategic points for performance */
@@ -869,7 +890,7 @@ init_hostlist_notebook_cb(GtkWidget *w _U_, gpointer d _U_)
     GtkWidget *vbox;
     GtkWidget *hbox;
     GtkWidget *bbox;
-    GtkWidget *close_bt;
+    GtkWidget *close_bt, *help_bt;
     GtkWidget *win;
     GtkWidget *resolv_cb;
     int page;
@@ -925,19 +946,28 @@ init_hostlist_notebook_cb(GtkWidget *w _U_, gpointer d _U_)
     SIGNAL_CONNECT(resolv_cb, "toggled", hostlist_resolve_toggle_dest, pages);
 
     /* Button row. */
-    bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
+    if(topic_available(HELP_STATS_ENDPOINTS_DIALOG)) {
+        bbox = dlg_button_row_new(GTK_STOCK_CLOSE, GTK_STOCK_HELP, NULL);
+    } else {
+        bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
+    }
     gtk_box_pack_end(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
 
     close_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_CLOSE);
     window_set_cancel_button(win, close_bt, window_cancel_button_cb);
 
+    if(topic_available(HELP_STATS_ENDPOINTS_DIALOG)) {
+        help_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_HELP);
+        SIGNAL_CONNECT(help_bt, "clicked", topic_cb, HELP_STATS_ENDPOINTS_DIALOG);
+    }
+
     SIGNAL_CONNECT(win, "delete_event", window_delete_event_cb, NULL);
     SIGNAL_CONNECT(win, "destroy", hostlist_win_destroy_notebook_cb, pages);
 
     gtk_widget_show_all(win);
     window_present(win);
 
-    retap_packets(&cfile);
+    cf_retap_packets(&cfile);
 
     /* after retapping, redraw table */
     for (page=1; page<=GPOINTER_TO_INT(pages[0]); page++) {
@@ -1018,19 +1048,19 @@ add_hostlist_table_data(hostlist_table *hl, const address *addr, guint32 port, g
         entries[0]="";
         entries[1]="";
 
-        g_snprintf(frames, 16, "%u", talker->tx_frames+talker->rx_frames);
+        g_snprintf(frames, 16, "%" PRIu64, talker->tx_frames+talker->rx_frames);
         entries[2]=frames;
-        g_snprintf(bytes, 16, "%u", talker->tx_bytes+talker->rx_bytes);
+        g_snprintf(bytes, 16, "%" PRIu64, talker->tx_bytes+talker->rx_bytes);
         entries[3]=bytes;
 
-        g_snprintf(txframes, 16, "%u", talker->tx_frames);
+        g_snprintf(txframes, 16, "%" PRIu64, talker->tx_frames);
         entries[4]=txframes;
-        g_snprintf(txbytes, 16, "%u", talker->tx_bytes);
+        g_snprintf(txbytes, 16, "%" PRIu64, talker->tx_bytes);
         entries[5]=txbytes;
 
-        g_snprintf(rxframes, 16, "%u", talker->rx_frames);
+        g_snprintf(rxframes, 16, "%" PRIu64, talker->rx_frames);
         entries[6]=rxframes;
-        g_snprintf(rxbytes, 16, "%u", talker->rx_bytes);
+        g_snprintf(rxbytes, 16, "%" PRIu64, talker->rx_bytes);
         entries[7]=rxbytes;
 
         gtk_clist_insert(hl->table, talker_idx, entries);
