@@ -1,7 +1,7 @@
 /* hostlist_udpip.c   2004 Ian Schorr
  * modified from endpoint_talkers_udpip.c   2003 Ronnie Sahlberg
  *
- * $Id: hostlist_udpip.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: hostlist_udpip.c 13993 2005-04-01 09:08:27Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -41,10 +41,10 @@
 
 
 static int
-udpip_hostlist_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+udpip_hostlist_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, const void *vip)
 {
 	hostlist_table *hosts=(hostlist_table *)pit;
-	e_udphdr *udphdr=vip;
+	const e_udphdr *udphdr=vip;
 
 	/* Take two "add" passes per packet, adding for each direction, ensures that all
 	packets are counted properly (even if address is sending to itself) 
@@ -68,7 +68,7 @@ gtk_udpip_hostlist_init(char *optarg)
 		filter=NULL;
 	}
 
-	init_hostlist_table(FALSE, "UDP Endpoints", "udp", filter, (void *)udpip_hostlist_packet);
+	init_hostlist_table(FALSE, "UDP Endpoints", "udp", filter, udpip_hostlist_packet);
 
 }
 
@@ -83,11 +83,10 @@ gtk_udpip_hostlist_cb(GtkWidget *w _U_, gpointer d _U_)
 void
 register_tap_listener_udpip_hostlist(void)
 {
-	register_ethereal_tap("endpoints,udp", gtk_udpip_hostlist_init);
+	register_tap_listener_cmd_arg("endpoints,udp", gtk_udpip_hostlist_init);
 
 	register_tap_menu_item("UDP (IPv4 & IPv6)", REGISTER_TAP_GROUP_ENDPOINT_LIST,
 	    gtk_udpip_hostlist_cb, NULL, NULL, NULL);
 
-	register_hostlist_table(FALSE, "UDP", "udp", NULL /*filter*/, (void *)udpip_hostlist_packet);
+	register_hostlist_table(FALSE, "UDP", "udp", NULL /*filter*/, udpip_hostlist_packet);
 }
-
