@@ -1,7 +1,7 @@
 /* main.h
  * Global defines, etc.
  *
- * $Id: main.h 13724 2005-03-11 20:56:31Z ulfl $
+ * $Id: main.h 15056 2005-07-25 18:02:32Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -271,14 +271,14 @@ extern gboolean main_filter_packets(capture_file *cf, const gchar *dftext,
 
 /** Init the drag-n-drop functionality.
  *
- * @param the target widget for this dnd operations
+ * @param w the target widget for this dnd operations
  */
 extern void dnd_init(GtkWidget *w);
 
 /** Open a new file coming from drag and drop.
  * @param selection_data the selection data reported from GTK
  */
-extern void dnd_open_file_cmd(GtkSelectionData *selection_data);
+extern void dnd_open_file_cmd(gchar *cf_names_freeme);
 
 /** Update the packets statusbar to the current values. */
 extern void packets_bar_update(void);
