@@ -1,7 +1,7 @@
 /* packet_list.c
  * packet list related functions   2002 Olivier Abad
  *
- * $Id: packet_list.c 14082 2005-04-14 20:54:01Z ulfl $
+ * $Id: packet_list.c 14826 2005-06-30 22:46:19Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -497,6 +497,14 @@ packet_list_new(e_prefs *prefs)
 
     /* Packet list */
     pkt_scrollw = scrolled_window_new(NULL, NULL);
+    /* The usual policy for scrolled windows is to set both scrollbars to automatic,
+     * meaning they'll only appear if the content doesn't fit into the window.
+     *
+     * As this doesn't seem to work in some cases for the vertical scrollbar
+     * (see http://bugs.ethereal.com/bugzilla/show_bug.cgi?id=220),
+     * we show that scrollbar always. */
+    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(pkt_scrollw),
+                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
 #if GTK_MAJOR_VERSION >= 2
     /* the eth_clist will have it's own GTK_SHADOW_IN, so don't use a shadow 
      * for both widgets */
@@ -519,8 +527,11 @@ packet_list_new(e_prefs *prefs)
         eth_clist_set_column_auto_resize(ETH_CLIST(packet_list), i, FALSE);
         eth_clist_set_column_resizeable(ETH_CLIST(packet_list), i, TRUE);
 
-        /* Right-justify the packet number column. */
-        if (cfile.cinfo.col_fmt[i] == COL_NUMBER)
+        /* Right-justify some special columns. */
+        if (cfile.cinfo.col_fmt[i] == COL_NUMBER ||
+            cfile.cinfo.col_fmt[i] == COL_PACKET_LENGTH ||
+            cfile.cinfo.col_fmt[i] == COL_CUMULATIVE_BYTES ||
+            cfile.cinfo.col_fmt[i] == COL_DCE_CALL)
             eth_clist_set_column_justification(ETH_CLIST(packet_list), i,
                                                GTK_JUSTIFY_RIGHT);
     }
