@@ -1,7 +1,7 @@
 /* packet_list.h
  * Declarations of GTK+-specific routines for managing the packet list.
  *
- * $Id: packet_list.h 11400 2004-07-18 00:24:25Z guy $
+ * $Id: packet_list.h 13192 2005-01-29 02:14:25Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -44,6 +44,13 @@ extern GtkWidget *packet_list_new(e_prefs *prefs);
  */
 extern void packet_list_set_column_titles(void);
 
+/** Resize columns
+ *
+ * @param widget parent widget (unused)
+ * @param data unused
+ */
+extern void packet_list_resize_columns_cb(GtkWidget *widget, gpointer data);
+
 /** Mark the currently selected packet.
  * 
  * @param widget parent widget (unused)
