@@ -1,7 +1,7 @@
 /* print_dlg.c
  * Dialog boxes for printing and exporting to text files
  *
- * $Id: print_dlg.c 12813 2004-12-22 09:19:01Z guy $
+ * $Id: print_dlg.c 13724 2005-03-11 20:56:31Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -48,6 +48,7 @@
 #endif
 #include "compat_macros.h"
 #include "range_utils.h"
+#include "help_dlg.h"
 
 
 /* dialog output action */
@@ -56,7 +57,8 @@ typedef enum {
   output_action_export_text,    /* export to plain text */
   output_action_export_ps,      /* export to postscript */
   output_action_export_psml,    /* export to packet summary markup language */
-  output_action_export_pdml     /* export to packet data markup language */
+  output_action_export_pdml,    /* export to packet data markup language */
+  output_action_export_csv      /* export to csv file */
 } output_action_e;
 
 
@@ -83,6 +85,7 @@ static void print_destroy_cb(GtkWidget *win, gpointer user_data);
 #define PRINT_PS_RB_KEY           "printer_ps_radio_button"
 #define PRINT_PDML_RB_KEY         "printer_pdml_radio_button"
 #define PRINT_PSML_RB_KEY         "printer_psml_radio_button"
+#define PRINT_CSV_RB_KEY          "printer_csv_radio_button"
 #define PRINT_DEST_CB_KEY         "printer_destination_check_button"
 
 #define PRINT_SUMMARY_CB_KEY      "printer_summary_check_button"
@@ -111,7 +114,7 @@ static gboolean print_prefs_init = FALSE;
 
 
 void
-file_print_cmd_cb(GtkWidget *widget _U_, gpointer data _U_)
+file_print_cmd(gboolean print_selected)
 {
   print_args_t *args = &print_args;
 
@@ -133,14 +136,29 @@ file_print_cmd_cb(GtkWidget *widget _U_, gpointer data _U_)
       args->print_hex           = FALSE;
       args->print_formfeed      = FALSE;
   }
-  
+
   /* init the printing range */
   packet_range_init(&args->range);
 
+  if(print_selected) {
+      args->range.process = range_process_selected;
+  }
+  
   print_win = open_print_dialog("Ethereal: Print", output_action_print, args);
   SIGNAL_CONNECT(print_win, "destroy", print_destroy_cb, &print_win);
 }
 
+void
+file_print_cmd_cb(GtkWidget *widget _U_, gpointer data _U_)
+{
+    file_print_cmd(FALSE);
+}
+
+void
+file_print_selected_cmd_cb(GtkWidget *widget _U_, gpointer data _U_)
+{
+    file_print_cmd(TRUE);
+}
 
 /*
  * Keep a static pointer to the current "Export text" window, if any, so that if
@@ -317,6 +335,47 @@ export_pdml_cmd_cb(GtkWidget *widget _U_, gpointer data _U_)
   SIGNAL_CONNECT(export_pdml_win, "destroy", print_destroy_cb, &export_pdml_win);
 }
 
+/*
+ * Keep a static pointer to the current "Export csv" window, if any, so that if
+ * somebody tries to do "File:Export to CSV" while there's already a "Export csv" window
+ * up, we just pop up the existing one, rather than creating a new one.
+ */
+static GtkWidget *export_csv_win = NULL;
+
+static print_args_t  export_csv_args;
+
+static gboolean export_csv_prefs_init = FALSE;
+
+void
+export_csv_cmd_cb(GtkWidget *widget _U_, gpointer data _U_)
+{
+  print_args_t *args = &export_csv_args;
+
+  if (export_csv_win != NULL) {
+    /* There's already a "Export csv" dialog box; reactivate it. */
+    reactivate_window(export_csv_win);
+    return;
+  }
+
+  /* get settings from preferences (and other initial values) only once */
+  if(export_csv_prefs_init == FALSE) {
+      export_csv_prefs_init     = TRUE;
+      args->format              = PR_FMT_TEXT; /* XXX */
+      args->to_file             = TRUE;
+      args->file                = g_strdup("");
+      args->cmd                 = g_strdup("");
+      args->print_summary       = FALSE;
+      args->print_dissections   = print_dissections_none;
+      args->print_hex           = FALSE;
+      args->print_formfeed      = FALSE;
+  }
+
+  /* init the printing range */
+  packet_range_init(&args->range);
+
+  export_csv_win = open_print_dialog("Ethereal: Export as \"Comma Separated Values\" File", output_action_export_csv, args);
+  SIGNAL_CONNECT(export_csv_win, "destroy", print_destroy_cb, &export_csv_win);
+}
 
 static void
 print_browse_file_cb(GtkWidget *file_bt, GtkWidget *file_te)
@@ -339,7 +398,7 @@ open_print_dialog(char *title, output_action_e action, print_args_t *args)
   GtkWidget     *main_vb;
 
   GtkWidget     *printer_fr, *printer_vb, *export_format_lb;
-  GtkWidget     *text_rb, *ps_rb, *pdml_rb, *psml_rb;
+  GtkWidget     *text_rb, *ps_rb, *pdml_rb, *psml_rb, *csv_rb;
   GtkWidget     *printer_tb, *dest_cb;
 #ifndef _WIN32
   GtkWidget     *cmd_lb, *cmd_te;
@@ -359,7 +418,7 @@ open_print_dialog(char *title, output_action_e action, print_args_t *args)
   GtkWidget     *hex_cb;
   GtkWidget     *sep, *formfeed_cb;
 
-  GtkWidget     *bbox, *ok_bt, *cancel_bt;
+  GtkWidget     *bbox, *ok_bt, *cancel_bt, *help_bt;
 
   GtkTooltips   *tooltips;
 
@@ -432,6 +491,16 @@ open_print_dialog(char *title, output_action_e action, print_args_t *args)
   gtk_box_pack_start(GTK_BOX(printer_vb), psml_rb, FALSE, FALSE, 0);
   /* gtk_widget_show(psml_rb); */
 
+  csv_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(text_rb, "_CSV", accel_group);
+  if (action == output_action_export_csv)
+    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(csv_rb), TRUE);
+  gtk_tooltips_set_tip (tooltips, csv_rb,
+      "Print output in \"Comma Separated Values\" (CSV) format, "
+      "a text format compatible with OpenOffice and Excel. "
+      "One row for each packet, with its timestamp and size.", NULL);
+  gtk_box_pack_start(GTK_BOX(printer_vb), csv_rb, FALSE, FALSE, 0);
+  /* gtk_widget_show(csv_rb); */
+
   /* printer table */
 #ifndef _WIN32
   printer_tb = gtk_table_new(2, 3, FALSE);
@@ -622,7 +691,11 @@ open_print_dialog(char *title, output_action_e action, print_args_t *args)
 
 
   /* Button row */
-  bbox = dlg_button_row_new(action == output_action_print ? GTK_STOCK_PRINT : GTK_STOCK_OK, GTK_STOCK_CANCEL, NULL);
+  if(topic_available(HELP_PRINT_DIALOG)) {
+    bbox = dlg_button_row_new(action == output_action_print ? GTK_STOCK_PRINT : GTK_STOCK_OK, GTK_STOCK_CANCEL, GTK_STOCK_HELP, NULL);
+  } else {
+    bbox = dlg_button_row_new(action == output_action_print ? GTK_STOCK_PRINT : GTK_STOCK_OK, GTK_STOCK_CANCEL, NULL);
+  }
   gtk_box_pack_start(GTK_BOX(main_vb), bbox, FALSE, FALSE, 0);
   gtk_widget_show(bbox);
 
@@ -633,6 +706,7 @@ open_print_dialog(char *title, output_action_e action, print_args_t *args)
   OBJECT_SET_DATA(ok_bt, PRINT_PS_RB_KEY, ps_rb);
   OBJECT_SET_DATA(ok_bt, PRINT_PDML_RB_KEY, pdml_rb);
   OBJECT_SET_DATA(ok_bt, PRINT_PSML_RB_KEY, psml_rb);
+  OBJECT_SET_DATA(ok_bt, PRINT_CSV_RB_KEY, csv_rb);
   OBJECT_SET_DATA(ok_bt, PRINT_DEST_CB_KEY, dest_cb);
 #ifndef _WIN32
   OBJECT_SET_DATA(ok_bt, PRINT_CMD_TE_KEY, cmd_te);
@@ -654,6 +728,11 @@ open_print_dialog(char *title, output_action_e action, print_args_t *args)
   window_set_cancel_button(main_win, cancel_bt, window_cancel_button_cb);
   gtk_tooltips_set_tip (tooltips, cancel_bt, "Cancel and exit dialog", NULL);
 
+  if(topic_available(HELP_PRINT_DIALOG)) {
+    help_bt  = OBJECT_GET_DATA(bbox, GTK_STOCK_HELP);
+    SIGNAL_CONNECT(help_bt, "clicked", topic_cb, HELP_PRINT_DIALOG);
+  }
+
   gtk_widget_grab_default(ok_bt);
 
   /* Catch the "activate" signal on the "Command" and "File" text entries,
@@ -735,16 +814,17 @@ print_cmd_toggle_detail(GtkWidget *widget _U_, gpointer data)
 static void
 print_ok_cb(GtkWidget *ok_bt, gpointer parent_w)
 {
-  GtkWidget     *button;
-  print_args_t  *args;
-  const gchar   *g_dest;
-  gchar         *f_name;
-  gchar         *dirname;
-  gboolean      export_as_pdml = FALSE, export_as_psml = FALSE;
+  GtkWidget         *button;
+  print_args_t      *args;
+  const gchar       *g_dest;
+  gchar             *f_name;
+  gchar             *dirname;
+  gboolean          export_as_pdml = FALSE, export_as_psml = FALSE;
+  gboolean          export_as_csv = FALSE;
 #ifdef _WIN32
-  gboolean win_printer = FALSE;
+  gboolean          win_printer = FALSE;
 #endif
-  pp_return_t   status;
+  cf_print_status_t status;
 
   args = (print_args_t *)OBJECT_GET_DATA(ok_bt, PRINT_ARGS_KEY);
 
@@ -798,6 +878,9 @@ print_ok_cb(GtkWidget *ok_bt, gpointer parent_w)
   button = (GtkWidget *)OBJECT_GET_DATA(ok_bt, PRINT_PSML_RB_KEY);
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (button)))
     export_as_psml = TRUE;
+  button = (GtkWidget *)OBJECT_GET_DATA(ok_bt, PRINT_CSV_RB_KEY);
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (button)))
+    export_as_csv = TRUE;
 
   button = (GtkWidget *)OBJECT_GET_DATA(ok_bt, PRINT_SUMMARY_CB_KEY);
   args->print_summary = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (button));
@@ -832,9 +915,11 @@ print_ok_cb(GtkWidget *ok_bt, gpointer parent_w)
 
   /* Now print/export the packets */
   if (export_as_pdml)
-    status = write_pdml_packets(&cfile, args);
+    status = cf_write_pdml_packets(&cfile, args);
   else if (export_as_psml)
-    status = write_psml_packets(&cfile, args);
+    status = cf_write_psml_packets(&cfile, args);
+  else if (export_as_csv)
+    status = cf_write_csv_packets(&cfile, args);
   else {
     switch (args->format) {
 
@@ -874,14 +959,14 @@ print_ok_cb(GtkWidget *ok_bt, gpointer parent_w)
       g_assert_not_reached();
       return;
     }
-    status = print_packets(&cfile, args);
+    status = cf_print_packets(&cfile, args);
   }
   switch (status) {
 
-  case PP_OK:
+  case CF_PRINT_OK:
     break;
 
-  case PP_OPEN_ERROR:
+  case CF_PRINT_OPEN_ERROR:
     if (args->to_file)
       open_failure_alert_box(args->file, errno, TRUE);
     else
@@ -889,7 +974,7 @@ print_ok_cb(GtkWidget *ok_bt, gpointer parent_w)
         args->cmd);
     break;
 
-  case PP_WRITE_ERROR:
+  case CF_PRINT_WRITE_ERROR:
     if (args->to_file)
       write_failure_alert_box(args->file, errno);
     else
