@@ -1,6 +1,6 @@
 /* proto_dlg.c
  *
- * $Id: proto_dlg.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: proto_dlg.c 15043 2005-07-24 19:01:28Z guy $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -42,6 +42,7 @@
 #include "compat_macros.h"
 #include "disabled_protos.h"
 #include <epan/filesystem.h>
+#include "help_dlg.h"
 
 static gboolean proto_delete_event_cb(GtkWidget *, GdkEvent *, gpointer);
 static void proto_ok_cb(GtkWidget *, gpointer);
@@ -76,13 +77,13 @@ static GtkWidget *proto_w = NULL;
 static GSList *protocol_list = NULL;
 
 typedef struct protocol_data {
-  char     *name;
-  char 	   *abbrev;
-  int  	   hfinfo_index;
-  gboolean enabled;
-  gboolean was_enabled;
+  const char  *name;
+  const char  *abbrev;
+  int  	      hfinfo_index;
+  gboolean    enabled;
+  gboolean    was_enabled;
 #if GTK_MAJOR_VERSION < 2
-  gint     row;
+  gint        row;
 #else
   GtkTreeIter iter;
 #endif
@@ -219,7 +220,11 @@ proto_cb(GtkWidget *w _U_, gpointer data _U_)
 
 
   /* Button row */
-  bbox = dlg_button_row_new(GTK_STOCK_OK, GTK_STOCK_APPLY, GTK_STOCK_SAVE, GTK_STOCK_CANCEL, NULL);
+  if(topic_available(HELP_ENABLED_PROTOCOLS_DIALOG)) {
+    bbox = dlg_button_row_new(GTK_STOCK_OK, GTK_STOCK_APPLY, GTK_STOCK_SAVE, GTK_STOCK_CANCEL, GTK_STOCK_HELP, NULL);
+  } else {
+    bbox = dlg_button_row_new(GTK_STOCK_OK, GTK_STOCK_APPLY, GTK_STOCK_SAVE, GTK_STOCK_CANCEL, NULL);
+  }
   gtk_box_pack_start(GTK_BOX(main_vb), bbox, FALSE, FALSE, 0);
   gtk_widget_show(bbox);
 
@@ -236,6 +241,11 @@ proto_cb(GtkWidget *w _U_, gpointer data _U_)
   button = OBJECT_GET_DATA(bbox, GTK_STOCK_CANCEL);
   window_set_cancel_button(proto_w, button, proto_cancel_cb);
 
+  if(topic_available(HELP_ENABLED_PROTOCOLS_DIALOG)) {
+    button = OBJECT_GET_DATA(bbox, GTK_STOCK_HELP);
+    SIGNAL_CONNECT(button, "clicked", topic_cb, HELP_ENABLED_PROTOCOLS_DIALOG);
+  }
+
   SIGNAL_CONNECT(proto_w, "delete_event", proto_delete_event_cb, NULL);
   SIGNAL_CONNECT(proto_w, "destroy", proto_destroy_cb, NULL);
 
@@ -406,14 +416,14 @@ proto_ok_cb(GtkWidget *ok_bt _U_, gpointer parent_w)
   redissect = set_proto_selection(GTK_WIDGET(parent_w));
   window_destroy(GTK_WIDGET(parent_w));
   if (redissect)
-    redissect_packets(&cfile);
+    cf_redissect_packets(&cfile);
 }
 
 static void
 proto_apply_cb(GtkWidget *apply_bt _U_, gpointer parent_w)
 {
   if (set_proto_selection(GTK_WIDGET(parent_w)))
-    redissect_packets(&cfile);
+    cf_redissect_packets(&cfile);
 }
 
 static void
@@ -448,7 +458,7 @@ proto_save_cb(GtkWidget *save_bt _U_, gpointer parent_w)
 
   if (must_redissect) {
     /* Redissect all the packets, and re-evaluate the display filter. */
-    redissect_packets(&cfile);
+    cf_redissect_packets(&cfile);
   }
 }
 
@@ -460,7 +470,7 @@ proto_cancel_cb(GtkWidget *cancel_bt _U_, gpointer parent_w)
   redissect = revert_proto_selection();
   window_destroy(GTK_WIDGET(parent_w));
   if (redissect)
-    redissect_packets(&cfile);
+    cf_redissect_packets(&cfile);
 }
 
 static gboolean
