@@ -3,7 +3,7 @@
  * Helper routines common to all service response time statistics
  * tap.
  *
- * $Id: service_response_time_table.c 12910 2005-01-01 02:57:02Z guy $
+ * $Id: service_response_time_table.c 14795 2005-06-27 08:13:41Z etxrab $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -328,7 +328,7 @@ srt_create_popup_menu(srt_stat_table *rst)
 
 
 void
-init_srt_table(srt_stat_table *rst, int num_procs, GtkWidget *vbox, char *filter_string)
+init_srt_table(srt_stat_table *rst, int num_procs, GtkWidget *vbox, const char *filter_string)
 {
 	int i, j;
 	column_arrows *col_arrows;
@@ -427,7 +427,7 @@ init_srt_table(srt_stat_table *rst, int num_procs, GtkWidget *vbox, char *filter
 }
 
 void
-init_srt_table_row(srt_stat_table *rst, int index, char *procedure)
+init_srt_table_row(srt_stat_table *rst, int index, const char *procedure)
 {
 	char str[10];
 
