@@ -3,7 +3,7 @@
  * Helper routines common to all service response time statistics
  * tap.
  *
- * $Id: service_response_time_table.h 11400 2004-07-18 00:24:25Z guy $
+ * $Id: service_response_time_table.h 14795 2005-06-27 08:13:41Z etxrab $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -58,7 +58,8 @@ typedef struct _srt_stat_table {
  * @param vbox the corresponding GtkVBox to fill in
  * @param filter_string filter string or NULL
  */
-void init_srt_table(srt_stat_table *rst, int num_procs, GtkWidget *vbox, char *filter_string);
+void init_srt_table(srt_stat_table *rst, int num_procs, GtkWidget *vbox,
+                    const char *filter_string);
 
 /** Init an srt table row data structure.
  *
@@ -66,7 +67,7 @@ void init_srt_table(srt_stat_table *rst, int num_procs, GtkWidget *vbox, char *f
  * @param index number of procedure
  * @param procedure the procedures name
  */
-void init_srt_table_row(srt_stat_table *rst, int index, char *procedure);
+void init_srt_table_row(srt_stat_table *rst, int index, const char *procedure);
 
 /** Add srt response to table row data. This will not draw the data!
  *
@@ -75,7 +76,7 @@ void init_srt_table_row(srt_stat_table *rst, int index, char *procedure);
  * @param req_time the time of the corresponding request
  * @param pinfo current packet info
  */
-void add_srt_table_data(srt_stat_table *rst, int index, nstime_t *req_time, packet_info *pinfo);
+void add_srt_table_data(srt_stat_table *rst, int index, const nstime_t *req_time, packet_info *pinfo);
 
 /** Draw the srt table data.
  *
