@@ -1,7 +1,7 @@
 /* simple_dialog.c
  * Simple message dialog box routines.
  *
- * $Id: simple_dialog.c,v 1.39 2004/06/29 22:21:04 ulfl Exp $
+ * $Id: simple_dialog.c 14108 2005-04-16 22:19:59Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -47,6 +47,7 @@ static void simple_dialog_cancel_cb(GtkWidget *, gpointer);
 #define CALLBACK_FCT_KEY    "ESD_Callback_Fct"
 #define CALLBACK_BTN_KEY    "ESD_Callback_Btn"
 #define CALLBACK_DATA_KEY   "ESD_Callback_Data"
+#define CHECK_BUTTON        "ESD_Check_Button"
 
 /*
  * Queue for messages requested before we have a main window.
@@ -62,8 +63,8 @@ static GSList *message_queue;
 static GtkWidget *
 display_simple_dialog(gint type, gint btn_mask, char *message)
 {
-  GtkWidget   *win, *main_vb, *top_hb, *type_pm, *msg_label,
-              *bbox, *ok_bt, *yes_bt, *bt;
+  GtkWidget   *win, *main_vb, *top_hb, *msg_vb, *type_pm, *msg_label, *ask_cb,
+              *bbox, *ok_bt, *yes_bt, *bt, *save_bt, *dont_save_bt;
   GdkPixmap   *pixmap;
   GdkBitmap   *mask;
   GtkStyle    *style;
@@ -141,6 +142,7 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
   gtk_container_add(GTK_CONTAINER(main_vb), top_hb);
   gtk_widget_show(top_hb);
 
+  /* icon */
   style = gtk_widget_get_style(win);
   cmap  = gdk_colormap_get_system();
   pixmap = gdk_pixmap_colormap_create_from_xpm_d(NULL, cmap,  &mask,
@@ -150,6 +152,13 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
   gtk_container_add(GTK_CONTAINER(top_hb), type_pm);
   gtk_widget_show(type_pm);
 
+  /* column for message and optional check button */
+  msg_vb = gtk_vbox_new(FALSE, 6);
+  gtk_box_set_spacing(GTK_BOX(msg_vb), 24);
+  gtk_container_add(GTK_CONTAINER(top_hb), msg_vb);
+  gtk_widget_show(msg_vb);
+
+  /* message */
   msg_label = gtk_label_new(message);
 
 #if GTK_MAJOR_VERSION >= 2
@@ -159,9 +168,14 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
 
   gtk_label_set_justify(GTK_LABEL(msg_label), GTK_JUSTIFY_FILL);
   gtk_misc_set_alignment (GTK_MISC (type_pm), 0.5, 0.0);
-  gtk_container_add(GTK_CONTAINER(top_hb), msg_label);
+  gtk_container_add(GTK_CONTAINER(msg_vb), msg_label);
   gtk_widget_show(msg_label);
 
+  /* optional check button */
+  ask_cb = gtk_check_button_new_with_label("replace with text...");
+  gtk_container_add(GTK_CONTAINER(msg_vb), ask_cb);
+  OBJECT_SET_DATA(win, CHECK_BUTTON, ask_cb);
+
   /* Button row */
   switch(btn_mask) {
   case(ESD_BTN_OK):
@@ -176,6 +190,9 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
   case(ESD_BTNS_YES_NO_CANCEL):
     bbox = dlg_button_row_new(GTK_STOCK_YES, GTK_STOCK_NO, GTK_STOCK_CANCEL, NULL);
     break;
+  case(ESD_BTNS_SAVE_DONTSAVE_CANCEL):
+    bbox = dlg_button_row_new(GTK_STOCK_SAVE, ETHEREAL_STOCK_DONT_SAVE, GTK_STOCK_CANCEL, NULL);
+    break;
   case(ESD_BTNS_YES_NO):
     bbox = dlg_button_row_new(GTK_STOCK_YES, GTK_STOCK_NO, NULL);
     break;
@@ -193,6 +210,17 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
       SIGNAL_CONNECT(ok_bt, "clicked", simple_dialog_cancel_cb, win);
   }
 
+  save_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_SAVE);
+  if (save_bt) {
+      OBJECT_SET_DATA(save_bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_SAVE));
+      SIGNAL_CONNECT(save_bt, "clicked", simple_dialog_cancel_cb, win);
+  }
+  
+  dont_save_bt = OBJECT_GET_DATA(bbox, ETHEREAL_STOCK_DONT_SAVE);
+  if (dont_save_bt) {
+      OBJECT_SET_DATA(dont_save_bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_DONT_SAVE));
+      SIGNAL_CONNECT(dont_save_bt, "clicked", simple_dialog_cancel_cb, win);  	
+  }      
   bt = OBJECT_GET_DATA(bbox, GTK_STOCK_CLEAR);
   if(bt) {
       OBJECT_SET_DATA(bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_CLEAR));
@@ -345,6 +373,22 @@ void simple_dialog_set_cb(gpointer dialog, simple_dialog_cb_t callback_fct, gpoi
     OBJECT_SET_DATA(GTK_WIDGET(dialog), CALLBACK_DATA_KEY, data);
 }
 
+void simple_dialog_check_set(gpointer dialog, gchar *text) {
+    GtkWidget *ask_cb = OBJECT_GET_DATA(dialog, CHECK_BUTTON);
+
+#if GTK_MAJOR_VERSION >= 2
+    /* XXX - find a way to set the GtkButton label in GTK 1.x */
+    gtk_button_set_label(GTK_BUTTON(ask_cb), text);
+#endif
+    gtk_widget_show(ask_cb);
+}
+
+gboolean simple_dialog_check_get(gpointer dialog) {
+    GtkWidget *ask_cb = OBJECT_GET_DATA(dialog, CHECK_BUTTON);
+
+    return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ask_cb));
+}
+
 char *
 simple_dialog_primary_start(void) {
     return PRIMARY_TEXT_START;
