@@ -1,7 +1,7 @@
 /* sip_stat.c
  * sip_stat   2004 Martin Mathieson
  *
- * $Id: sip_stat.c 14098 2005-04-16 10:53:09Z ulfl $
+ * $Id: sip_stat.c 14739 2005-06-24 01:32:42Z guy $
  * Copied from http_stat.c
  *
  * Ethereal - Network traffic analyzer
@@ -73,13 +73,13 @@ typedef struct _sip_stats_t {
  * for example it can be { 3, 404, "Not Found" ,...}
  * which means we captured 3 reply sip/1.1 404 Not Found */
 typedef struct _sip_response_code_t {
-    guint32 	 packets;		    /* 3 */
-    guint	 	 response_code;		/* 404 */
-    gchar		*name;			    /* "Not Found" */
-    GtkWidget	*widget;		    /* Label where we display it */
-    GtkWidget	*table;			    /* Table in which we put it,
-                                       e.g. client_error_table */
-    sipstat_t	*sp;                /* Pointer back to main struct */
+    guint32 	 packets;		/* 3 */
+    guint 	 response_code;		/* 404 */
+    const gchar	*name;			/* "Not Found" */
+    GtkWidget	*widget;		/* Label where we display it */
+    GtkWidget	*table;			/* Table in which we put it,
+					   e.g. client_error_table */
+    sipstat_t	*sp;			/* Pointer back to main struct */
 } sip_response_code_t;
 
 /* Used to keep track of the stats for a specific request string */
