@@ -1,7 +1,7 @@
 /* summary_dlg.c
  * Routines for capture file summary window
  *
- * $Id: summary_dlg.c 12915 2005-01-01 23:19:11Z guy $
+ * $Id: summary_dlg.c 14888 2005-07-09 11:28:13Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -33,11 +33,19 @@
 #include <wtap.h>
 #include <time.h>
 
+#include "globals.h"
+#include "file.h"
+#ifdef HAVE_LIBPCAP
+#include <pcap.h>
+#include "capture.h"
+#include "main.h"
+#endif
 #include "summary.h"
 #include "summary_dlg.h"
 #include "dlg_utils.h"
 #include "ui_util.h"
 #include "compat_macros.h"
+#include "help_dlg.h"
 
 #define SUM_STR_MAX     1024
 #define FILTER_SNIP_LEN 50
@@ -86,7 +94,7 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
 {
   summary_tally summary;
   GtkWidget     *sum_open_w,
-                *main_vb, *bbox, *close_bt;
+                *main_vb, *bbox, *close_bt, *help_bt;
   GtkWidget     *table;
   GtkWidget     *list;
   char          *titles[] = { "Traffic", "Captured", "Displayed" };
@@ -107,7 +115,10 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
   unsigned int  elapsed_time;
 
   /* initial computations */
-  summary_fill_in(&summary);
+  summary_fill_in(&cfile, &summary);
+#ifdef HAVE_LIBPCAP
+  summary_fill_in_capture(capture_opts, &summary);
+#endif
   seconds = summary.stop_time - summary.start_time;
   disp_seconds = summary.filtered_stop - summary.filtered_start;
 
@@ -196,7 +207,7 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
 
   /* interface */
   if (summary.iface) {
-    g_snprintf(string_buff, SUM_STR_MAX, "%s", summary.iface);
+    g_snprintf(string_buff, SUM_STR_MAX, "%s", summary.iface_descr);
   } else {
     g_snprintf(string_buff, SUM_STR_MAX, "unknown");
   }
@@ -204,7 +215,7 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
 
   /* Dropped count */
   if (summary.drops_known) {
-    g_snprintf(string_buff, SUM_STR_MAX, "%u", summary.drops);
+    g_snprintf(string_buff, SUM_STR_MAX, "%" PRIu64, summary.drops);
   } else {
     g_snprintf(string_buff, SUM_STR_MAX, "unknown");
   }
@@ -295,22 +306,24 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
   /* Packet size */
   if (summary.packet_count > 0){
     g_snprintf(string_buff, SUM_STR_MAX, "%.3f bytes",
-      (float)summary.bytes/summary.packet_count);
+      /* MSVC cannot convert from unsigned __int64 to float, so first convert to signed __int64 */
+      (float) (gint64) (summary.bytes/summary.packet_count) );
   } else {
     strcpy(string_buff, "");
   }
   if (summary.dfilter && summary.filtered_count > 0){
     g_snprintf(string_buff2, SUM_STR_MAX, "%.3f bytes",
-          (float) summary.filtered_bytes/summary.filtered_count);
+          /* MSVC cannot convert from unsigned __int64 to float, so first convert to signed __int64 */
+          (float) (gint64) summary.filtered_bytes/summary.filtered_count);
   } else {
     strcpy(string_buff2, "");
   }
   add_string_to_list(list, "Avg. packet size", string_buff, string_buff2);
 
   /* Byte count */
-  g_snprintf(string_buff, SUM_STR_MAX, "%d", summary.bytes);
+  g_snprintf(string_buff, SUM_STR_MAX, "%" PRIu64, summary.bytes);
   if (summary.dfilter && summary.filtered_count > 0){
-    g_snprintf(string_buff2, SUM_STR_MAX, "%d", summary.filtered_bytes);
+    g_snprintf(string_buff2, SUM_STR_MAX, "%" PRIu64, summary.filtered_bytes);
   } else {
     strcpy(string_buff2, "");
   }
@@ -318,12 +331,14 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
 
   /* Bytes per second */
   if (seconds > 0){
-    g_snprintf(string_buff, SUM_STR_MAX, "%.3f", summary.bytes/seconds);
+    /* MSVC cannot convert from unsigned __int64 to float, so first convert to signed __int64 */
+    g_snprintf(string_buff, SUM_STR_MAX, "%.3f", ((gint64) summary.bytes)/seconds );
   } else {
     strcpy(string_buff, "");
   }
   if (summary.dfilter && disp_seconds > 0){
-    g_snprintf(string_buff2, SUM_STR_MAX, "%.3f", summary.filtered_bytes/disp_seconds);
+    /* MSVC cannot convert from unsigned __int64 to float, so first convert to signed __int64 */
+    g_snprintf(string_buff2, SUM_STR_MAX, "%.3f", ((gint64) summary.filtered_bytes)/disp_seconds );
   } else {
     strcpy(string_buff2, "");
   }
@@ -331,13 +346,15 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
 
   /* MBit per second */
   if (seconds > 0){
-    g_snprintf(string_buff, SUM_STR_MAX, "%.3f", summary.bytes * 8.0 / (seconds * 1000.0 * 1000.0));
+    /* MSVC cannot convert from unsigned __int64 to float, so first convert to signed __int64 */
+    g_snprintf(string_buff, SUM_STR_MAX, "%.3f", ((gint64) summary.bytes) * 8.0 / (seconds * 1000.0 * 1000.0));
   } else {
     strcpy(string_buff, "");
   }
   if (summary.dfilter && disp_seconds > 0){
     g_snprintf(string_buff2, SUM_STR_MAX, "%.3f", 
-          summary.filtered_bytes * 8.0 / (disp_seconds * 1000.0 * 1000.0));
+          /* MSVC cannot convert from unsigned __int64 to float, so first convert to signed __int64 */
+          ((gint64) summary.filtered_bytes) * 8.0 / (disp_seconds * 1000.0 * 1000.0));
   } else {
     strcpy(string_buff2, "");
   }
@@ -345,12 +362,21 @@ summary_open_cb(GtkWidget *w _U_, gpointer d _U_)
 
   
   /* Button row. */
-  bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
+  if(topic_available(HELP_STATS_SUMMARY_DIALOG)) {
+    bbox = dlg_button_row_new(GTK_STOCK_CLOSE, GTK_STOCK_HELP, NULL);
+  } else {
+    bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
+  }
   gtk_container_add(GTK_CONTAINER(main_vb), bbox);
 
   close_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_CLOSE);
   window_set_cancel_button(sum_open_w, close_bt, window_cancel_button_cb);
 
+  if(topic_available(HELP_STATS_SUMMARY_DIALOG)) {
+    help_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_HELP);
+    SIGNAL_CONNECT(help_bt, "clicked", topic_cb, HELP_STATS_SUMMARY_DIALOG);
+  }
+
   gtk_widget_grab_focus(close_bt);
 
   SIGNAL_CONNECT(sum_open_w, "delete_event", window_delete_event_cb, NULL);
