@@ -1,7 +1,7 @@
 /* tap_menu.h
  * Menu definitions for use by taps
  *
- * $Id: tap_menu.h,v 1.6 2004/06/03 02:14:14 guy Exp $
+ * $Id: tap_menu.h 14098 2005-04-16 10:53:09Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -39,7 +39,9 @@ typedef enum {
     REGISTER_TAP_GROUP_GENERIC,
     REGISTER_TAP_GROUP_CONVERSATION_LIST,
     REGISTER_TAP_GROUP_ENDPOINT_LIST,
-    REGISTER_TAP_GROUP_RESPONSE_TIME
+    REGISTER_TAP_GROUP_RESPONSE_TIME,
+    REGISTER_TAP_GROUP_TELEPHONY
+    /* XXX - split into telephony and VoIP? */
 } REGISTER_TAP_GROUP_E;
 
 /**
