@@ -2,7 +2,7 @@
  * The main toolbar
  * Copyright 2003, Ulf Lamping <ulf.lamping@web.de>
  *
- * $Id: toolbar.c 14138 2005-04-19 20:53:22Z ulfl $
+ * $Id: toolbar.c 14326 2005-05-07 20:47:39Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -135,6 +135,9 @@
 #include "../image/toolbar/telephony_16.xpm"
 #include "../image/toolbar/decode_as_16.xpm"
 #include "../image/toolbar/checkbox_16.xpm"
+#include "../image/toolbar/file_set_list_16.xpm"
+#include "../image/toolbar/file_set_next_16.xpm"
+#include "../image/toolbar/file_set_previous_16.xpm"
 
 
 /* XXX: add this key to some .h file, as it adds a key to the top level Widget? */
@@ -200,7 +203,10 @@ static void ethereal_stock_icons(void) {
         { ETHEREAL_STOCK_GRAPHS,                ETHEREAL_STOCK_LABEL_GRAPHS,                0, 0, NULL },
         { ETHEREAL_STOCK_TELEPHONY,             ETHEREAL_STOCK_LABEL_TELEPHONY,             0, 0, NULL },
         { ETHEREAL_STOCK_DECODE_AS,             ETHEREAL_STOCK_LABEL_DECODE_AS,             0, 0, NULL },
-        { ETHEREAL_STOCK_CHECKBOX,              ETHEREAL_STOCK_LABEL_CHECKBOX,              0, 0, NULL }
+        { ETHEREAL_STOCK_CHECKBOX,              ETHEREAL_STOCK_LABEL_CHECKBOX,              0, 0, NULL },
+        { ETHEREAL_STOCK_FILE_SET_LIST,         ETHEREAL_STOCK_LABEL_FILE_SET_LIST,         0, 0, NULL },
+        { ETHEREAL_STOCK_FILE_SET_NEXT,         ETHEREAL_STOCK_LABEL_FILE_SET_NEXT,         0, 0, NULL },
+        { ETHEREAL_STOCK_FILE_SET_PREVIOUS,     ETHEREAL_STOCK_LABEL_FILE_SET_PREVIOUS,     0, 0, NULL }
     };
 
     static const stock_pixmap_t pixmaps[] = {
@@ -236,6 +242,9 @@ static void ethereal_stock_icons(void) {
         { ETHEREAL_STOCK_TELEPHONY,             telephony_16_xpm},
         { ETHEREAL_STOCK_DECODE_AS,             decode_as_16_xpm},
         { ETHEREAL_STOCK_CHECKBOX,              checkbox_16_xpm},
+        { ETHEREAL_STOCK_FILE_SET_LIST,         file_set_list_16_xpm},
+        { ETHEREAL_STOCK_FILE_SET_NEXT,         file_set_next_16_xpm},
+        { ETHEREAL_STOCK_FILE_SET_PREVIOUS,     file_set_previous_16_xpm},
         { NULL, NULL }
     };
 
