@@ -1,7 +1,7 @@
 /* packet-acn.c
  * Routines for ACN packet disassembly
  *
- * $Id: packet-acn.c 12832 2004-12-25 13:49:30Z ulfl $
+ * $Id: packet-acn.c 13644 2005-03-07 02:44:41Z guy $
  *
  * Copyright (c) 2003 by Erwin Rol <erwin@erwinrol.com>
  *
@@ -30,8 +30,6 @@
 #include "config.h"
 #endif
 
-#include "plugins/plugin_api.h"
-
 #include "moduleinfo.h"
 
 #include <stdio.h>
@@ -50,8 +48,6 @@
 
 #include "acn.h"
 
-#include "plugins/plugin_api_defs.h"
-
 /* Define version if we are not building ethereal statically */
 
 #ifndef ENABLE_STATIC
@@ -937,7 +933,7 @@ proto_register_acn(void) {
 		"res", HFILL }},
 
 	{ &hf_acn_pdu_length,
-	    { "Lenght","acn.pdu.length",
+	    { "Length","acn.pdu.length",
 		FT_UINT8, BASE_DEC, NULL, 0x0,
 		"Length", HFILL }},
 
@@ -1202,24 +1198,19 @@ proto_reg_handoff_acn(void) {
 #ifndef ENABLE_STATIC
 
 G_MODULE_EXPORT void
-plugin_reg_handoff(void){
-  proto_reg_handoff_acn();
-}
-
-G_MODULE_EXPORT void
-plugin_init(plugin_address_table_t *pat
-#ifndef PLUGINS_NEED_ADDRESS_TABLE
-_U_
-#endif
-){
-  /* initialise the table of pointers needed in Win32 DLLs */
-  plugin_address_table_init(pat);
+plugin_register(void)
+{
   /* register the new protocol, protocol fields, and subtrees */
   if (proto_acn == -1) { /* execute protocol initialization only once */
     proto_register_acn();
   }
 }
 
+G_MODULE_EXPORT void
+plugin_reg_handoff(void){
+  proto_reg_handoff_acn();
+}
+
 #endif
 
 /* End the functions we need for plugin stuff */
