@@ -1,7 +1,7 @@
 /* packet-gryphon.c
  * Definitions for Gryphon packet disassembly structures and routines
  *
- * $Id: packet-gryphon.h,v 1.8 2003/10/03 23:22:12 guy Exp $
+ * $Id: packet-gryphon.h 15015 2005-07-23 11:41:25Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Steve Limkemann <stevelim@dgtech.com>
@@ -457,8 +457,8 @@
 
 
 typedef struct val_str_dsp {
-    int     value;
-    char    *strptr;
-    int     (*cmd_fnct)(tvbuff_t *, int, proto_tree*);
-    int     (*rsp_fnct)(tvbuff_t *, int, proto_tree*);
+    int		value;
+    const char	*strptr;
+    int		(*cmd_fnct)(tvbuff_t *, int, proto_tree*);
+    int		(*rsp_fnct)(tvbuff_t *, int, proto_tree*);
 } val_str_dsp;
