@@ -1,7 +1,7 @@
 /* packet-lwres.c
  * Routines for light weight reslover (lwres, part of BIND9) packet disassembly
  *
- * $Id: packet-lwres.c 12140 2004-09-29 22:20:21Z guy $
+ * $Id: packet-lwres.c 13644 2005-03-07 02:44:41Z guy $
  *
  * Copyright (c) 2003 by Oleg Terletsky <oleg.terletsky@comverse.com>
  *
@@ -28,7 +28,6 @@
 #include "config.h"
 #endif
 
-#include "plugins/plugin_api.h"
 #include "moduleinfo.h"
 
 #include <stdio.h>
@@ -41,8 +40,6 @@
 #include <epan/packet.h>
 #include <epan/prefs.h>
 
-#include "plugins/plugin_api_defs.h"
-
 #define LWRES_LWPACKET_LENGTH           (4 * 5 + 2 * 4)
 #define LWRES_LWPACKETFLAG_RESPONSE     0x0001U /* if set, pkt is a response */
 #define LWRES_LWPACKETVERSION_0         0
@@ -1450,7 +1447,7 @@ proto_register_lwres(void)
 
 	{ &hf_adn_addr_len,
 	{ "Address length", "lwres.adn.addr.length", FT_UINT16, BASE_DEC, NULL, 0x0,
-	"lwres adn addr lenght", HFILL }},
+	"lwres adn addr length", HFILL }},
 
 	{ &hf_adn_addr_addr,
     { "IP Address", "lwres.adn.addr.addr", FT_STRING, BASE_DEC, NULL, 0x0,
@@ -1526,24 +1523,19 @@ proto_reg_handoff_lwres(void)
 #ifndef ENABLE_STATIC
 
 G_MODULE_EXPORT void
-plugin_reg_handoff(void){
-  proto_reg_handoff_lwres();
-}
-
-G_MODULE_EXPORT void
-plugin_init(plugin_address_table_t *pat
-#ifndef PLUGINS_NEED_ADDRESS_TABLE
-_U_
-#endif
-){
-  /* initialise the table of pointers needed in Win32 DLLs */
-  plugin_address_table_init(pat);
+plugin_register(void)
+{
   /* register the new protocol, protocol fields, and subtrees */
   if (proto_lwres == -1) { /* execute protocol initialization only once */
     proto_register_lwres();
   }
 }
 
+G_MODULE_EXPORT void
+plugin_reg_handoff(void){
+  proto_reg_handoff_lwres();
+}
+
 #endif
 
 /* End the functions we need for plugin stuff */
