@@ -9,7 +9,7 @@
  *          Laboratories, Inc., http://www.PacketCable.com/
  * www.iana.org/assignments/mgcp-localconnectionoptions
  *
- * $Id: packet-mgcp.c 14275 2005-05-02 20:05:03Z gerald $
+ * $Id: packet-mgcp.c 15015 2005-07-23 11:41:25Z jmayer $
  *
  * Copyright (c) 2000 by Ed Warnicke <hagbard@physics.rutgers.edu>
  * Copyright (c) 2004 by Thomas Anders <thomas.anders [AT] blue-cable.de>
@@ -268,7 +268,7 @@ static int callagent_tcp_port = 0;
 static int callagent_udp_port = 0;
 
 /* Some basic utility functions that are specific to this dissector */
-static gboolean is_mgcp_verb(tvbuff_t *tvb, gint offset, gint maxlength, gchar **verb_name);
+static gboolean is_mgcp_verb(tvbuff_t *tvb, gint offset, gint maxlength, const gchar **verb_name);
 static gboolean is_mgcp_rspcode(tvbuff_t *tvb, gint offset, gint maxlength);
 static gint tvb_parse_param(tvbuff_t *tvb, gint offset, gint maxlength, int** hf);
 
@@ -345,7 +345,7 @@ static void dissect_mgcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint32 num_messages;
 	gint tvb_sectionend,tvb_sectionbegin, tvb_len, tvb_current_len;
 	proto_tree *mgcp_tree, *ti;
-	gchar *verb_name = "";
+	const gchar *verb_name = "";
 
 	/* Initialize variables */
 	tvb_sectionend = 0;
@@ -451,7 +451,7 @@ static void dissect_mgcp_message(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 	gint sectionlen;
 	gint tvb_sectionend,tvb_sectionbegin, tvb_len, tvb_current_len;
 	tvbuff_t *next_tvb;
-	gchar *verb_name = "";
+	const gchar *verb_name = "";
 
 	/* Initialise stat info for passing to tap */
 	pi_current++;
@@ -950,7 +950,7 @@ void proto_reg_handoff_mgcp(void)
  *
  * Return: TRUE if there is an MGCP verb at offset in tvb, otherwise FALSE
  */
-static gboolean is_mgcp_verb(tvbuff_t *tvb, gint offset, gint maxlength, gchar **verb_name)
+static gboolean is_mgcp_verb(tvbuff_t *tvb, gint offset, gint maxlength, const gchar **verb_name)
 {
 	int returnvalue = FALSE;
 	guint8 word[5];
@@ -967,6 +967,7 @@ static gboolean is_mgcp_verb(tvbuff_t *tvb, gint offset, gint maxlength, gchar *
 		    ((strncasecmp(word, "AUEP", 4) == 0) && (*verb_name = "AuditEndpoint")) ||
 		    ((strncasecmp(word, "AUCX", 4) == 0) && (*verb_name = "AuditConnection")) ||
 		    ((strncasecmp(word, "RSIP", 4) == 0) && (*verb_name = "RestartInProgress")) ||
+		    ((strncasecmp(word, "MESG", 4) == 0) && (*verb_name = "Message")) ||
 		    (word[0] == 'X' && is_rfc2234_alpha(word[1]) && is_rfc2234_alpha(word[2]) &&
 		                       is_rfc2234_alpha(word[3]) && (*verb_name = "*Experimental*")))
 		{
@@ -1066,8 +1067,11 @@ static gint tvb_parse_param(tvbuff_t* tvb, gint offset, gint len, int** hf)
 {
 	gint returnvalue = -1, tvb_current_offset,counter;
 	guint8 tempchar, plus_minus;
+	gchar **buf;
+
 	tvb_current_offset = offset;
 	*hf = NULL;
+	buf=NULL;
 
 	if (len > 0)
 	{
@@ -1183,6 +1187,7 @@ static gint tvb_parse_param(tvbuff_t* tvb, gint offset, gint len, int** hf)
 				break;
 			case 'S':
 				*hf = &hf_mgcp_param_signalreq;
+				buf = &(mi->signalReq);
 				break;
 			case 'D':
 				*hf = &hf_mgcp_param_digitmap;
@@ -1190,6 +1195,7 @@ static gint tvb_parse_param(tvbuff_t* tvb, gint offset, gint len, int** hf)
 				break;
 			case 'O':
 				*hf = &hf_mgcp_param_observedevent;
+				buf = &(mi->observedEvents);
 				break;
 			case 'P':
 				tvb_current_offset++;
@@ -1261,6 +1267,11 @@ static gint tvb_parse_param(tvbuff_t* tvb, gint offset, gint len, int** hf)
 			tvb_current_offset++;
 			tvb_current_offset = tvb_skip_wsp(tvb,tvb_current_offset, (len - tvb_current_offset + offset));
 			returnvalue = tvb_current_offset;
+
+                       /* set the observedEvents or signalReq used in Voip Calls analysis */
+                       if (buf != NULL) {
+                               *buf = tvb_get_string(tvb, tvb_current_offset, (len - tvb_current_offset + offset));
+                       }
 		}
 	}
 	else
@@ -1310,7 +1321,7 @@ static void dissect_mgcp_firstline(tvbuff_t *tvb, packet_info *pinfo, proto_tree
 	mgcp_call_t *mgcp_call = NULL;
 	nstime_t delta;
 	gint rspcode = 0;
-	gchar *verb_description = "";
+	const gchar *verb_description = "";
 	char code_with_verb[64] = "";  /* To fit "<4-letter-code> (<longest-verb>)" */
 
 	static address null_address = { AT_NONE, 0, NULL };
@@ -1878,7 +1889,7 @@ dissect_mgcp_localconnectionoptions(proto_tree *parent_tree, tvbuff_t *tvb, gint
 
 	if (parent_tree)
 	{
-		item = proto_tree_add_item(parent_tree, hf_mgcp_param_connectionparam, tvb, offset, param_type_len+param_val_len, FALSE);
+		item = proto_tree_add_item(parent_tree, hf_mgcp_param_localconnoptions, tvb, offset, param_type_len+param_val_len, FALSE);
 		tree = proto_item_add_subtree(item, ett_mgcp_param_localconnectionoptions);
 	}
 
