@@ -2,7 +2,7 @@
  * Routines for PN-DCP (PROFINET Discovery and basic Configuration Protocol) 
  * packet dissection.
  *
- * $Id$
+ * $Id: packet-pn-dcp.c 15015 2005-07-23 11:41:25Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -329,12 +329,12 @@ dissect_pn_padding(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 
 /* append the given info text */
 static void
-pn_append_info(packet_info *pinfo, proto_item *dcp_item, char *text)
+pn_append_info(packet_info *pinfo, proto_item *dcp_item, const char *text)
 {
     if (check_col(pinfo->cinfo, COL_INFO))
         col_append_fstr(pinfo->cinfo, COL_INFO, text);
 
-    proto_item_append_text(dcp_item, text);
+    proto_item_append_text(dcp_item, "%s", text);
 }
 
 
