@@ -1,7 +1,7 @@
 /* tap-dcerpcstat.c
  * dcerpcstat   2002 Ronnie Sahlberg
  *
- * $Id: tap-dcerpcstat.c 13993 2005-04-01 09:08:27Z guy $
+ * $Id: tap-dcerpcstat.c 15043 2005-07-24 19:01:28Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -40,7 +40,7 @@
 
 /* used to keep track of statistics for a specific procedure */
 typedef struct _rpc_procedure_t {
-	char *proc;
+	const char *proc;
 	int num;
 	nstime_t min;
 	nstime_t max;
@@ -49,7 +49,7 @@ typedef struct _rpc_procedure_t {
 
 /* used to keep track of the statistics for an entire program interface */
 typedef struct _rpcstat_t {
-	char *prog;
+	const char *prog;
 	char *filter;
 	e_uuid_t uuid;
 	guint16 ver;
