@@ -1,7 +1,7 @@
 /* tap-iostat.c
  * iostat   2002 Ronnie Sahlberg
  *
- * $Id: tap-iostat.c 12917 2005-01-01 23:22:10Z guy $
+ * $Id: tap-iostat.c 13993 2005-04-01 09:08:27Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -650,5 +650,5 @@ iostat_init(char *optarg)
 void
 register_tap_listener_iostat(void)
 {
-	register_ethereal_tap("io,stat,", iostat_init);
+	register_tap_listener_cmd_arg("io,stat,", iostat_init);
 }
