@@ -1,7 +1,7 @@
 /* tap-protohierstat.c
  * protohierstat   2002 Ronnie Sahlberg
  *
- * $Id: tap-protohierstat.c 13993 2005-04-01 09:08:27Z guy $
+ * $Id: tap-protohierstat.c 14739 2005-06-24 01:32:42Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -47,7 +47,7 @@ typedef struct _phs_t {
 	struct _phs_t *parent;
 	char *filter;
 	int protocol;
-	char *proto_name;
+	const char *proto_name;
 	guint32 frames;
 	guint32 bytes;
 } phs_t;
