@@ -1,7 +1,7 @@
 /* tap-rpcprogs.c
  * rpcstat   2002 Ronnie Sahlberg
  *
- * $Id: tap-rpcprogs.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: tap-rpcprogs.c 13993 2005-04-01 09:08:27Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -57,9 +57,9 @@ static rpc_program_t *prog_list=NULL;
 static int already_enabled=0;
 
 static int
-rpcprogs_packet(void *dummy1 _U_, packet_info *pinfo, epan_dissect_t *edt _U_, void *pri)
+rpcprogs_packet(void *dummy1 _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const void *pri)
 {
-	rpc_call_info_value *ri=pri;
+	const rpc_call_info_value *ri=pri;
 	nstime_t delta;
 	rpc_program_t *rp=NULL;
 
@@ -242,7 +242,7 @@ rpcprogs_init(char *optarg _U_)
 void
 register_tap_listener_rpcprogs(void)
 {
-	register_ethereal_tap("rpc,programs", rpcprogs_init);
+	register_tap_listener_cmd_arg("rpc,programs", rpcprogs_init);
 }
 
 
