@@ -1,7 +1,7 @@
 /* tap_sipstat.c
  * sip message counter for ethereal
  *
- * $Id: tap-sipstat.c 14294 2005-05-03 18:36:05Z gerald $
+ * $Id: tap-sipstat.c 14739 2005-06-24 01:32:42Z guy $
  * Copied from gtk/sip_stat.c and tap-httpstat.c
  *
  * Ethereal - Network traffic analyzer
@@ -55,7 +55,7 @@ typedef struct _sip_stats_t {
 typedef struct _sip_response_code_t {
 	guint32 	 packets;		/* 3 */
 	guint	 	 response_code;		/* 404 */
-	gchar		*name;			/* Not Found */
+	const gchar	*name;			/* Not Found */
 	sipstat_t	*sp;
 } sip_response_code_t;
 
