@@ -97,7 +97,7 @@
 
 /* ascend-grammar.y
  *
- * $Id: ascend-grammar.y 13818 2005-03-20 10:55:50Z guy $
+ * $Id: ascend-grammar.y 14997 2005-07-22 17:57:40Z jmayer $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -241,9 +241,9 @@ XMIT-Max7:20: (task "_brouterControlTask" at 0xb094ac20, time: 1481.51) 20 octet
 #define NO_USER "<none>"
 
 int yyparse(void);
-void yyerror(char *);
+void yyerror(const char *);
 
-gchar *ascend_parse_error;
+const gchar *ascend_parse_error;
 
 static unsigned int bcur;
 static guint32 start_time, secs, usecs, caplen, wirelen;
@@ -1780,7 +1780,7 @@ parse_ascend(FILE_T fh, guint8 *pd, struct ascend_phdr *phdr,
 }
 
 void
-yyerror (char *s)
+yyerror (const char *s)
 {
   ascend_parse_error = s;
 }
