@@ -2,7 +2,7 @@
  * Definitions for routines common to multiple modules in the Lucent/Ascend
  * capture file reading code code, but not used outside that code.
  *
- * $Id: ascend-int.h 11400 2004-07-18 00:24:25Z guy $
+ * $Id: ascend-int.h 14997 2005-07-22 17:57:40Z jmayer $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -36,7 +36,7 @@ typedef struct {
 
 extern int at_eof;
 
-extern gchar *ascend_parse_error;
+extern const gchar *ascend_parse_error;
 
 /*
  * Pointer to the pseudo-header for the current packet.
@@ -49,6 +49,6 @@ int ascendlex(void);
 void init_parse_ascend(void);
 void ascend_init_lexer(FILE_T fh);
 int parse_ascend(FILE_T fh, guint8 *pd, struct ascend_phdr *phdr,
-		ascend_pkthdr *hdr, int len);
+		ascend_pkthdr *hdr, long *start_of_data);
 
 #endif /* ! __ASCEND_INT_H__ */
