@@ -1,6 +1,6 @@
 /* libpcap.c
  *
- * $Id: libpcap.c 14265 2005-05-02 14:07:33Z tuexen $
+ * $Id: libpcap.c 14994 2005-07-22 15:55:06Z etxrab $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -307,9 +307,9 @@ static const struct {
 	{ 127,		WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP },  /* 802.11 plus radiotap WLAN header */
 	{ 128,		WTAP_ENCAP_TZSP },	/* Tazmen Sniffer Protocol */
 	{ 129,		WTAP_ENCAP_ARCNET_LINUX },
-
+        { 130,          WTAP_ENCAP_JUNIPER_MLPPP }, /* Juniper MLPPP on ML-, LS-, AS- PICs */
 	/*
-	 * Values 130 through 137 not listed here are reserved for use
+	 * Values 131-134, 136 not listed here are reserved for use
 	 * in Juniper hardware.
 	 */
 	{ 135,		WTAP_ENCAP_JUNIPER_ATM2 }, /* various encapsulations captured on the ATM2 PIC */
@@ -356,8 +356,13 @@ static const struct {
 	 * of the 0xff03 header, the 0xff, is replaced by a direction
 	 * byte.  I don't know whether any captures look like that,
 	 * but it is used for some Linux IP filtering (ipfilter?).
-	 *
-	 * 167 and 168 are reserved for more Juniper private-chassis-
+	 */
+
+        /* Ethernet PPPoE frames captured on a service PIC */
+        { 167,          WTAP_ENCAP_JUNIPER_PPPOE },
+
+        /*
+	 * 168 is reserved for more Juniper private-chassis-
 	 * internal meta-information.
 	 */
 
@@ -368,6 +373,10 @@ static const struct {
 	 * Framing Procedure.
 	 */
 
+	/* Registered by Gcom, Inc. */
+	{ 172,		WTAP_GCOM_TIE1 },
+	{ 173,		WTAP_GCOM_SERIAL },
+
 	/*
 	 * To repeat:
 	 *
@@ -983,6 +992,7 @@ int libpcap_open(wtap *wth, int *err, gchar **err_info)
 			*err = WTAP_ERR_UNSUPPORTED_ENCAP;
 			*err_info = g_strdup_printf("pcap: network type %u unknown or unsupported",
 			    hdr.network);
+			g_free(wth->capture.pcap);
 			return -1;
 		}
 	}
