@@ -1,6 +1,6 @@
 /* netxray.c
  *
- * $Id: netxray.c 13194 2005-01-29 10:48:16Z guy $
+ * $Id: netxray.c 14832 2005-07-02 15:40:49Z jmayer $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -153,6 +153,10 @@ static const char vers_2_002[] = {
 	'0', '0', '2', '.', '0', '0', '2', '\0'
 };
 
+static const char vers_2_003[] = {
+	'0', '0', '2', '.', '0', '0', '3', '\0'
+};
+
 /* Old NetXRay data record format - followed by frame data. */
 struct old_netxrayrec_hdr {
 	guint32	timelo;		/* lower 32 bits of time stamp */
@@ -310,6 +314,10 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 			version_major = 2;
 			version_minor = 2;
 			file_type = WTAP_FILE_NETXRAY_2_00x;
+		} else if (memcmp(hdr.version, vers_2_003, sizeof vers_2_003) == 0) {
+			version_major = 2;
+			version_minor = 3;
+			file_type = WTAP_FILE_NETXRAY_2_00x;
 		} else {
 			*err = WTAP_ERR_UNSUPPORTED;
 			*err_info = g_strdup_printf("netxray: version \"%.8s\" unsupported", hdr.version);
@@ -406,7 +414,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 		 * captures?
 		 */
 		if (network_type == 1 && hdr.xxc[4] == ETH_CAPTYPE_GIGPOD &&
-		    version_minor == 2)
+		    (version_minor == 2 || version_minor == 3))
 			start_timestamp = 0.0;
 		break;
 
@@ -440,6 +448,20 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 			case WAN_CAPTYPE_FRELAY:
 				/*
 				 * Frame Relay.
+				 *
+				 * XXX - in at least one capture, this
+				 * is Cisco HDLC, not Frame Relay, but
+				 * in another capture, it's Frame Relay.
+				 *
+				 * In the Cisco HDLC capture, hdr.xxc[22:26]
+				 * is 0x02 0x00 0x01 0x00 0x06, but it's
+				 * 0x00 0x00 0x00 0x00 0x00 in the Frame
+				 * Relay capture.  Also, hdr.xxc[30:31]
+				 * is 0xff 0xff in the Cisco HDLC capture
+				 * and 0x00 0x00 in the Frame Relay capture,
+				 * and hdr.xxc[46:47] is 0xff 0xff in the
+				 * Cisco HDLC capture and 0x05 0x00 in the
+				 * Frame Relay capture.
 				 */
 				file_encap = WTAP_ENCAP_FRELAY_WITH_PHDR;
 				break;
