@@ -1,6 +1,6 @@
 /* wtap.h
  *
- * $Id: wtap.h 14265 2005-05-02 14:07:33Z tuexen $
+ * $Id: wtap.h 14997 2005-07-22 17:57:40Z jmayer $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -165,8 +165,14 @@
 #define WTAP_ENCAP_NETTL_FDDI			74
 #define WTAP_ENCAP_NETTL_UNKNOWN		75
 #define WTAP_ENCAP_MTP2_WITH_PHDR               76
+#define WTAP_ENCAP_JUNIPER_PPPOE       		77
+#define WTAP_GCOM_TIE1				78
+#define WTAP_GCOM_SERIAL			79
+#define WTAP_ENCAP_NETTL_X25			80
+#define WTAP_ENCAP_K12					81
+#define WTAP_ENCAP_JUNIPER_MLPPP                82
 /* last WTAP_ENCAP_ value + 1 */
-#define WTAP_NUM_ENCAP_TYPES			77
+#define WTAP_NUM_ENCAP_TYPES			83
 
 /* File types that can be read by wiretap.
    We support writing some many of these file types, too, so we
@@ -211,9 +217,10 @@
 #define WTAP_FILE_NETWORK_INSTRUMENTS_V9	37
 #define WTAP_FILE_AIROPEEK_V9			38
 #define WTAP_FILE_EYESDN			39
+#define WTAP_FILE_K12				40
 
 /* last WTAP_FILE_ value + 1 */
-#define WTAP_NUM_FILE_TYPES			40
+#define WTAP_NUM_FILE_TYPES			41
 
 /*
  * Maximum packet size we'll support.
@@ -445,6 +452,30 @@ struct mtp2_phdr {
 	guint16 link_number;  
 };
 
+/* Packet "pseudo-header" for K12 files. */
+
+typedef union {
+	struct {
+		guint16 vp;
+		guint16 vc;
+	} atm;
+	
+	guint32 ds0mask;
+} k12_input_info_t;
+
+struct k12_phdr {
+	guint32 input;
+	const gchar* input_name;
+	const gchar* stack_file;
+	guint32 input_type;
+	k12_input_info_t input_info;
+	void* stuff;
+};
+
+#define K12_PORT_DS0S      0x00010008
+#define K12_PORT_DS1       0x00100008
+#define K12_PORT_ATMPVC    0x01020000
+
 union wtap_pseudo_header {
 	struct eth_phdr		eth;
 	struct x25_phdr		x25;
@@ -457,6 +488,7 @@ union wtap_pseudo_header {
 	struct irda_phdr	irda;
 	struct nettl_phdr	nettl;
 	struct mtp2_phdr        mtp2;
+	struct k12_phdr		k12;
 };
 
 struct wtap_pkthdr {
